DROP TABLE IF EXISTS recanvis_incidencia;
DROP TABLE IF EXISTS estadistiques_client;
DROP TABLE IF EXISTS estadistiques_familia;
DROP TABLE IF EXISTS estadistiques_incidencia;
DROP TABLE IF EXISTS estadistiques_tipus;
DROP TABLE IF EXISTS estadistiques_provincia;
DROP TABLE IF EXISTS estadistiques_pais;
DROP TABLE IF EXISTS estadistiques_producte;
DROP TABLE IF EXISTS estadistiques_recanvi;
DROP TABLE IF EXISTS estadistiques_sat;
DROP TABLE IF EXISTS log;
DROP TABLE IF EXISTS opinio;
DROP TABLE IF EXISTS desc_estat_incidencia;
DROP TABLE IF EXISTS desc_tipus_incidencia;
DROP TABLE IF EXISTS desc_recanvi;
DROP TABLE IF EXISTS desc_producte;
DROP TABLE IF EXISTS desc_familia_producte;
DROP TABLE IF EXISTS incidencia;
DROP TABLE IF EXISTS tipus_incidencia;
DROP TABLE IF EXISTS estat_incidencia;
DROP TABLE IF EXISTS garantia;
DROP TABLE IF EXISTS producte;
DROP TABLE IF EXISTS client;
DROP TABLE IF EXISTS sat;
DROP TABLE IF EXISTS recanvi;
DROP TABLE IF EXISTS familia_producte;
DROP TABLE IF EXISTS provincia;
DROP TABLE IF EXISTS pais;
DROP TABLE IF EXISTS idioma;

CREATE TABLE pais (
  id_pais INTEGER NOT NULL AUTO_INCREMENT,
  nom_pais VARCHAR(200) NOT NULL,
  PRIMARY KEY (id_pais),
  UNIQUE KEY nom_pais (nom_pais)
);


CREATE TABLE provincia (
  id_provincia INTEGER NOT NULL AUTO_INCREMENT,
  id_pais INTEGER NOT NULL,
  provincia VARCHAR(60) NOT NULL,
  PRIMARY KEY (id_provincia),
  KEY provincia (provincia),
  FOREIGN KEY (id_pais)
  	REFERENCES pais (id_pais)
  		ON DELETE RESTRICT
  		ON UPDATE NO ACTION
);


CREATE TABLE idioma (
  id_idioma INTEGER NOT NULL AUTO_INCREMENT,
  nom_idioma VARCHAR(50),
  PRIMARY KEY (id_idioma),
  KEY nom_idioma (nom_idioma)
);


CREATE TABLE familia_producte (
  id_familia INTEGER NOT NULL AUTO_INCREMENT,
  PRIMARY KEY (id_familia)
);  


CREATE TABLE desc_familia_producte (
  id_familia INTEGER NOT NULL,
  id_idioma INTEGER NOT NULL,
  nom VARCHAR(60) NOT NULL,
  descripcio TEXT,
  PRIMARY KEY (id_familia, id_idioma),
  FOREIGN KEY(id_familia)
    REFERENCES familia_producte(id_familia)
      ON DELETE RESTRICT
      ON UPDATE NO ACTION,
  FOREIGN KEY(id_idioma)
    REFERENCES idioma(id_idioma)
      ON DELETE RESTRICT
      ON UPDATE NO ACTION
);

  

CREATE TABLE producte (
  id_producte INTEGER NOT NULL AUTO_INCREMENT,
  codi VARCHAR(30) NOT NULL,
  id_familia INTEGER NOT NULL,
  PRIMARY KEY (id_producte),
  UNIQUE KEY codi (codi),
  FOREIGN KEY(id_familia)
    REFERENCES familia_producte(id_familia)
      ON DELETE RESTRICT
      ON UPDATE NO ACTION
);


CREATE TABLE desc_producte (
  id_producte INTEGER NOT NULL,
  id_idioma INTEGER NOT NULL,
  descripcio_curta VARCHAR(200) NOT NULL,
  descripcio_llarga TEXT NOT NULL,
  PRIMARY KEY (id_producte,id_idioma),
  FOREIGN KEY (id_producte)
  	REFERENCES producte(id_producte)
  		ON DELETE CASCADE
  		ON UPDATE NO ACTION,
  FOREIGN KEY (id_idioma)
  	REFERENCES idioma(id_idioma)
  		ON DELETE RESTRICT
  		ON UPDATE NO ACTION
);


CREATE TABLE garantia (
  id_pais INTEGER NOT NULL,
  id_producte INTEGER NOT NULL,
  garantia INTEGER NOT NULL,
  PRIMARY KEY (id_pais,id_producte),
  FOREIGN KEY (id_pais)
  	REFERENCES pais(id_pais)
  		ON DELETE RESTRICT
  		ON UPDATE NO ACTION,
  FOREIGN KEY (id_producte)
  	REFERENCES producte(id_producte)
  		ON DELETE CASCADE
  		ON UPDATE NO ACTION
);


CREATE TABLE client (
  id_client INTEGER NOT NULL AUTO_INCREMENT,
  nif VARCHAR(12) NOT NULL,
  nom VARCHAR(50) NOT NULL,
  cognoms VARCHAR(200) NOT NULL,
  direccio VARCHAR(200) NOT NULL,
  cp VARCHAR(15) NOT NULL,
  poblacio VARCHAR(120) NOT NULL,
  id_provincia INTEGER NOT NULL,
  telefonf VARCHAR(15) NOT NULL,
  telefonm VARCHAR(15) DEFAULT NULL,
  correue VARCHAR(120) NOT NULL,
  observacions TEXT,
  PRIMARY KEY (id_client),
  UNIQUE KEY nif (nif),
  FOREIGN KEY (id_provincia)
  	REFERENCES provincia(id_provincia)
  		ON DELETE RESTRICT
  		ON UPDATE NO ACTION
);


CREATE TABLE sat (
  id_sat INTEGER NOT NULL AUTO_INCREMENT,
  nif VARCHAR(12) NOT NULL,
  nom VARCHAR(120) NOT NULL,
  direccio VARCHAR(200) NOT NULL,
  poblacio VARCHAR(120) NOT NULL,
  id_provincia INTEGER NOT NULL,
  cp VARCHAR(15) NOT NULL,
  telefon VARCHAR(15) NOT NULL,
  fax VARCHAR(15) NOT NULL,
  correue VARCHAR(120) NOT NULL,
  horari VARCHAR(120) NOT NULL,
  PRIMARY KEY (id_sat),
  UNIQUE KEY nif (nif),
  FOREIGN KEY (id_provincia)
  	REFERENCES provincia(id_provincia)
  		ON DELETE RESTRICT
  		ON UPDATE NO ACTION
);


CREATE TABLE recanvi (
  id_recanvi INTEGER NOT NULL AUTO_INCREMENT,
  codi VARCHAR(50)  NOT NULL,
  preu DOUBLE NOT NULL,
  PRIMARY KEY (id_recanvi),
  UNIQUE KEY codi (codi)
);


CREATE TABLE desc_recanvi (
  id_recanvi INTEGER NOT NULL,
  id_idioma INTEGER NOT NULL,
  descripcio_curta VARCHAR(200) NOT NULL,
  descripcio_llarga TEXT NOT NULL,
  PRIMARY KEY (id_recanvi,id_idioma),
  FOREIGN KEY (id_recanvi)
  	REFERENCES recanvi(id_recanvi)
  		ON DELETE CASCADE
  		ON UPDATE NO ACTION,
  FOREIGN KEY (id_idioma)
  	REFERENCES idioma(id_idioma)
  		ON DELETE RESTRICT
  		ON UPDATE NO ACTION
);


CREATE TABLE tipus_incidencia (
  id_tipus INTEGER NOT NULL AUTO_INCREMENT,
  PRIMARY KEY (id_tipus)
);  

  
CREATE TABLE desc_tipus_incidencia (
  id_tipus INTEGER NOT NULL,
  id_idioma INTEGER NOT NULL,
  descripcio VARCHAR(60)  NOT NULL,
  PRIMARY KEY (id_tipus, id_idioma),
  FOREIGN KEY (id_tipus)
  	REFERENCES tipus_incidencia(id_tipus)
  		ON DELETE CASCADE
  		ON UPDATE NO ACTION,
  FOREIGN KEY (id_idioma)
  	REFERENCES idioma(id_idioma)
  		ON DELETE RESTRICT
  		ON UPDATE NO ACTION
);


CREATE TABLE estat_incidencia (
  id_estat INTEGER NOT NULL AUTO_INCREMENT,
  PRIMARY KEY (id_estat)
);  


CREATE TABLE desc_estat_incidencia (
  id_estat INTEGER NOT NULL,
  id_idioma INTEGER NOT NULL,
  descripcio VARCHAR(60) NOT NULL,
  PRIMARY KEY (id_estat, id_idioma),
  FOREIGN KEY(id_estat)
    REFERENCES estat_incidencia(id_estat)
      ON DELETE RESTRICT
      ON UPDATE NO ACTION,
  FOREIGN KEY(id_idioma)
    REFERENCES idioma(id_idioma)
      ON DELETE RESTRICT
      ON UPDATE NO ACTION
);


CREATE TABLE incidencia (
  id_incidencia INTEGER NOT NULL AUTO_INCREMENT,
  id_client INTEGER NOT NULL,
  id_producte INTEGER NOT NULL,
  id_sat INTEGER NOT NULL,
  data_compra DATE NOT NULL,
  data_entrada TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
  data_sortida TIMESTAMP,
  garantia TINYINT(1) NOT NULL,
  id_tipus INTEGER NOT NULL,
  id_estat INTEGER NOT NULL,
  descripcio TEXT NOT NULL,
  PRIMARY KEY (id_incidencia),
  KEY id_client (id_client),
  KEY id_producte (id_producte),
  KEY id_sat (id_sat),
  FOREIGN KEY (id_client)
  	REFERENCES client(id_client)
  		ON DELETE RESTRICT
  		ON UPDATE NO ACTION,
  FOREIGN KEY (id_producte)
  	REFERENCES producte(id_producte)
  		ON DELETE RESTRICT
  		ON UPDATE NO ACTION,
  FOREIGN KEY (id_sat)
  	REFERENCES sat(id_sat)
  		ON DELETE RESTRICT
  		ON UPDATE NO ACTION,
  FOREIGN KEY (id_tipus)
  	REFERENCES tipus_incidencia(id_tipus)
  		ON DELETE RESTRICT
  		ON UPDATE NO ACTION,
  FOREIGN KEY (id_estat)
  	REFERENCES estat_incidencia(id_estat)
  		ON DELETE RESTRICT
  		ON UPDATE NO ACTION  
);


CREATE TABLE opinio (
  id_incidencia INTEGER NOT NULL,
  valoracio_sat INTEGER(1) NOT NULL,
  valoracio_producte INTEGER(1) NOT NULL,
  opinio TEXT,
  PRIMARY KEY (id_incidencia),
  FOREIGN KEY (id_incidencia)
  	REFERENCES incidencia(id_incidencia)
  		ON DELETE RESTRICT
  		ON UPDATE NO ACTION
 );


CREATE TABLE recanvis_incidencia (
  id_incidencia INTEGER NOT NULL,
  id_recanvi INTEGER NOT NULL,
  unitats INTEGER NOT NULL,
  preu_unitari INTEGER NOT NULL,
  PRIMARY KEY (id_incidencia, id_recanvi),
  FOREIGN KEY (id_incidencia)
  	REFERENCES incidencia(id_incidencia)
  		ON DELETE RESTRICT
  		ON UPDATE NO ACTION,
  FOREIGN KEY (id_recanvi)
  	REFERENCES recanvi(id_recanvi)
  		ON DELETE RESTRICT
  		ON UPDATE NO ACTION
);


CREATE TABLE estadistiques_client (
  id_client INTEGER NOT NULL,
  any INTEGER(4) NOT NULL,
  nombre INTEGER NOT NULL,
  garantia INTEGER NOT NULL,
  cost_total DOUBLE NOT NULL,
  cost_garantia DOUBLE NOT NULL,
  PRIMARY KEY (id_client,any),
  KEY any (any),
  FOREIGN KEY (id_client)
  	REFERENCES client(id_client)
  		ON DELETE RESTRICT
  		ON UPDATE NO ACTION
);


CREATE TABLE estadistiques_familia (
  id_familia INTEGER NOT NULL,
  any INTEGER(4) NOT NULL,
  mes INTEGER(2) NOT NULL,
  nombre INTEGER NOT NULL,
  garantia INTEGER NOT NULL,
  temps_total INTEGER NOT NULL,
  cost_total DOUBLE NOT NULL,
  cost_garantia DOUBLE NOT NULL,
  PRIMARY KEY (id_familia,any,mes),
  KEY any (any),
  KEY mes (mes),
  FOREIGN KEY (id_familia)
  	REFERENCES familia_producte(id_familia)
  		ON DELETE RESTRICT
  		ON UPDATE NO ACTION
);


CREATE TABLE estadistiques_incidencia (
  any INTEGER(4) NOT NULL,
  mes INTEGER(2) NOT NULL,
  nombre INTEGER NOT NULL,
  garantia INTEGER NOT NULL,
  temps_total INTEGER NOT NULL,
  cost_total DOUBLE NOT NULL,
  cost_garantia DOUBLE NOT NULL,
  nombre_valoracions INTEGER NOT NULL,
  total_valoracions INTEGER NOT NULL,
  PRIMARY KEY (any,mes)
);


CREATE TABLE estadistiques_tipus (
  id_tipus INTEGER NOT NULL,
  any INTEGER(4) NOT NULL,
  mes INTEGER(2) NOT NULL,
  nombre INTEGER NOT NULL,
  garantia INTEGER NOT NULL,
  temps_total INTEGER NOT NULL,
  cost_total DOUBLE NOT NULL,
  cost_garantia DOUBLE NOT NULL,
  PRIMARY KEY (id_tipus,any,mes),
  KEY any (any),
  KEY mes (any,mes),
  FOREIGN KEY (id_tipus)
  	REFERENCES tipus_incidencia(id_tipus)
  		ON DELETE RESTRICT
  		ON UPDATE NO ACTION  
);


CREATE TABLE estadistiques_provincia (
  id_provincia INTEGER NOT NULL,
  any INTEGER(4) NOT NULL,
  mes INTEGER(2) NOT NULL,
  nombre INTEGER NOT NULL,
  garantia INTEGER NOT NULL,
  PRIMARY KEY (id_provincia,any,mes),
  KEY any (any),
  KEY mes (any,mes),
  FOREIGN KEY (id_provincia)
  	REFERENCES provincia(id_provincia)
  		ON DELETE RESTRICT
  		ON UPDATE NO ACTION
);


CREATE TABLE estadistiques_pais (
  id_pais INTEGER NOT NULL,
  any INTEGER(4) NOT NULL,
  mes INTEGER(2) NOT NULL,
  nombre INTEGER NOT NULL,
  garantia INTEGER NOT NULL,
  temps_total INTEGER NOT NULL,
  cost_total DOUBLE NOT NULL,
  cost_garantia DOUBLE NOT NULL,
  nombre_valoracions INTEGER NOT NULL,
  total_valoracions INTEGER NOT NULL,
  PRIMARY KEY (id_pais,any,mes),
  KEY any (any),
  KEY mes (any,mes),
  FOREIGN KEY (id_pais)
  	REFERENCES pais(id_pais)
  		ON DELETE RESTRICT
  		ON UPDATE NO ACTION
);


CREATE TABLE estadistiques_producte (
  id_producte INTEGER NOT NULL,
  any INTEGER(4) NOT NULL,
  mes INTEGER(2) NOT NULL,
  nombre INTEGER NOT NULL,
  garantia INTEGER NOT NULL,
  temps_total INTEGER NOT NULL,
  cost_total DOUBLE NOT NULL,
  cost_garantia DOUBLE NOT NULL,
  nombre_valoracions INTEGER NOT NULL,
  total_valoracions INTEGER NOT NULL,
  PRIMARY KEY (id_producte,any,mes),
  KEY any (any),
  KEY mes (any,mes),
  FOREIGN KEY (id_producte)
  	REFERENCES producte(id_producte)
  		ON DELETE RESTRICT
  		ON UPDATE NO ACTION
);


CREATE TABLE estadistiques_recanvi (
  id_recanvi INTEGER NOT NULL,
  any INTEGER(4) NOT NULL,
  mes INTEGER(2) NOT NULL,
  nombre INTEGER NOT NULL,
  garantia INTEGER NOT NULL,
  cost_total DOUBLE NOT NULL,
  cost_garantia DOUBLE NOT NULL,
  PRIMARY KEY (id_recanvi,any,mes),
  KEY any (any),
  KEY mes (any,mes),
  FOREIGN KEY (id_recanvi)
  REFERENCES recanvi(id_recanvi)
  		ON DELETE RESTRICT
  		ON UPDATE NO ACTION
);


CREATE TABLE estadistiques_sat (
  id_sat INTEGER NOT NULL,
  any INTEGER(4) NOT NULL,
  mes INTEGER(2) NOT NULL,
  nombre INTEGER NOT NULL,
  garantia INTEGER NOT NULL,
  temps_total INTEGER NOT NULL,
  cost_total DOUBLE NOT NULL,
  cost_garantia DOUBLE NOT NULL,
  nombre_valoracions INTEGER NOT NULL,
  total_valoracions INTEGER NOT NULL,
  PRIMARY KEY (id_sat,any,mes),
  KEY any (any),
  KEY mes (any,mes),
  FOREIGN KEY (id_sat)
  	REFERENCES sat(id_sat)
  		ON DELETE RESTRICT
  		ON UPDATE NO ACTION
);


CREATE TABLE log (
  id_log INTEGER NOT NULL AUTO_INCREMENT,
  data TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
  procediment_emmagatzemat VARCHAR(240) NOT NULL,
  resultat_operacio INTEGER NOT NULL,
  PRIMARY KEY (id_log),
  KEY procediment_emmagatzemat(procediment_emmagatzemat)
);

-- Insertem el primer registre a la taula estat que representa el estat "Tancat";
INSERT INTO estat_incidencia () VALUES ();