/******************************************************************************
   NOM:      	altaPais
   
   PROPSIT:	Donar d'alta un pas a la base de dades.
   
******************************************************************************/
DROP PROCEDURE IF EXISTS altaPais;
DELIMITER //
CREATE PROCEDURE altaPais (
		IN nomPais VARCHAR(200),
		OUT resultat INTEGER)
BEGIN
	p:BEGIN
		DECLARE tot INTEGER;
		SET resultat = 99;

		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */
		IF nomPais IS NULL THEN
			SET resultat = 1;
			leave p;
		END IF;
		
		/* Eliminem espais a l'inici i fi de la variable */
		SELECT TRIM(nomPais) INTO nomPais;

		/* Cerquem si ja existeix el registre */
   		SELECT COUNT(*) INTO tot FROM pais WHERE nom_pais = nomPais;
   		
   		/* Si existeix el registre gravem error i sortim */	
   		IF tot > 0 THEN
   			SET resultat = 2;
   			leave p;
   		END IF;
   		
   		/* Insertem el registre */
   		INSERT INTO pais (nom_pais) VALUES (nomPais);
   		
   		/* Asignem el valor de sortida OK */
   		SET resultat = 0;
   		
   	END; # p: END;
	
   	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('altaPais',resultat);	
   
END //

DELIMITER ;


/******************************************************************************
   NOM:      	altaIdioma
   
   PROPSIT:	Donar d'alta un idioma a la base de dades.
   
******************************************************************************/
DROP PROCEDURE IF EXISTS altaIdioma;
DELIMITER //
CREATE PROCEDURE altaIdioma (
		IN nomIdioma VARCHAR(50),
		OUT resultat INTEGER)
BEGIN
	p:BEGIN
		DECLARE tot INTEGER;
		SET resultat = 99;
		
		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */
		IF nomIdioma IS NULL THEN
			SET resultat = 1;
			leave p;
		END IF;
		
		/* Eliminem espais a l'inici i fi de la variable */
   		SELECT TRIM(nomIdioma) INTO nomIdioma;
   		
   		/* Cerquem si ja existeix el registre */
   		SELECT COUNT(*) INTO tot FROM idioma WHERE nom_idioma = nomIdioma;
   		
   		/* Si existeix el registre gravem error i sortim */	
   		IF tot > 0 THEN
   			SET resultat = 2;
   			leave p;
   		END IF;
   		
   		/* Insertem el registre */
   		INSERT INTO idioma (nom_idioma) VALUES (nomIdioma);
   		
   		/* Asignem el valor de sortida OK */
   		SET resultat = 0;
   		
 	END; # p: END;

 	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('altaIdioma',resultat);
   
END //

DELIMITER ;
   

/******************************************************************************
   NOM:      	altaProvincia
   
   PROPSIT:	Donar d'alta una provncia a la base de dades.
   
******************************************************************************/
DROP PROCEDURE IF EXISTS altaProvincia;
DELIMITER //
CREATE PROCEDURE altaProvincia (
		IN idPais INTEGER,
		IN nomProvincia VARCHAR(60),
		OUT resultat INTEGER)

BEGIN
	p:BEGIN
		DECLARE tot INTEGER;
		SET resultat = 99;

		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */	
		IF idPais IS NULL OR nomProvincia IS NULL THEN 
			SET resultat = 1;
			leave p;
		END IF;

		/* Cerquem la clau externa */
   		SELECT COUNT(*) INTO tot FROM pais WHERE id_pais = idPais;
   		
   		/* Si no existeix la clau externa gravem error i sortim */
	   	IF tot = 0 THEN
   			SET resultat = 3;
   			leave p;
		END IF;

		/* Eliminem espais a l'inici i fi de la variable */
		SELECT TRIM(nomProvincia) INTO nomProvincia;
		
		/* Cerquem si ja existeix el registre */
		SELECT COUNT(*) INTO tot FROM provincia WHERE provincia = nomProvincia AND id_pais = idPais;
   		
		/* Si existeix el registre gravem error i sortim */	
	   	IF tot > 0 THEN
   			SET resultat = 2;
   			leave p;
		END IF;
		
		/* Insertem el registre */
		INSERT INTO provincia (id_pais, provincia) VALUES (idPais,nomProvincia);
		
		/* Asignem el valor de sortida OK */
		SET resultat = 0;
		
 	END; # p: END;

 	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('altaProvincia',resultat);
   	
END //

DELIMITER ;


/******************************************************************************
   NOM:      	altaFamiliaProducte
   
   PROPSIT:	Donar d'alta una famlia de productes a la base de dades.
   
******************************************************************************/
DROP PROCEDURE IF EXISTS altaFamiliaProducte;
DELIMITER //
CREATE PROCEDURE altaFamiliaProducte (OUT resultat INTEGER)
BEGIN
	p:BEGIN
		DECLARE tot INTEGER;
		SET resultat = 99;
		
		/* Insertem el registre */
		INSERT INTO familia_producte () VALUES ();
		
		/* Asignem el valor de sortida OK */
		SET resultat = 0;


	END; # p: END;

	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('altaFamiliaProducte',resultat);

END //

DELIMITER ;

/******************************************************************************
   NOM:      	altaDescripcioFamiliaProducte
   
   PROPSIT:	Donar d'alta la descripci d'una famlia de productes en un
   				idioma a la base de dades.
   				
******************************************************************************/
DROP PROCEDURE IF EXISTS altaDescripcioFamiliaProducte;
DELIMITER //
CREATE PROCEDURE altaDescripcioFamiliaProducte (
		IN idFamilia INTEGER,
		IN idIdioma INTEGER,
		IN fNom VARCHAR(60),
		IN fDescripcio TEXT,
		OUT resultat INTEGER)

BEGIN
	p:BEGIN
		DECLARE tot INTEGER;
		SET resultat = 99;
	
		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */
		IF idFamilia IS NULL OR idIdioma IS NULL OR fNom IS NULL THEN 
			SET resultat = 1;
			leave p;
		END IF;

		/* Cerquem la clau externa */
   		SELECT COUNT(*) INTO tot FROM familia_producte WHERE id_familia = idFamilia;
   		
   		/* Si no existeix la clau externa gravem error i sortim */
	   	IF tot = 0 THEN
   			SET resultat = 3;
   			leave p;
		END IF;

		/* Cerquem la clau externa */
   		SELECT COUNT(*) INTO tot FROM idioma WHERE id_idioma = idIdioma;
   		
   		/* Si no existeix la clau externa gravem error i sortim */
	   	IF tot = 0 THEN
   			SET resultat = 3;
   			leave p;
		END IF;
		
		/* Cerquem si ja existeix el registre */
		SELECT COUNT(*) INTO tot FROM desc_familia_producte WHERE id_familia = idFamilia AND id_idioma = idIdioma;
   		
		/* Si existeix el registre gravem error i sortim */	
	   	IF tot > 0 THEN
   			SET resultat = 2;
   			leave p;
		END IF;
	
		/* Eliminem espais a l'inici i fi de la variable */
		SELECT TRIM(fNom) INTO fNom;
		
		/* Cerquem si ja existeix el registre */
   		SELECT COUNT(*) INTO tot FROM desc_familia_producte WHERE id_idioma = idIdioma AND nom = fNom;
		
		/* Si existeix el registre gravem error i sortim */	
	   	IF tot > 0 THEN
   			SET resultat = 2;
   			leave p;
		END IF;
		
		/* Insertem el registre */
		INSERT INTO desc_familia_producte (id_familia,id_idioma,nom,descripcio) VALUES (idFamilia,idIdioma,fNom,fDescripcio);
		
		/* Asignem el valor de sortida OK */
		SET resultat = 0;

		
 	END; # p: END;

 	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('altaDescripcioFamiliaProducte',resultat);
   	
END //

DELIMITER ;


/******************************************************************************
   NOM:      	altaProducte
   
   PROPSIT:	Donar d'alta un producte a la base de dades.
   				
******************************************************************************/
DROP PROCEDURE IF EXISTS altaProducte;
DELIMITER //
CREATE PROCEDURE altaProducte (
		IN pCodi VARCHAR(30),
		IN idFamilia INTEGER,
		OUT resultat INTEGER)

BEGIN
	p:BEGIN
		DECLARE tot INTEGER;
		SET resultat = 99;
	
		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */
		IF pCodi IS NULL OR idFamilia IS NULL THEN 
			SET resultat = 1;
			leave p;
		END IF;

		/* Cerquem la clau externa */
   		SELECT COUNT(*) INTO tot FROM familia_producte WHERE id_familia = idFamilia;
   		
   		/* Si no existeix la clau externa gravem error i sortim */
	   	IF tot = 0 THEN
   			SET resultat = 3;
   			leave p;
		END IF;

		/* Eliminem espais a l'inici i fi de la variable */
		SELECT TRIM(pCodi) INTO pCodi;
		
		/* Cerquem si ja existeix el registre */
   		SELECT COUNT(*) INTO tot FROM producte WHERE codi = pCodi;
   		
   		/* Si existeix el registre gravem error i sortim */	
	   	IF tot > 0 THEN
   			SET resultat = 2;
   			leave p;
		END IF;
		
		/* Insertem el registre */
		INSERT INTO producte (codi,id_familia) VALUES (pCodi,idFamilia);
		
		/* Asignem el valor de sortida OK */
		SET resultat = 0;
		
 	END; # p: END;

 	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('altaProducte',resultat);
   	
END //

DELIMITER ;


/******************************************************************************
   NOM:      	altaDescripcioProducte
   
   PROPSIT:	Donar d'alta la descripci d'un producte en un idioma a la 
   				base de dades.
   				
******************************************************************************/
DROP PROCEDURE IF EXISTS altaDescripcioProducte;
DELIMITER //
CREATE PROCEDURE altaDescripcioProducte (
		IN idProducte INTEGER,
		IN idIdioma INTEGER,
		IN dCurta VARCHAR(200),
		IN dLlarga TEXT,
		OUT resultat INTEGER)

BEGIN
	p:BEGIN
		DECLARE tot INTEGER;
		SET resultat = 99;
	
		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */
		IF idProducte IS NULL OR idIdioma IS NULL OR dCurta IS NULL OR dLlarga IS NULL THEN 
			SET resultat = 1;
			leave p;
		END IF;

		/* Cerquem la clau externa */
   		SELECT COUNT(*) INTO tot FROM producte WHERE id_producte = idProducte;
   		
   		/* Si no existeix la clau externa gravem error i sortim */
	   	IF tot = 0 THEN
   			SET resultat = 3;
   			leave p;
		END IF;

		/* Cerquem la clau externa */
   		SELECT COUNT(*) INTO tot FROM idioma WHERE id_idioma = idIdioma;
   		
   		/* Si no existeix la clau externa gravem error i sortim */
	   	IF tot = 0 THEN
   			SET resultat = 3;
   			leave p;
		END IF;
		
		/* Cerquem si ja existeix el registre */
		SELECT COUNT(*) INTO tot FROM desc_producte WHERE id_producte = idProducte AND id_idioma = idIdioma;
   		
		/* Si existeix el registre gravem error i sortim */	
	   	IF tot > 0 THEN
   			SET resultat = 2;
   			leave p;
		END IF;
		
		/* Eliminem espais a l'inici i fi de la variable */
		SELECT TRIM(dCurta) INTO dCurta;
		
		/* Cerquem si ja existeix el registre */
   		SELECT COUNT(*) INTO tot FROM desc_producte WHERE id_idioma = idIdioma AND descripcio_curta = dCurta;
		
		/* Si existeix el registre gravem error i sortim */	
	   	IF tot > 0 THEN
   			SET resultat = 2;
   			leave p;
		END IF;
		
		/* Insertem el registre */
		INSERT INTO desc_producte (id_producte,id_idioma,descripcio_curta,descripcio_llarga) VALUES (idProducte,idIdioma,dCurta,dLlarga);
		
		/* Asignem el valor de sortida OK */
		SET resultat = 0;
		
 	END; # p: END;

 	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('altaDescripcioProducte',resultat);
   	
END //

DELIMITER ;


/******************************************************************************
   NOM:      	altaGarantia
   
   PROPSIT:	Donar d'alta la garantia d'un producte en un pas a la base
   				de dades.
   				
******************************************************************************/
DROP PROCEDURE IF EXISTS altaGarantia;
DELIMITER //
CREATE PROCEDURE altaGarantia (
		IN idPais INTEGER,
		IN idProducte INTEGER,
		IN tGarantia INTEGER,
		OUT resultat INTEGER)
BEGIN
	p:BEGIN
		DECLARE tot INTEGER;
		SET resultat = 99;
	
		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */
		IF idPais IS NULL OR idProducte IS NULL OR tGarantia IS NULL THEN 
			SET resultat = 1;
			leave p;
		END IF;
	
		/* Verifiquem que els valors estiguin dintre del rang, del contrari gravem error i sortim */
		IF tGarantia < 0 THEN
			SET resultat = 4;
			leave p;
		END IF;
		
		/* Cerquem la clau externa */
	   	SELECT COUNT(*) INTO tot FROM pais WHERE id_pais = idPais;
   		
	   	/* Si no existeix la clau externa gravem error i sortim */
   		IF tot = 0 THEN
   			SET resultat = 3;
	   		leave p;
		END IF;
		
		/* Cerquem la clau externa */
		SELECT COUNT(*) INTO tot FROM producte WHERE id_producte = idProducte;
   		
		/* Si no existeix la clau externa gravem error i sortim */
	   	IF tot = 0 THEN
   			SET resultat = 3;
   			leave p;
		END IF;
		
		/* Cerquem si ja existeix el registre */
		SELECT COUNT(*) INTO tot FROM garantia WHERE id_pais = idPais AND id_producte = idProducte;
   		
		/* Si existeix el registre gravem error i sortim */	
	   	IF tot > 0 THEN
   			SET resultat = 2;
   			leave p;
		END IF;
		
		/* Insertem el registre */
		INSERT INTO garantia (id_pais, id_producte, garantia) VALUES (idPais,idProducte,tGarantia);

				/* Asignem el valor de sortida OK */
		SET resultat = 0;
		
	END; # p: END;

	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('altaGarantia',resultat);
	
END //

DELIMITER ;


/******************************************************************************
   NOM:      	altaClient
   
   PROPSIT:	Donar d'alta un client a la base de dades.
   				
******************************************************************************/
DROP PROCEDURE IF EXISTS altaClient;
DELIMITER //
CREATE PROCEDURE altaClient (
		IN cNif VARCHAR(12),
		IN cNom VARCHAR(50),
		IN cCognoms VARCHAR(200),
		IN cDireccio VARCHAR(200),
		IN cCp VARCHAR(15),
		IN cPoblacio VARCHAR(120),
		IN idProvincia INTEGER,
		IN cTelefonf VARCHAR(15),
		IN cTelefonm VARCHAR(15),
		IN cCorreue VARCHAR(120),
		IN cObservacions TEXT,
		OUT resultat INTEGER)
BEGIN
	p:BEGIN
		DECLARE tot INTEGER;
		SET resultat = 99;
	
		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */
		IF cNIF IS NULL OR cNom IS NULL OR cCognoms IS NULL OR cDireccio IS NULL OR cCp IS NULL OR cPoblacio IS NULL OR idProvincia IS NULL OR cTelefonf IS NULL OR cCorreue IS NULL OR cObservacions IS NULL THEN 
			SET resultat = 1;
			leave p;
		END IF;
	
		/* Eliminem espais en blanc al inici i fi de les variables */
		SELECT TRIM(cNif) INTO cNif;
		SELECT TRIM(cNom) INTO cNom;
		SELECT TRIM(cCognoms) INTO cCognoms;
		SELECT TRIM(cCp) INTO cCp;
		SELECT TRIM(cPoblacio) INTO cPoblacio;
		SELECT TRIM(cTelefonf) INTO cTelefonf;
		SELECT TRIM(cTelefonm) INTO cTelefonm;
		SELECT TRIM(cCorreue) INTO cCorreue;
		
		/* Cerquem la clau externa */
	   	SELECT COUNT(*) INTO tot FROM provincia WHERE id_provincia = idProvincia;
   		
	   	/* Si no existeix la clau externa gravem error i sortim */
   		IF tot = 0 THEN
   			SET resultat = 3;
	   		leave p;
		END IF;
		
		/* Cerquem si ja existeix el registre */
		SELECT COUNT(*) INTO tot FROM client WHERE nif = cNif;
   		
		/* Si existeix el registre gravem error i sortim */	
	   	IF tot > 0 THEN
   			SET resultat = 2;
   			leave p;
		END IF;
		
		/* Insertem el registre */
		INSERT INTO client (nif,nom,cognoms,direccio,cp,poblacio,id_provincia,telefonf,telefonm,correue,observacions)
					VALUES (cNif,cNom,cCognoms,cDireccio,cCp,cPoblacio,idProvincia,cTelefonf,cTelefonm,cCorreue,cObservacions);

		/* Asignem el valor de sortida OK */
		SET resultat = 0;

	END; # p: END;

	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('altaClient',resultat);
	
END //

DELIMITER ;


/******************************************************************************
   NOM:      	altaSat
   
   PROPSIT:	Donar d'alta un SAT (servei atencici tcnica) a la base de
   				dades.
   				
******************************************************************************/
DROP PROCEDURE IF EXISTS altaSat;
DELIMITER //
CREATE PROCEDURE altaSat (
		IN sNif VARCHAR(12),
		IN sNom VARCHAR(120),
		IN sDireccio VARCHAR(200),
		IN sCp VARCHAR(15),
		IN sPoblacio VARCHAR(120),
		IN idProvincia INTEGER,
		IN sTelefon VARCHAR(15),
		IN sFax VARCHAR(15),
		IN sCorreue VARCHAR(120),
		IN sHorari VARCHAR(120),
		OUT resultat INTEGER)
BEGIN
	p:BEGIN
		DECLARE tot INTEGER;
		SET resultat = 99;
	
		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */
		IF sNIF IS NULL OR sNom IS NULL OR sDireccio IS NULL OR sCp IS NULL OR sPoblacio IS NULL OR idProvincia IS NULL OR sTelefon IS NULL OR sFax IS NULL OR sCorreue IS NULL OR sHorari IS NULL THEN 
			SET resultat = 1;
			leave p;
		END IF;
	
		/* Eliminem espais en blanc al inici i fi de les variables */
		SELECT TRIM(sNif) INTO sNif;
		SELECT TRIM(sNom) INTO sNom;
		SELECT TRIM(sCp) INTO sCp;
		SELECT TRIM(sPoblacio) INTO sPoblacio;
		SELECT TRIM(sTelefon) INTO sTelefon;
		SELECT TRIM(sFax) INTO sFax;
		SELECT TRIM(sCorreue) INTO sCorreue;
		SELECT TRIM(sHorari) INTO sHorari;
		
		/* Cerquem la clau externa */
	   	SELECT COUNT(*) INTO tot FROM provincia WHERE id_provincia = idProvincia;
   		
	   	/* Si no existeix la clau externa gravem error i sortim */
   		IF tot = 0 THEN
   			SET resultat = 3;
	   		leave p;
		END IF;
		
		/* Cerquem si ja existeix el registre */
		SELECT COUNT(*) INTO tot FROM sat WHERE nif = sNif;
   		
		/* Si existeix el registre gravem error i sortim */	
	   	IF tot > 0 THEN
   			SET resultat = 2;
   			leave p;
		END IF;
		
		/* Insertem el registre */
		INSERT INTO sat (nif,nom,direccio,cp,poblacio,id_provincia,telefon,fax,correue,horari)
				VALUES (sNif,sNom,sDireccio,sCp,sPoblacio,idProvincia,sTelefon,sFax,sCorreue,sHorari);

		/* Asignem el valor de sortida OK */
		SET resultat = 0;

	END; # p: END;

	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('altaSat',resultat);
	
END //

DELIMITER ;


/******************************************************************************
   NOM:      	altaRecanvi
   
   PROPSIT:	Donar d'alta un recanvi a la base de dades.
   				
******************************************************************************/
DROP PROCEDURE IF EXISTS altaRecanvi;
DELIMITER //
CREATE PROCEDURE altaRecanvi (
		IN rCodi VARCHAR(50),
		IN rPreu DOUBLE,
		OUT resultat INTEGER)
BEGIN
	p:BEGIN
		DECLARE tot INTEGER;
		SET resultat = 99;
	
		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */
		IF rCodi IS NULL OR rPreu IS NULL THEN 
			SET resultat = 1;
			leave p;
		END IF;
		
		/* Verifiquem que els valors estiguin dintre del rang, del contrari gravem error i sortim */
		IF rPreu < 0 THEN
			SET resultat = 4;
			leave p;
		END IF;
		
		/* Eliminem espais a l'inici i fi de la variable */
		SELECT TRIM(rCodi) INTO rCodi;
		
		/* Cerquem si ja existeix el registre */
		SELECT COUNT(*) INTO tot FROM recanvi WHERE codi = rCodi;
   		
		/* Si existeix el registre gravem error i sortim */	
	   	IF tot > 0 THEN
   			SET resultat = 2;
   			leave p;
		END IF;
		
		/* Insertem el registre */
		INSERT INTO recanvi (codi,preu) VALUES (rCodi,rPreu);

		/* Asignem el valor de sortida OK */
		SET resultat = 0;

	END; # p: END;

	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('altaRecanvi',resultat);

END //

DELIMITER ;


/******************************************************************************
   NOM:      	altaDescripcioRecanvi
   
   PROPSIT:	Donar d'alta la descripci d'un recanvi en un idioma a la
   				base de dades.
   				
******************************************************************************/
DROP PROCEDURE IF EXISTS altaDescripcioRecanvi;
DELIMITER //
CREATE PROCEDURE altaDescripcioRecanvi (
		IN idRecanvi INTEGER,
		IN idIdioma INTEGER,
		IN dCurta VARCHAR(200),
		IN dLlarga TEXT,
		OUT resultat INTEGER)
BEGIN
	p:BEGIN
		DECLARE tot INTEGER;
		SET resultat = 99;
	
		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */
		IF idRecanvi IS NULL OR idIdioma IS NULL OR dCurta IS NULL OR dLlarga IS NULL THEN 
			SET resultat = 1;
			leave p;
		END IF;
		
		/* Cerquem la clau externa */
	   	SELECT COUNT(*) INTO tot FROM recanvi WHERE id_recanvi = idRecanvi;
   		
	   	/* Si no existeix la clau externa gravem error i sortim */
   		IF tot = 0 THEN
   			SET resultat = 3;
	   		leave p;
		END IF;
	
		/* Cerquem la clau externa */
		SELECT COUNT(*) INTO tot FROM idioma WHERE id_idioma = idIdioma;
   		
		/* Si no existeix la clau externa gravem error i sortim */
   		IF tot = 0 THEN
   			SET resultat = 3;
	   		leave p;
		END IF;
		
		/* Cerquem si ja existeix el registre */
		SELECT COUNT(*) INTO tot FROM desc_recanvi WHERE id_recanvi = idRecanvi AND id_idioma = idIdioma;
   		
		/* Si existeix el registre gravem error i sortim */	
	   	IF tot > 0 THEN
   			SET resultat = 2;
   			leave p;
		END IF;
		
		/* Eliminem espais a l'inici i fi de la variable */
		SELECT TRIM(dCurta) INTO dCurta;
		
		/* Cerquem si ja existeix el registre */
   		SELECT COUNT(*) INTO tot FROM desc_recanvi WHERE id_idioma = idIdioma AND descripcio_curta = dCurta;
		
		/* Si existeix el registre gravem error i sortim */	
	   	IF tot > 0 THEN
   			SET resultat = 2;
   			leave p;
		END IF;
		
		/* Insertem el registre */
		INSERT INTO desc_recanvi (id_recanvi,id_idioma,descripcio_curta,descripcio_llarga) VALUES (idRecanvi,idIdioma,dCurta,dLlarga);

		/* Asignem el valor de sortida OK */
		SET resultat = 0;
		
	END; # p: END;

	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('altaDescripcioRecanvi',resultat);
	
END //

DELIMITER ;


/******************************************************************************
   NOM:      	altaTipusIncidencia
   
   PROPSIT:	Donar d'alta un tipus d'incidncia a la base de dades.
   				
******************************************************************************/
DROP PROCEDURE IF EXISTS altaTipusIncidencia;
DELIMITER //
CREATE PROCEDURE altaTipusIncidencia (OUT resultat INTEGER)
BEGIN
	p:BEGIN
		DECLARE tot INTEGER;
		SET resultat = 99;
		
		/* Insertem el registre */
		INSERT INTO tipus_incidencia () VALUES ();

		/* Asignem el valor de sortida OK */
		SET resultat = 0;

	END; # p: END;
	
	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('altaTipusIncidencia',resultat);

END //

DELIMITER ;


/******************************************************************************
   NOM:      	altaDescripcioTipusIncidencia
   
   PROPSIT:	Donar d'alta la descripci d'un tipus d'incidncia en un
   				idioma a la base de dades.
   				
******************************************************************************/
DROP PROCEDURE IF EXISTS altaDescripcioTipusIncidencia;
DELIMITER //
CREATE PROCEDURE altaDescripcioTipusIncidencia (
		IN idTipus INTEGER,
		IN idIdioma INTEGER,		
		IN tDescripcio VARCHAR(60),
		OUT resultat INTEGER)

BEGIN
	p:BEGIN
		DECLARE tot INTEGER;
		SET resultat = 99;
	
		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */
		IF idTipus IS NULL OR idIdioma IS NULL OR tDescripcio IS NULL THEN 
			SET resultat = 1;
			leave p;
		END IF;

		/* Cerquem la clau externa */
   		SELECT COUNT(*) INTO tot FROM tipus_incidencia WHERE id_tipus = idTipus;
   		
   		/* Si no existeix la clau externa gravem error i sortim */
	   	IF tot = 0 THEN
   			SET resultat = 3;
   			leave p;
		END IF;

		/* Cerquem la clau externa */
   		SELECT COUNT(*) INTO tot FROM idioma WHERE id_idioma = idIdioma;
   		
   		/* Si no existeix la clau externa gravem error i sortim */
	   	IF tot = 0 THEN
   			SET resultat = 3;
   			leave p;
		END IF;
		
		/* Cerquem si ja existeix el registre */
		SELECT COUNT(*) INTO tot FROM desc_tipus_incidencia WHERE id_tipus = idTipus AND id_idioma = idIdioma;
   		
		/* Si existeix el registre gravem error i sortim */	
	   	IF tot > 0 THEN
   			SET resultat = 2;
   			leave p;
		END IF;
		
		/* Eliminem espais a l'inici i fi de la variable */
		SELECT TRIM(tDescripcio) INTO tDescripcio;
		
		/* Cerquem si ja existeix el registre */
		SELECT COUNT(*) INTO tot FROM desc_tipus_incidencia WHERE id_idioma = idIdioma AND descripcio = tDescripcio;
   		
		/* Si existeix el registre gravem error i sortim */	
	   	IF tot > 0 THEN
   			SET resultat = 2;
   			leave p;
		END IF;
		
		/* Insertem el registre */
		INSERT INTO desc_tipus_incidencia (id_tipus,id_idioma,descripcio) VALUES (idTipus,idIdioma,tDescripcio);

		/* Asignem el valor de sortida OK */
		SET resultat = 0;
		
 	END; # p: END;

 	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('altaDescripcioTipusIncidencia',resultat);
   	
END //

DELIMITER ;


/******************************************************************************
   NOM:      	altaEstatIncidencia
   
   PROPSIT:	Donar d'alta un estat d'una incidncia a la base de dades.
   				
******************************************************************************/
DROP PROCEDURE IF EXISTS altaEstatIncidencia;
DELIMITER //
CREATE PROCEDURE altaEstatIncidencia (OUT resultat INTEGER)
BEGIN
	p:BEGIN
		DECLARE tot INTEGER;
		SET resultat = 99;
		
		/* Insertem el registre */
		INSERT INTO estat_incidencia () VALUES ();

		/* Asignem el valor de sortida OK */
		SET resultat = 0;

	END; # p: END;

	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('altaEstatIncidencia',resultat);

END //

DELIMITER ;


/******************************************************************************
   NOM:      	altaDescripcioEstatIncidencia
   
   PROPSIT:	Donar d'alta la descripci d'un estat d'una incidncia en un
   				idioma a la base de dades.
   				
******************************************************************************/  
DROP PROCEDURE IF EXISTS altaDescripcioEstatIncidencia;
DELIMITER //
CREATE PROCEDURE altaDescripcioEstatIncidencia (
		IN idEstat INTEGER,
		IN idIdioma INTEGER,		
		IN eDescripcio VARCHAR(60),
		OUT resultat INTEGER)

BEGIN
	p:BEGIN
		DECLARE tot INTEGER;
		SET resultat = 99;
	
		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */
		IF idEstat IS NULL OR idIdioma IS NULL OR eDescripcio IS NULL THEN 
			SET resultat = 1;
			leave p;
		END IF;

		/* Cerquem la clau externa */
   		SELECT COUNT(*) INTO tot FROM estat_incidencia WHERE id_estat = idEstat;
   		
   		/* Si no existeix la clau externa gravem error i sortim */
	   	IF tot = 0 THEN
   			SET resultat = 3;
   			leave p;
		END IF;

		/* Cerquem la clau externa */
   		SELECT COUNT(*) INTO tot FROM idioma WHERE id_idioma = idIdioma;
   		
   		/* Si no existeix la clau externa gravem error i sortim */
	   	IF tot = 0 THEN
   			SET resultat = 3;
   			leave p;
		END IF;
		
		/* Cerquem si ja existeix el registre */
		SELECT COUNT(*) INTO tot FROM desc_estat_incidencia WHERE id_estat = idEstat AND id_idioma = idIdioma;
   		
		/* Si existeix el registre gravem error i sortim */	
	   	IF tot > 0 THEN
   			SET resultat = 2;
   			leave p;
		END IF;
		
		/* Eliminem espais a l'inici i fi de la variable */
		SELECT TRIM(eDescripcio) INTO eDescripcio;
		
		/* Cerquem si ja existeix un registre igual */
		SELECT COUNT(*) INTO tot FROM desc_estat_incidencia WHERE id_idioma = idIdioma AND descripcio = eDescripcio;
   		
		/* Si existeix el registre gravem error i sortim */	
	   	IF tot > 0 THEN
   			SET resultat = 2;
   			leave p;
		END IF;
		
		/* Insertem el registre */
		INSERT INTO desc_estat_incidencia (id_estat,id_idioma,descripcio) VALUES (idEstat,idIdioma,eDescripcio);
		
		/* Asignem el valor de sortida OK */
		SET resultat = 0;
		
 	END; # p: END;

 	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('altaDescripcioEstatIncidencia',resultat);
   	
END //

DELIMITER ;


/******************************************************************************
   NOM:      	altaIncidencia
   
   PROPSIT:	Donar d'alta una incidncia a la base de dades.
   				
******************************************************************************/
DROP PROCEDURE IF EXISTS altaIncidencia;
DELIMITER //
CREATE PROCEDURE altaIncidencia (
		IN idClient INTEGER,
		IN idProducte INTEGER,
		IN idSat INTEGER,
		IN dCompra DATE,
		IN pGarantia TINYINT,
		IN idTipus INTEGER,
		IN idEstat INTEGER,
		IN iDescripcio TEXT,
		OUT resultat INTEGER)
BEGIN
	p:BEGIN
		DECLARE tot INTEGER;
		SET resultat = 99;
	
		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */
		IF idClient IS NULL OR idProducte IS NULL OR idSat IS NULL OR dCompra IS NULL OR pGarantia IS NULL OR idTipus IS NULL OR idEstat IS NULL OR iDescripcio IS NULL THEN 
			SET resultat = 1;
			leave p;
		END IF;
		
		/* Verifiquem que els valors estiguin dintre del rang, del contrari gravem error i sortim */
		IF pGarantia > 1 OR pGarantia < 0 THEN
			SET resultat = 4;
			leave p;
		END IF;

		/* Cerquem la clau externa */
		SELECT COUNT(*) INTO tot FROM client WHERE id_client = idClient;
		
		/* Si no existeix la clau externa gravem error i sortim */
		IF tot = 0 THEN
   			SET resultat = 3;
   			leave p;
		END IF;
		
		/* Cerquem la clau externa */
		SELECT COUNT(*) INTO tot FROM producte WHERE id_producte = idProducte;
   		
		/* Si no existeix la clau externa gravem error i sortim */
	   	IF tot = 0 THEN
   			SET resultat = 3;
   			leave p;
		END IF;
		
		/* Cerquem la clau externa */
		SELECT COUNT(*) INTO tot FROM sat WHERE id_sat = idSat;
		
		/* Si no existeix la clau externa gravem error i sortim */
		IF tot = 0 THEN
   			SET resultat = 3;
   			leave p;
		END IF;
		
		/* Cerquem la clau externa */
		SELECT COUNT(*) INTO tot FROM tipus_incidencia WHERE id_tipus = idTipus;
		
		/* Si no existeix la clau externa gravem error i sortim */
		IF tot = 0 THEN
   			SET resultat = 3;
   			leave p;
		END IF;
		
		/* Cerquem la clau externa */
		SELECT COUNT(*) INTO tot FROM estat_incidencia WHERE id_estat = idEstat;
		
		/* Si no existeix la clau externa gravem error i sortim */
		IF tot = 0 THEN
   			SET resultat = 3;
   			leave p;
		END IF;
		
		/* Cerquem si ja existeix el registre */
		SELECT COUNT(*) INTO tot FROM incidencia WHERE id_client = idClient AND id_producte = idProducte AND id_sat = idSat;
   		
		/* Si existeix el registre gravem error i sortim */	
	   	IF tot > 0 THEN
   			SET resultat = 2;
   			leave p;
		END IF;
		
		/* Insertem el registre */
		INSERT INTO incidencia (id_client,id_producte,id_sat,data_compra,garantia,id_tipus,id_estat,descripcio)
				 VALUES (idClient,idProducte,idSat,dCompra,pGarantia,idTipus,idEstat,iDescripcio);

		/* Asignem el valor de sortida OK */
		SET resultat = 0;

	END; # p: END;

	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('altaIncidencia',resultat);

END //

DELIMITER ;


/******************************************************************************
   NOM:      	altaOpinio
   
   PROPSIT:	Donar d'alta l'opini d'una incidncia a la base de dades.
   				
******************************************************************************/
DROP PROCEDURE IF EXISTS altaOpinio;
DELIMITER //
CREATE PROCEDURE altaOpinio (
		IN idIncidencia INTEGER,
		IN vSat INTEGER(1),
		IN vProducte INTEGER(1),
		IN oOpinio TEXT,
		OUT resultat INTEGER)
BEGIN
	p:BEGIN
		DECLARE tot INTEGER;
		SET resultat = 99;
	
		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */
		IF idIncidencia IS NULL OR vSat IS NULL OR vProducte IS NULL OR oOpinio IS NULL THEN 
			SET resultat = 1;
			leave p;
		END IF;
		
		/* Verifiquem que els valors estiguin dintre del rang, del contrari gravem error i sortim */
		IF vSat > 9 OR vSat < 0 OR vProducte > 9 OR vProducte < 0 THEN
   			SET resultat = 4;
   			leave p;
		END IF;
		
		/* Cerquem la clau externa */
		SELECT COUNT(*) INTO tot FROM incidencia WHERE id_incidencia = idIncidencia;
		
		/* Si no existeix la clau externa gravem error i sortim */
		IF tot = 0 THEN
   			SET resultat = 3;
   			leave p;
		END IF;
		
		/* Cerquem si ja existeix el registre */
		SELECT COUNT(*) INTO tot FROM opinio WHERE id_incidencia = idIncidencia;
   		
		/* Si existeix el registre gravem error i sortim */	
	   	IF tot > 0 THEN
   			SET resultat = 2;
   			leave p;
		END IF;
		
		/* Insertem el registre */		
		INSERT INTO opinio (id_incidencia,valoracio_sat,valoracio_producte,opinio)
				 VALUES (idIncidencia,vSat,vProducte,oOpinio);

		/* Asignem el valor de sortida OK */
		SET resultat = 0;

	END; # p: END;

	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('altaOpinio',resultat);

END //

DELIMITER ;


/******************************************************************************
   NOM:      	altaRecanviIncidencia
   
   PROPSIT:	Donar d'alta un recanvi en una incidncia a la base de dades.
   				
******************************************************************************/
DROP PROCEDURE IF EXISTS altaRecanviIncidencia;
DELIMITER //
CREATE PROCEDURE altaRecanviIncidencia (
		IN idIncidencia INTEGER,
		IN idRecanvi INTEGER,
		IN rUnitats INTEGER,
		IN preu INTEGER,
		OUT resultat INTEGER)
BEGIN
	p:BEGIN
		DECLARE tot INTEGER;
		SET resultat = 99;
	
		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */
		IF idIncidencia IS NULL OR idRecanvi IS NULL OR rUnitats IS NULL OR preu IS NULL THEN 
			SET resultat = 1;
			leave p;
		END IF;
		
		/* Verifiquem que els valors estiguin dintre del rang, del contrari gravem error i sortim */
		IF rUnitats < 0 OR preu < 0 THEN
   			SET resultat = 4;
   			leave p;
		END IF;
		
		/* Cerquem la clau externa */
		SELECT COUNT(*) INTO tot FROM incidencia WHERE id_incidencia = idIncidencia;
		
		/* Si no existeix la clau externa gravem error i sortim */
		IF tot = 0 THEN
   			SET resultat = 3;
   			leave p;
		END IF;
		
		/* Cerquem la clau externa */
		SELECT COUNT(*) INTO tot FROM recanvi WHERE id_recanvi = idRecanvi;
		
		/* Si no existeix la clau externa gravem error i sortim */
		IF tot = 0 THEN
   			SET resultat = 3;
   			leave p;
		END IF;
		
		/* Cerquem si ja existeix el registre */
		SELECT COUNT(*) INTO tot FROM recanvis_incidencia WHERE id_incidencia = idIncidencia AND id_recanvi = idRecanvi;
   		
		/* Si existeix el registre gravem error i sortim */	
	   	IF tot > 0 THEN
	   		SET resultat = 2;
	   		leave p;
	   	END IF;
	   	
	   	/* Insertem el registre */
	   	INSERT INTO recanvis_incidencia (id_incidencia,id_recanvi,unitats,preu_unitari)
			 VALUES (idIncidencia,idRecanvi,rUnitats,preu);

		/* Asignem el valor de sortida OK */
		SET resultat = 0;
		
	END; # p: END;

	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('altaRecanviIncidencia',resultat);

END //

DELIMITER ;

/******************************************************************************
******************************************************************************/
