/******************************************************************************
   NOM:      	tancarIncidencia
   
   PROPSIT:	Canvia l'estat de la incidncia demanada a "Tancat", omple el
   				camp data_sortida amb la data i hora actual i llena les 
   				estadstiques.
   				
   				Si totes les operacions no es realitzen correctament, no
   				s'enregistra cap estadstica ni en tancament de la incidncia.
   
******************************************************************************/
DROP PROCEDURE IF EXISTS tancarIncidencia;
DELIMITER //
CREATE PROCEDURE tancarIncidencia (
		IN idIncidencia INTEGER,
		OUT resultat INTEGER)
BEGIN
	p:BEGIN
		DECLARE idEstat INTEGER;
		
		SET resultat = 99;

		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */
		IF idIncidencia IS NULL THEN
			SET resultat = 1;
			leave p;
		END IF;
		
		/* Cerquem estat de la incidncia */
		SELECT id_estat INTO idEstat FROM incidencia WHERE id_incidencia = idIncidencia;
		
		/* Si id_estat s NULL -> no existeix la incidncia */
		IF idEstat IS NULL THEN
			SET resultat = 5;
			leave p;
		END IF;
		
		/* Mirem que l'estat de la incidncia no estigui ja tancada. L'estat que representa tancada s 1 per definici */
		IF idEstat = 1 THEN
			SET resultat = 12;
			leave p;
		END IF;		
		
		/* Iniciem transacci per assegurar que tot el proces es realitza conjuntament o no es fa res */
		START TRANSACTION;
		
			/* Actualitzem l'estat de la incidncia */
			UPDATE incidencia SET id_estat = 1, data_sortida = NOW() WHERE id_incidencia = idIncidencia;
		
			/* Cridem als Procediments Emmagatzemats d'Estadstiques i Insertem acci i resultat a la taula log */
			
			CALL altaEstadistiquesClient(idIncidencia,@res);			
			/* Cerquem errors, si no s'ha executat correctament l'estadistica no guardem res */
			IF @res != 0 THEN
				ROLLBACK;
				SET resultat = 13;
				leave p;
			END IF;
			
			CALL altaEstadistiquesSat(idIncidencia,@res);
			/* Cerquem errors, si no s'ha executat correctament l'estadistica no guardem res */
			IF @res != 0 THEN
				ROLLBACK;
				SET resultat = 13;
				leave p;
			END IF;
			
			CALL altaEstadistiquesProducte(idIncidencia,@res);
			/* Cerquem errors, si no s'ha executat correctament l'estadistica no guardem res */
			IF @res != 0 THEN
				ROLLBACK;
				SET resultat = 13;
				leave p;
			END IF;
			
			CALL altaEstadistiquesTipus(idIncidencia,@res);
			/* Cerquem errors, si no s'ha executat correctament l'estadistica no guardem res */
			IF @res != 0 THEN
				ROLLBACK;
				SET resultat = 13;
				leave p;
			END IF;
			
			CALL altaEstadistiquesIncidencia(idIncidencia,@res);
			/* Cerquem errors, si no s'ha executat correctament l'estadistica no guardem res */
			IF @res != 0 THEN
				ROLLBACK;
				SET resultat = 13;
				leave p;
			END IF;
			
			CALL altaEstadistiquesProvincia(idIncidencia,@res);
			/* Cerquem errors, si no s'ha executat correctament l'estadistica no guardem res */
			IF @res != 0 THEN
				ROLLBACK;
				SET resultat = 13;
				leave p;
			END IF;
			
			CALL altaEstadistiquesFamilia(idIncidencia,@res);
			/* Cerquem errors, si no s'ha executat correctament l'estadistica no guardem res */
			IF @res != 0 THEN
				ROLLBACK;
				SET resultat = 13;
				leave p;
			END IF;
			
			CALL altaEstadistiquesPais(idIncidencia,@res);
			/* Cerquem errors, si no s'ha executat correctament l'estadistica no guardem res */
			IF @res != 0 THEN
				ROLLBACK;
				SET resultat = 13;
				leave p;
			END IF;
			
			CALL altaEstadistiquesRecanvi(idIncidencia,@res);
			/* Cerquem errors, si no s'ha executat correctament l'estadistica no guardem res */
			IF @res != 0 THEN
				ROLLBACK;
				SET resultat = 13;
				leave p;
			END IF;
			
		COMMIT;
			
		/* Asignem el valor de sortida OK */
   		SET resultat = 0;
   		
   	END; # p: END;
	
   	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('altaEstadistiquesClient',resultat);	   
   
END //

DELIMITER ;

/******************************************************************************
******************************************************************************/