/******************************************************************************
   NOM:      	esborraPais
   
   PROPSIT:	Esborrar un pas a la base de dades.
   
******************************************************************************/
DROP PROCEDURE IF EXISTS esborraPais;
DELIMITER //
CREATE PROCEDURE esborraPais (
		IN idPais INTEGER,
		OUT resultat INTEGER)
BEGIN
	
	p:BEGIN
		DECLARE tot INTEGER;
		SET resultat = 99;

		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */
		IF idPais IS NULL THEN
			SET resultat = 1;
			leave p;
		END IF;
		
		/* Cerquem si existeix el registre a esborrar */
   		SELECT COUNT(*) INTO tot FROM pais WHERE id_pais = idPais;
   		
   		/* Si no existeix el registre gravem error i sortim */	
   		IF tot = 0 THEN
   			SET resultat = 5;
   			leave p;
   		END IF;

   		/* Cerquem a la taula relacionada si existeix cap registre amb aquesta clau forana */
   		SELECT COUNT(*) INTO tot FROM garantia WHERE id_pais = idPais;
   		
   		/* Si existeix el registre com a clau forana gravem error i sortim */	
		IF tot > 0 THEN
   			SET resultat = 7;
   			leave p;
   		END IF;
   		
   		/* Cerquem a la taula relacionada si existeix cap registre amb aquesta clau forana */
   		SELECT COUNT(*) INTO tot FROM provincia WHERE id_pais = idPais;
   		
   		/* Si existeix el registre com a clau forana gravem error i sortim */	
		IF tot > 0 THEN
   			SET resultat = 7;
   			leave p;
   		END IF;
   		
   		/* Cerquem a la taula relacionada si existeix cap registre amb aquesta clau forana */
   		SELECT COUNT(*) INTO tot FROM estadistiques_pais WHERE id_pais = idPais;
   		
   		/* Si existeix el registre com a clau forana gravem error i sortim */
		IF tot > 0 THEN
   			SET resultat = 7;
   			leave p;
   		END IF;
   		
   		/* Esborrem registre */
   		DELETE FROM pais WHERE id_pais = idPais;

   		 /* Asignem el valor de sortida OK */
		SET resultat = 0;
  		
   	END; # p: END;
	
   	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('esborraPais',resultat);	
   
END //

DELIMITER ;


/******************************************************************************
   NOM:      	esborraIdioma
   
   PROPSIT:	Esborrar un idioma a la base de dades.
   
******************************************************************************/
DROP PROCEDURE IF EXISTS esborraIdioma;
DELIMITER //
CREATE PROCEDURE esborraIdioma (
		IN idIdioma INTEGER,
		OUT resultat INTEGER)
BEGIN
	p:BEGIN
		DECLARE tot INTEGER;
		SET resultat = 99;
		
		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */
		IF idIdioma IS NULL THEN
			SET resultat = 1;
			leave p;
		END IF;
		
		/* Cerquem si existeix el registre a esborrar */
   		SELECT COUNT(*) INTO tot FROM idioma WHERE id_idioma = idIdioma;
   		
   		/* Si no existeix el registre gravem error i sortim */	
   		IF tot = 0 THEN
   			SET resultat = 5;
   			leave p;
   		END IF;
		
   		/* Cerquem a la taula relacionada si existeix cap registre amb aquesta clau forana */
   		SELECT COUNT(*) INTO tot FROM desc_familia_producte WHERE id_idioma = idIdioma;
   		
   		/* Si existeix el registre com a clau forana gravem error i sortim */
		IF tot > 0 THEN
   			SET resultat = 7;
   			leave p;
   		END IF;
   		
   		/* Cerquem a la taula relacionada si existeix cap registre amb aquesta clau forana */
   		SELECT COUNT(*) INTO tot FROM desc_producte WHERE id_idioma = idIdioma;
   		
   		/* Si existeix el registre com a clau forana gravem error i sortim */
		IF tot > 0 THEN
   			SET resultat = 7;
   			leave p;
   		END IF;

   		/* Cerquem a la taula relacionada si existeix cap registre amb aquesta clau forana */
   		SELECT COUNT(*) INTO tot FROM desc_recanvi WHERE id_idioma = idIdioma;
   		
   		/* Si existeix el registre com a clau forana gravem error i sortim */
		IF tot > 0 THEN
   			SET resultat = 7;
   			leave p;
   		END IF;
   		
   		/* Cerquem a la taula relacionada si existeix cap registre amb aquesta clau forana */
   		SELECT COUNT(*) INTO tot FROM desc_tipus_incidencia WHERE id_idioma = idIdioma;
   		
   		/* Si existeix el registre com a clau forana gravem error i sortim */
		IF tot > 0 THEN
   			SET resultat = 7;
   			leave p;
   		END IF;

		/* Cerquem a la taula relacionada si existeix cap registre amb aquesta clau forana */
   		SELECT COUNT(*) INTO tot FROM desc_estat_incidencia WHERE id_idioma = idIdioma;
   		
   		/* Si existeix el registre com a clau forana gravem error i sortim */
		IF tot > 0 THEN
   			SET resultat = 7;
   			leave p;
   		END IF;
   		
   		/* Esborrem el registre */
   		DELETE FROM idioma WHERE id_idioma = idIdioma;

   		 /* Asignem el valor de sortida OK */
		SET resultat = 0;
  		
 	END; # p: END;

 	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('esborraIdioma',resultat);
   
END //

DELIMITER ;
   

/******************************************************************************
   NOM:      	esborraProvincia
   
   PROPSIT:	Esborrar una provincia a la base de dades.
   
******************************************************************************/
DROP PROCEDURE IF EXISTS esborraProvincia;
DELIMITER //
CREATE PROCEDURE esborraProvincia (
		IN idProvincia INTEGER,
		OUT resultat INTEGER)

BEGIN
	p:BEGIN
		DECLARE tot INTEGER;
		SET resultat = 99;

		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */	
		IF idProvincia IS NULL THEN 
			SET resultat = 1;
			leave p;
		END IF;

		/* Cerquem si existeix el registre a esborrar */
   		SELECT COUNT(*) INTO tot FROM provincia WHERE id_provincia = idProvincia;
   		
   		/* Si no existeix el registre gravem error i sortim */	
   		IF tot = 0 THEN
   			SET resultat = 5;
   			leave p;
   		END IF;
		
		/* Cerquem a la taula relacionada si existeix cap registre amb aquesta clau forana */
   		SELECT COUNT(*) INTO tot FROM client WHERE id_provincia = idProvincia;
   		
   		/* Si existeix el registre com a clau forana gravem error i sortim */
		IF tot > 0 THEN
   			SET resultat = 7;
   			leave p;
   		END IF;

		/* Cerquem a la taula relacionada si existeix cap registre amb aquesta clau forana */
   		SELECT COUNT(*) INTO tot FROM sat WHERE id_provincia = idProvincia;
   		
   		/* Si existeix el registre com a clau forana gravem error i sortim */
		IF tot > 0 THEN
   			SET resultat = 7;
   			leave p;
   		END IF;
   		
   		/* Cerquem a la taula relacionada si existeix cap registre amb aquesta clau forana */
   		SELECT COUNT(*) INTO tot FROM estadistiques_provincia WHERE id_provincia = idProvincia;
   		
   		/* Si existeix el registre com a clau forana gravem error i sortim */
		IF tot > 0 THEN
   			SET resultat = 7;
   			leave p;
   		END IF;
		
		/* Esborrem el registre */
		DELETE FROM provincia WHERE id_provincia = idProvincia;

		/* Asignem el valor de sortida OK */
		SET resultat = 0;
		
 	END; # p: END;

 	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('esborraProvincia',resultat);
   	
END //

DELIMITER ;


/******************************************************************************
   NOM:      	esborraFamiliaProducte
   
   PROPSIT:	Esborrar una famlia de productes a la base de dades.
   
******************************************************************************/
DROP PROCEDURE IF EXISTS esborraFamiliaProducte;
DELIMITER //
CREATE PROCEDURE esborraFamiliaProducte (
		IN idFamilia INTEGER,
		OUT resultat INTEGER)

BEGIN
	p:BEGIN
		DECLARE tot INTEGER;
		SET resultat = 99;
	
		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */
		IF idFamilia IS NULL THEN 
			SET resultat = 1;
			leave p;
		END IF;
		
		/* Cerquem si existeix el registre a esborrar */
   		SELECT COUNT(*) INTO tot FROM familia_producte WHERE id_familia = idFamilia;
   		
   		/* Si no existeix el registre gravem error i sortim */	
   		IF tot = 0 THEN
   			SET resultat = 5;
   			leave p;
   		END IF;
		
		/* Cerquem a la taula relacionada si existeix cap registre amb aquesta clau forana */
   		SELECT COUNT(*) INTO tot FROM producte WHERE id_familia = idFamilia;
   		
   		/* Si existeix el registre com a clau forana gravem error i sortim */
		IF tot > 0 THEN
   			SET resultat = 7;
   			leave p;
   		END IF;

		/* Cerquem a la taula relacionada si existeix cap registre amb aquesta clau forana */
   		SELECT COUNT(*) INTO tot FROM estadistiques_familia WHERE id_familia = idFamilia;
   		
   		/* Si existeix el registre com a clau forana gravem error i sortim */
		IF tot > 0 THEN
   			SET resultat = 7;
   			leave p;
   		END IF;
   		
   		/* Esborrem el registre */
		DELETE FROM familia_producte WHERE id_familia = idFamilia;

		/* Asignem el valor de sortida OK */
		SET resultat = 0;
		
 	END; # p: END;

 	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('esborraFamiliaProducte',resultat);
   	
END //

DELIMITER ;


/******************************************************************************
   NOM:      	esborraDescripcioFamiliaProducte
   
   PROPSIT:	Esborrar la descripci d'una famlia de productes en un
   				idioma a la base de dades.
   				
******************************************************************************/
DROP PROCEDURE IF EXISTS esborraDescripcioFamiliaProducte;
DELIMITER //
CREATE PROCEDURE esborraDescripcioFamiliaProducte (
		IN idFamilia INTEGER,
		IN idIdioma INTEGER,
		OUT resultat INTEGER)

BEGIN
	p:BEGIN
		DECLARE tot INTEGER;
		SET resultat = 99;
	
		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */
		IF idFamilia IS NULL OR idIdioma THEN 
			SET resultat = 1;
			leave p;
		END IF;
		
		/* Cerquem si existeix el registre a esborrar */
   		SELECT COUNT(*) INTO tot FROM desc_familia_producte WHERE id_familia = idFamilia AND id_idioma = idIdioma;
   		
   		/* Si no existeix el registre gravem error i sortim */	
   		IF tot = 0 THEN
   			SET resultat = 5;
   			leave p;
   		END IF;	
   		   		
		/* Esborrem descripci el registre */
		DELETE FROM desc_familia_producte  WHERE id_familia = idFamilia AND id_idioma = idIdioma;		

		/* Asignem el valor de sortida OK */
		SET resultat = 0;
		
 	END; # p: END;

 	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('esborraDescripcioFamiliaProducte',resultat);
   	
END //

DELIMITER ;


/******************************************************************************
   NOM:      	esborraProducte
   
   PROPSIT:	Esborrar un producte a la base de dades.
   				
******************************************************************************/
DROP PROCEDURE IF EXISTS esborraProducte;
DELIMITER //
CREATE PROCEDURE esborraProducte (
		IN idProducte INTEGER,
		OUT resultat INTEGER)

BEGIN
	p:BEGIN
		DECLARE tot INTEGER;
		SET resultat = 99;
	
		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */
		IF idProducte IS NULL THEN 
			SET resultat = 1;
			leave p;
		END IF;

		/* Cerquem si existeix el registre a esborrar */
   		SELECT COUNT(*) INTO tot FROM producte WHERE id_producte = idProducte;
   		
   		/* Si no existeix el registre gravem error i sortim */	
   		IF tot = 0 THEN
   			SET resultat = 5;
   			leave p;
   		END IF;
				
		/* Cerquem a la taula relacionada si existeix cap registre amb aquesta clau forana */
   		SELECT COUNT(*) INTO tot FROM incidencies WHERE id_producte = idProducte;
   		
   		/* Si existeix el registre com a clau forana gravem error i sortim */
		IF tot > 0 THEN
   			SET resultat = 7;
   			leave p;
   		END IF;

		/* Cerquem a la taula relacionada si existeix cap registre amb aquesta clau forana */
   		SELECT COUNT(*) INTO tot FROM estadistiques_producte WHERE id_producte = idProducte;
   		
   		/* Si existeix el registre com a clau forana gravem error i sortim */
		IF tot > 0 THEN
   			SET resultat = 7;
   			leave p;
   		END IF;
   		
		/* Esborrem el registre */
		DELETE FROM producte WHERE id_producte = idProducte;

		/* Asignem el valor de sortida OK */
		SET resultat = 0;
		
 	END; # p: END;

 	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('esborraProducte',resultat);
   	
END //

DELIMITER ;


/******************************************************************************
   NOM:      	esborraDescripcioProducte
   
   PROPSIT:	Esborrar la descripci d'un producte en un idioma a la 
   				base de dades.
   				
******************************************************************************/
DROP PROCEDURE IF EXISTS esborraDescripcioProducte;
DELIMITER //
CREATE PROCEDURE esborraDescripcioProducte (
		IN idProducte INTEGER,
		IN idIdioma INTEGER,
		OUT resultat INTEGER)

BEGIN
	p:BEGIN
		DECLARE tot INTEGER;
		SET resultat = 99;
	
		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */
		IF idProducte IS NULL OR idIdioma THEN 
			SET resultat = 1;
			leave p;
		END IF;
		
		/* Cerquem si existeix el registre a esborrar */
		SELECT COUNT(*) INTO tot FROM desc_producte WHERE id_producte = idProducte AND id_idioma = idIdioma;
   		
   		/* Si no existeix el registre gravem error i sortim */	
   		IF tot = 0 THEN
   			SET resultat = 5;
   			leave p;
   		END IF;
		
		/* Esborrem el registre */
		DELETE FROM desc_producte WHERE id_producte = idProducte AND id_idioma = idIdioma;

		/* Asignem el valor de sortida OK */
		SET resultat = 0;
		
 	END; # p: END;

 	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('esborraDescripcioProducte',resultat);
   	
END //

DELIMITER ;


/******************************************************************************
   NOM:      	esborraGarantia
   
   PROPSIT:	Esborrar la garantia d'un producte en un pas a la base
   				de dades.
   				
******************************************************************************/
DROP PROCEDURE IF EXISTS esborraGarantia;
DELIMITER //
CREATE PROCEDURE esborraGarantia (
		IN idPais INTEGER,
		IN idProducte INTEGER,
		OUT resultat INTEGER)
BEGIN
	p:BEGIN
		DECLARE tot INTEGER;
		SET resultat = 99;
	
		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */
		IF idPais IS NULL OR idProducte IS NULL THEN 
			SET resultat = 1;
			leave p;
		END IF;

		/* Cerquem si existeix el registre a esborrar */
		SELECT COUNT(*) INTO tot FROM garantia WHERE id_producte = idProducte AND id_pais = idPais;
   		
   		/* Si no existeix el registre gravem error i sortim */	
   		IF tot = 0 THEN
   			SET resultat = 5;
   			leave p;
   		END IF;
		
		/* Esborrem el registre */
		DELETE FROM garantia WHERE id_producte = idProducte AND id_pais = idPais;

		/* Asignem el valor de sortida OK */
		SET resultat = 0;
		
	END; # p: END;

	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('esborraGarantia',resultat);
	
END //

DELIMITER ;


/******************************************************************************
   NOM:      	esborraClient
   
   PROPSIT:	Esborrar un client a la base de dades.
   				
******************************************************************************/
DROP PROCEDURE IF EXISTS esborraClient;
DELIMITER //
CREATE PROCEDURE esborraClient (
		IN idClient INTEGER,
		OUT resultat INTEGER)
BEGIN
	p:BEGIN
		DECLARE tot INTEGER;
		SET resultat = 99;
	
		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */
		IF idClient IS NULL THEN 
			SET resultat = 1;
			leave p;
		END IF;
	
		/* Cerquem si existeix el registre a esborrar */
		SELECT COUNT(*) INTO tot FROM client WHERE id_client = idClient;
   		
   		/* Si no existeix el registre gravem error i sortim */	
   		IF tot = 0 THEN
   			SET resultat = 5;
   			leave p;
   		END IF;
		
		/* Cerquem a la taula relacionada si existeix cap registre amb aquesta clau forana */
   		SELECT COUNT(*) INTO tot FROM incidencies WHERE id_client = idClient;
   		
   		/* Si existeix el registre com a clau forana gravem error i sortim */
		IF tot > 0 THEN
   			SET resultat = 7;
   			leave p;
   		END IF;

		/* Cerquem a la taula relacionada si existeix cap registre amb aquesta clau forana */
   		SELECT COUNT(*) INTO tot FROM estadistiques_client WHERE id_client = idClient;
   		
   		/* Si existeix el registre com a clau forana gravem error i sortim */
		IF tot > 0 THEN
   			SET resultat = 7;
   			leave p;
   		END IF;
   		
   		/* Esborrem el registre */
		DELETE FROM client WHERE id_client = idClient; 

		/* Asignem el valor de sortida OK */
		SET resultat = 0;

	END; # p: END;

	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('esborraClient',resultat);
	
END //

DELIMITER ;


/******************************************************************************
   NOM:      	esborraSat
   
   PROPSIT:	Esborrar un SAT (servei atencici tcnica) a la base de
   				dades.
   				
******************************************************************************/
DROP PROCEDURE IF EXISTS esborraSat;
DELIMITER //
CREATE PROCEDURE esborraSat (
		IN idSat INTEGER,
		OUT resultat INTEGER)
BEGIN
	p:BEGIN
		DECLARE tot INTEGER;
		SET resultat = 99;
	
		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */
		IF idSat IS NULL THEN 
			SET resultat = 1;
			leave p;
		END IF;
		
		/* Cerquem si existeix el registre a esborrar */
		SELECT COUNT(*) INTO tot FROM sat WHERE id_sat = idSat;
   		
   		/* Si no existeix el registre gravem error i sortim */	
   		IF tot = 0 THEN
   			SET resultat = 5;
   			leave p;
   		END IF;
		
		/* Cerquem a la taula relacionada si existeix cap registre amb aquesta clau forana */
   		SELECT COUNT(*) INTO tot FROM incidencies WHERE id_sat = idSat;
   		
   		/* Si existeix el registre com a clau forana gravem error i sortim */
		IF tot > 0 THEN
   			SET resultat = 7;
   			leave p;
   		END IF;

		/* Cerquem a la taula relacionada si existeix cap registre amb aquesta clau forana */
   		SELECT COUNT(*) INTO tot FROM estadistiques_sat WHERE id_sat = idSat;
   		
   		/* Si existeix el registre com a clau forana gravem error i sortim */
		IF tot > 0 THEN
   			SET resultat = 7;
   			leave p;
   		END IF;
   				
		/* Esborrem el registre */
		DELETE FROM sat WHERE id_sat = idSat; 

		/* Asignem el valor de sortida OK */
		SET resultat = 0;
		
	END; # p: END;

	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('esborraSat',resultat);
	
END //

DELIMITER ;


/******************************************************************************
   NOM:      	esborraRecanvi
   
   PROPSIT:	Esborrar un recanvi a la base de dades.
   				
******************************************************************************/
DROP PROCEDURE IF EXISTS esborraRecanvi;
DELIMITER //
CREATE PROCEDURE esborraRecanvi (
		IN idRecanvi INTEGER,
		OUT resultat INTEGER)
BEGIN
	p:BEGIN
		DECLARE tot INTEGER;
		SET resultat = 99;
	
		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */
		IF idRecanvi IS NULL THEN 
			SET resultat = 1;
			leave p;
		END IF;
		
		/* Cerquem si existeix el registre a esborrar */
		SELECT COUNT(*) INTO tot FROM recanvi WHERE id_recanvi = idRecanvi;
   		
   		/* Si no existeix el registre gravem error i sortim */	
   		IF tot = 0 THEN
   			SET resultat = 5;
   			leave p;
   		END IF;
		
		/* Cerquem a la taula relacionada si existeix cap registre amb aquesta clau forana */
   		SELECT COUNT(*) INTO tot FROM recanvis_incidencia WHERE id_recanvi = idRecanvi;
   		
   		/* Si existeix el registre com a clau forana gravem error i sortim */
		IF tot > 0 THEN
   			SET resultat = 7;
   			leave p;
   		END IF;

		/* Cerquem a la taula relacionada si existeix cap registre amb aquesta clau forana */
   		SELECT COUNT(*) INTO tot FROM estadistiques_recanvi WHERE id_recanvi = idRecanvi;
   		
   		/* Si existeix el registre com a clau forana gravem error i sortim */
		IF tot > 0 THEN
   			SET resultat = 7;
   			leave p;
   		END IF;
   		
		/* Esborrem el registre */
		DELETE FROM recanvi WHERE id_recanvi = idRecanvi;

		/* Asignem el valor de sortida OK */
		SET resultat = 0;

	END; # p: END;

	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('esborraRecanvi',resultat);

END //

DELIMITER ;


/******************************************************************************
   NOM:      	esborraDescripcioRecanvi
   
   PROPSIT:	Esborrar la descripci d'un recanvi en un idioma a la
   				base de dades.
   				
******************************************************************************/
DROP PROCEDURE IF EXISTS esborraDescripcioRecanvi;
DELIMITER //
CREATE PROCEDURE esborraDescripcioRecanvi (
		IN idRecanvi INTEGER,
		IN idIdioma INTEGER,
		OUT resultat INTEGER)
BEGIN
	p:BEGIN
		DECLARE tot INTEGER;
		SET resultat = 99;
	
		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */
		IF idRecanvi IS NULL OR idIdioma THEN 
			SET resultat = 1;
			leave p;
		END IF;
		
		/* Cerquem si existeix el registre a esborrar */
		SELECT COUNT(*) INTO tot FROM desc_recanvi WHERE id_recanvi = idRecanvi AND id_idioma = idIdioma;
   		
   		/* Si no existeix el registre gravem error i sortim */	
   		IF tot = 0 THEN
   			SET resultat = 5;
   			leave p;
   		END IF;
		
   		/* Esborrem el registre */
		DELETE FROM desc_recanvi WHERE id_recanvi = idRecanvi AND id_idioma = idIdioma;

		/* Asignem el valor de sortida OK */
		SET resultat = 0;
		
	END; # p: END;

	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('esborraDescripcioRecanvi',resultat);
	
END //

DELIMITER ;


/******************************************************************************
   NOM:      	esborraTipusIncidencia
   
   PROPSIT:	Esborrar un tipus d'incidncia a la base de dades.
   				
******************************************************************************/
DROP PROCEDURE IF EXISTS esborraTipusIncidencia;
DELIMITER //
CREATE PROCEDURE esborraTipusIncidencia (
		IN idTipus INTEGER,
		OUT resultat INTEGER)

BEGIN
	p:BEGIN
		DECLARE tot INTEGER;
		SET resultat = 99;
	
		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */
		IF idTipus IS NULL THEN 
			SET resultat = 1;
			leave p;
		END IF;
		
		/* Cerquem si existeix el registre a esborrar */
		SELECT COUNT(*) INTO tot FROM tipus_incidencia WHERE id_tipus = idTipus;
   		
   		/* Si no existeix el registre gravem error i sortim */	
   		IF tot = 0 THEN
   			SET resultat = 5;
   			leave p;
   		END IF;

		/* Cerquem a la taula relacionada si existeix cap registre amb aquesta clau forana */
   		SELECT COUNT(*) INTO tot FROM incidencia WHERE id_tipus = idTipus;
   		
   		/* Si existeix el registre com a clau forana gravem error i sortim */
		IF tot > 0 THEN
   			SET resultat = 7;
   			leave p;
   		END IF;

		/* Cerquem a la taula relacionada si existeix cap registre amb aquesta clau forana */
   		SELECT COUNT(*) INTO tot FROM estadistiques_tipus WHERE id_tipus = idTipus;
   		
   		/* Si existeix el registre com a clau forana gravem error i sortim */
		IF tot > 0 THEN
   			SET resultat = 7;
   			leave p;
   		END IF;
   		
		/* Esborrem el registre */
		DELETE FROM tipus_incidencia WHERE id_tipus = idTipus;

		/* Asignem el valor de sortida OK */
		SET resultat = 0;
	
 	END; # p: END;

 	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('esborraTipusIncidencia',resultat);
   	
END //

DELIMITER ;


/******************************************************************************
   NOM:      	esborraDescripcioTipusIncidencia
   
   PROPSIT:	Esborrar la descripci d'un tipus d'incidncia en un
   				idioma a la base de dades.
   				
******************************************************************************/
DROP PROCEDURE IF EXISTS esborraDescripcioTipusIncidencia;
DELIMITER //
CREATE PROCEDURE esborraDescripcioTipusIncidencia (
		IN idTipus INTEGER,
		IN idIdioma INTEGER,		
		OUT resultat INTEGER)

BEGIN
	p:BEGIN
		DECLARE tot INTEGER;
		SET resultat = 99;
	
		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */
		IF idTipus IS NULL OR idIdioma IS NULL THEN 
			SET resultat = 1;
			leave p;
		END IF;
		
		/* Cerquem si existeix el registre a esborrar */
		SELECT COUNT(*) INTO tot FROM desc_tipus_incidencia WHERE id_tipus = idTipus AND id_idioma = idIdioma;
   		
   		/* Si no existeix el registre gravem error i sortim */	
   		IF tot = 0 THEN
   			SET resultat = 5;
   			leave p;
   		END IF;
				
		/* Esborrem el registre */
		DELETE FROM desc_tipus_incidencia WHERE id_tipus = idTipus AND id_idioma = idIdioma;

		/* Asignem el valor de sortida OK */
		SET resultat = 0;
		
 	END; # p: END;

 	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('esborraDescripcioTipusIncidencia',resultat);
   	
END //

DELIMITER ;


/******************************************************************************
   NOM:      	esborraEstatIncidencia
   
   PROPSIT:	Esborrar un estat d'una incidncia a la base de dades.
   				
******************************************************************************/  
DROP PROCEDURE IF EXISTS esborraEstatIncidencia;
DELIMITER //
CREATE PROCEDURE esborraEstatIncidencia (
		IN idEstat INTEGER,
		OUT resultat INTEGER)

BEGIN
	p:BEGIN
		DECLARE tot INTEGER;
		SET resultat = 99;
	
		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */
		IF idEstat IS NULL THEN 
			SET resultat = 1;
			leave p;
		END IF;
		
		/* Cerquem si existeix el registre a esborrar */
		SELECT COUNT(*) INTO tot FROM desc_estat_incidencia WHERE id_estat = idEstat;
		   		
   		/* Si no existeix el registre gravem error i sortim */	
   		IF tot = 0 THEN
   			SET resultat = 5;
   			leave p;
   		END IF;

		/* Cerquem a la taula relacionada si existeix cap registre amb aquesta clau forana */
   		SELECT COUNT(*) INTO tot FROM incidencia WHERE id_estat = idEstat;
   		
   		/* Si existeix el registre com a clau forana gravem error i sortim */
		IF tot > 0 THEN
   			SET resultat = 7;
   			leave p;
   		END IF;
   		
		/* Esborrem el registre */
		DELETE FROM estat_incidencia WHERE id_estat = idEstat;

		/* Asignem el valor de sortida OK */
		SET resultat = 0;
	
 	END; # p: END;

 	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('esborraEstatIncidencia',resultat);
   	
END //

DELIMITER ;


/******************************************************************************
   NOM:      	esborraDescripcioEstatIncidencia
   
   PROPSIT:	Esborrar la descripci d'un estat d'una incidncia en un
   				idioma a la base de dades.
   				
******************************************************************************/  
DROP PROCEDURE IF EXISTS esborraDescripcioEstatIncidencia;
DELIMITER //
CREATE PROCEDURE esborraDescripcioEstatIncidencia (
		IN idEstat INTEGER,
		IN idIdioma INTEGER,
		OUT resultat INTEGER)

BEGIN
	p:BEGIN
		DECLARE tot INTEGER;
		SET resultat = 99;
	
		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */
		IF idEstat IS NULL OR idIdioma IS NULL THEN 
			SET resultat = 1;
			leave p;
		END IF;
		
		/* Cerquem si existeix el registre a esborrar */
		SELECT COUNT(*) INTO tot FROM desc_estat_incidencia WHERE id_estat = idEstat AND id_idioma = idIdioma;
		   		
   		/* Si no existeix el registre gravem error i sortim */	
   		IF tot = 0 THEN
   			SET resultat = 5;
   			leave p;
   		END IF;
		
		/* Esborrem el registre */
		DELETE FROM desc_estat_incidencia WHERE id_estat = idEstat AND id_idioma = idIdioma;

		/* Asignem el valor de sortida OK */
		SET resultat = 0;
		
 	END; # p: END;

 	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('esborraDescripcioEstatIncidencia',resultat);
   	
END //

DELIMITER ;


/******************************************************************************
   NOM:      	esborraIncidencia
   
   PROPSIT:	Esborrar una incidncia a la base de dades.
   				
******************************************************************************/
DROP PROCEDURE IF EXISTS esborraIncidencia;
DELIMITER //
CREATE PROCEDURE esborraIncidencia (
		IN idIncidencia INTEGER,
		OUT resultat INTEGER)
BEGIN
	p:BEGIN
		DECLARE tot INTEGER;
		SET resultat = 99;
	
		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */
		IF idIncidencia IS NULL THEN 
			SET resultat = 1;
			leave p;
		END IF;
		
		/* Cerquem si existeix el registre a esborrar */
		SELECT COUNT(*) INTO tot FROM incidencia WHERE id_incidencia = idIncidencia;
   		
   		/* Si no existeix el registre gravem error i sortim */	
   		IF tot = 0 THEN
   			SET resultat = 5;
   			leave p;
   		END IF;
   		
   		/* Cerquem a la taula relacionada si existeix cap registre amb aquesta clau forana */
   		SELECT COUNT(*) INTO tot FROM opinio WHERE id_incidencia = idIncidencia;
   		
   		/* Si existeix el registre com a clau forana gravem error i sortim */
		IF tot > 0 THEN
   			SET resultat = 7;
   			leave p;
   		END IF;

		/* Cerquem a la taula relacionada si existeix cap registre amb aquesta clau forana */
   		SELECT COUNT(*) INTO tot FROM recanvis_incidencia WHERE id_incidencia = idIncidencia;
   		
   		/* Si existeix el registre com a clau forana gravem error i sortim */
		IF tot > 0 THEN
   			SET resultat = 7;
   			leave p;
   		END IF;
		
		/* Esborrem el registre */
		DELETE FROM incidencia WHERE id_incidencia = idIncidencia;

		/* Asignem el valor de sortida OK */
		SET resultat = 0;
		
	END; # p: END;

	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('esborraIncidencia',resultat);

END //

DELIMITER ;


/******************************************************************************
   NOM:      	esborraOpinio
   
   PROPSIT:	Esborrar l'opini d'una incidncia a la base de dades.
   				
******************************************************************************/
DROP PROCEDURE IF EXISTS esborraOpinio;
DELIMITER //
CREATE PROCEDURE esborraOpinio (
		IN idOpinio INTEGER,
		OUT resultat INTEGER)
BEGIN
	p:BEGIN
		DECLARE tot INTEGER;
		SET resultat = 99;
	
		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */
		IF idOpinio IS NULL THEN 
			SET resultat = 1;
			leave p;
		END IF;
		
		/* Cerquem si existeix el registre a esborrar */
		SELECT COUNT(*) INTO tot FROM opinio WHERE id_opinio = idOpinio;
   		
   		/* Si no existeix el registre gravem error i sortim */	
   		IF tot = 0 THEN
   			SET resultat = 5;
   			leave p;
   		END IF;
		
		/* Esborrem el registre */
		DELETE FROM opinio WHERE id_opinio = idOpinio;

		/* Asignem el valor de sortida OK */
		SET resultat = 0;

	END; # p: END;

	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('esborraOpinio',resultat);

END //

DELIMITER ;


/******************************************************************************
   NOM:      	esborraRecanviIncidencia
   
   PROPSIT:	Esborrar un recanvi d'una incidncia a la base de dades.
   				
******************************************************************************/
DROP PROCEDURE IF EXISTS esborraRecanviIncidencia;
DELIMITER //
CREATE PROCEDURE esborraRecanviIncidencia (
		IN idIncidencia INTEGER,
		IN idRecanvi INTEGER,
		OUT resultat INTEGER)
BEGIN
	p:BEGIN
		DECLARE tot INTEGER;
		SET resultat = 99;
	
		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */
		IF idIncidencia IS NULL OR idRecanvi IS NULL THEN 
			SET resultat = 1;
			leave p;
		END IF;
		
		/* Cerquem si existeix el registre a esborrar */
		SELECT COUNT(*) INTO tot FROM recanvis_incidencia WHERE id_incidencia = idIncidencia AND id_recanvi = idRecanvi;
   		
   		/* Si no existeix el registre gravem error i sortim */	
   		IF tot = 0 THEN
   			SET resultat = 5;
   			leave p;
   		END IF;
		
	   	/* Esborrem el registre */
	   	DELETE FROM recanvis_incidencia	WHERE id_incidencia = idIncidencia AND id_recanvi = idRecanvi;

	   	/* Asignem el valor de sortida OK */
		SET resultat = 0;
		
	END; # p: END;

	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('esborraRecanviIncidencia',resultat);

END //

DELIMITER ;

/******************************************************************************
   NOM:      	esborraRecanvisIncidencia
   
   PROPSIT:	Esborrar tots els recanvis d'una incidncia a la base de dades.
   				
******************************************************************************/
DROP PROCEDURE IF EXISTS esborraRecanvisIncidencia;
DELIMITER //
CREATE PROCEDURE esborraRecanvisIncidencia (
		IN idIncidencia INTEGER,
		OUT resultat INTEGER)
BEGIN
	p:BEGIN
		DECLARE tot INTEGER;
		SET resultat = 99;
	
		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */
		IF idIncidencia IS NULL THEN 
			SET resultat = 1;
			leave p;
		END IF;
		
		/* Cerquem si existeix el registre a esborrar */
		SELECT COUNT(*) INTO tot FROM recanvis_incidencia WHERE id_incidencia = idIncidencia;
   		
   		/* Si no existeix el registre gravem error i sortim */	
   		IF tot = 0 THEN
   			SET resultat = 5;
   			leave p;
   		END IF;
		
	   	/* Esborrem el registre */
	   	DELETE FROM recanvis_incidencia	WHERE id_incidencia = idIncidencia;

	   	/* Asignem el valor de sortida OK */
		SET resultat = 0;
		
	END; # p: END;

	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('esborraRecanvisIncidencia',resultat);

END //

DELIMITER ;

/******************************************************************************
******************************************************************************/
