/******************************************************************************
   NOM:      	consultaPaisos
   
   PROPSIT:	Retornar una llista amb els pasos de la taula pasos.
   
******************************************************************************/
DROP PROCEDURE IF EXISTS consultaPaisos;
DELIMITER //
CREATE PROCEDURE consultaPaisos (OUT resultat INTEGER)
BEGIN
	p:BEGIN
		SET resultat = 99;

   		/* Realitzem cerca */
   		SELECT * FROM pais ORDER BY nom_pais;

   		/* Asignem el valor de sortida OK */
		SET resultat = 0;
   		   		
   	END; # p: END;
	
   	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('consultaPaisos',resultat);	
   
END //

DELIMITER ;


/******************************************************************************
   NOM:      	consultaPais
   
   PROPSIT:	Retornar les dades del pais demanat.
   
******************************************************************************/
DROP PROCEDURE IF EXISTS consultaPais;
DELIMITER //
CREATE PROCEDURE consultaPais (
		IN idPais INTEGER,
		OUT resultat INTEGER)
BEGIN
	p:BEGIN
		DECLARE tot INTEGER;
		SET resultat = 99;
		
		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */	
		IF idPais IS NULL THEN 
			SET resultat = 1;
			leave p;
		END IF;
		
   		/* Realitzem cerca */
   		SELECT * FROM pais WHERE id_pais = idPais;

   		/* Asignem el valor de sortida OK */
		SET resultat = 0;

   	END; # p: END;
	
   	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('consultaPais',resultat);	
   
END //

DELIMITER ;


/******************************************************************************
   NOM:      	consultaIdiomes
   
   PROPSIT:	Retornar una llista amb els idiomes de la taula idoma.
   
******************************************************************************/
DROP PROCEDURE IF EXISTS consultaIdiomes;
DELIMITER //
CREATE PROCEDURE consultaIdiomes (OUT resultat INTEGER)
BEGIN
	p:BEGIN		
		SET resultat = 99;
		
   		/* Realitzem cerca */
   		SELECT * FROM idioma ORDER BY nom_idioma;

   		/* Asignem el valor de sortida OK */
		SET resultat = 0;
	
 	END; # p: END;

 	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('consultaIdiomes',resultat);
   
END //

DELIMITER ;


/******************************************************************************
   NOM:      	consultaIdioma
   
   PROPSIT:	Retornar les dades del idioma demanat.
   
******************************************************************************/
DROP PROCEDURE IF EXISTS consultaIdioma;
DELIMITER //
CREATE PROCEDURE consultaIdioma (
		IN idIdioma INTEGER,
		OUT resultat INTEGER)
BEGIN
	p:BEGIN		
		SET resultat = 99;
		
		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */	
		IF idIdioma IS NULL THEN 
			SET resultat = 1;
			leave p;
		END IF;
		
   		/* Realitzem cerca */
   		SELECT * FROM idioma WHERE id_idioma = idIdioma;

   		/* Asignem el valor de sortida OK */
		SET resultat = 0;
		
 	END; # p: END;

 	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('consultaIdioma',resultat);
   
END //

DELIMITER ;


/******************************************************************************
   NOM:      	consultaProvinciesPais
   
   PROPSIT:	Retornar una llista amb les provncies del pas demanat.
   
******************************************************************************/
DROP PROCEDURE IF EXISTS consultaProvinciesPais;
DELIMITER //
CREATE PROCEDURE consultaProvinciesPais (
		IN idPais INTEGER,
		OUT resultat INTEGER)
BEGIN
	p:BEGIN
		SET resultat = 99;

		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */	
		IF idPais IS NULL THEN 
			SET resultat = 1;
			leave p;
		END IF;

		/* Realitzem cerca */
		SELECT * FROM provincia WHERE id_pais = idPais ORDER BY provincia;

		/* Asignem el valor de sortida OK */
		SET resultat = 0;
	
 	END; # p: END;

 	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('consultaProvinciesPais',resultat);
   	
END //

DELIMITER ;


/******************************************************************************
   NOM:      	consultaProvinciaPais
   
   PROPSIT:	Retornar les dades de la provincia demanada.
   
******************************************************************************/
DROP PROCEDURE IF EXISTS consultaProvinciaPais;
DELIMITER //
CREATE PROCEDURE consultaProvinciaPais (
		IN idProvincia INTEGER,
		OUT resultat INTEGER)
BEGIN
	p:BEGIN
		SET resultat = 99;

		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */	
		IF idProvincia IS NULL THEN 
			SET resultat = 1;
			leave p;
		END IF;

		/* Realitzem cerca */
		SELECT * FROM provincia WHERE id_provincia = idProvincia;

		/* Asignem el valor de sortida OK */
		SET resultat = 0;

 	END; # p: END;

 	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('consultaProvinciaPais',resultat);
   	
END //

DELIMITER ;


/******************************************************************************
   NOM:      	consultaFamiliesProducteIdioma
   
   PROPSIT:	Retornar una llista amb les families de productes del idioma
   				demanat.
   
******************************************************************************/
DROP PROCEDURE IF EXISTS consultaFamiliesProducteIdioma;
DELIMITER //
CREATE PROCEDURE consultaFamiliesProducteIdioma (
		IN idIdioma INTEGER,
		OUT resultat INTEGER)
BEGIN
	p:BEGIN
		DECLARE tot INTEGER;
		SET resultat = 99;

		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */	
		IF idIdioma IS NULL THEN 
			SET resultat = 1;
			leave p;
		END IF;
		
		/* Realitzem cerca */
		SELECT 	f.id_familia,
				d.nom,
				d.descripcio 
		FROM familia_producte f,desc_familia_producte d
		WHERE f.id_familia = d.id_familia AND d.id_idioma = idIdioma
		ORDER BY d.nom;

		/* Asignem el valor de sortida OK */
		SET resultat = 0;

	END; # p: END;

	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('consultaFamiliesProducteIdioma',resultat);

END //

DELIMITER ;

/******************************************************************************
   NOM:      	consultaFamiliaProducteIdioma
   
   PROPSIT:	Retornar les dades de la familia de producte del idioma
   				demanat.
   
******************************************************************************/
DROP PROCEDURE IF EXISTS consultaFamiliaProducteIdioma;
DELIMITER //
CREATE PROCEDURE consultaFamiliaProducteIdioma (
		IN idFamilia INTEGER,
		IN idIdioma INTEGER,
		OUT resultat INTEGER)

BEGIN
	p:BEGIN
		DECLARE tot INTEGER;
		SET resultat = 99;
	
		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */
		IF idFamilia IS NULL OR idIdioma IS NULL THEN 
			SET resultat = 1;
			leave p;
		END IF;
		
		/* Realitzem cerca */
		SELECT 	f.id_familia,
				d.nom,
				d.descripcio 
		FROM familia_producte f,desc_familia_producte d
		WHERE f.id_familia = d.id_familia AND d.id_idioma = idIdioma AND f.id_familia = idFamilia;

		/* Asignem el valor de sortida OK */
		SET resultat = 0;
		
 	END; # p: END;

 	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('consultaFamiliaProducteIdioma',resultat);
   	
END //

DELIMITER ;


/******************************************************************************
   NOM:      	consultaProducteIdioma
   
   PROPSIT:	Retornar les dades del producte demanat cercant pel id_producte
   				mateix.
   
******************************************************************************/
DROP PROCEDURE IF EXISTS consultaProducteIdioma;
DELIMITER //
CREATE PROCEDURE consultaProducteIdioma (
		IN idProducte INTEGER,
		IN idIdioma INTEGER,
		OUT resultat INTEGER)

BEGIN
	p:BEGIN
		DECLARE tot INTEGER;
		SET resultat = 99;
	
		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */
		IF idProducte IS NULL OR idIdioma IS NULL THEN 
			SET resultat = 1;
			leave p;
		END IF;

		/* Realitzem cerca */
		SELECT   p.id_producte,
				 p.codi,
				 d.descripcio_curta,
				 d.descripcio_llarga
		FROM producte p, desc_producte d
		WHERE p.id_producte = d.id_producte AND p.id_producte = idProducte AND d.id_idioma = idIdioma;
		
		/* Asignem el valor de sortida OK */
		SET resultat = 0;
		
 	END; # p: END;

 	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('consultaProducteIdioma',resultat);
   	
END //

DELIMITER ;


/******************************************************************************
   NOM:      	consultaProducteCodiIdioma
   
   PROPSIT:	Retornar les dades del producte demanat cercant pel codi del
   				mateix.
   
******************************************************************************/
DROP PROCEDURE IF EXISTS consultaProducteCodiIdioma;
DELIMITER //
CREATE PROCEDURE consultaProducteCodiIdioma (
		IN pCodi VARCHAR(30),
		IN idIdioma INTEGER,
		OUT resultat INTEGER)

BEGIN
	p:BEGIN
		DECLARE tot INTEGER;
		SET resultat = 99;
	
		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */
		IF pCodi IS NULL OR idIdioma IS NULL THEN 
			SET resultat = 1;
			leave p;
		END IF;
		
		/* Eliminem espais en blanc al inici i fi de les variables */
		SELECT TRIM(pCodi) INTO pCodi;

		/* Realitzem cerca */
		SELECT   p.id_producte,
				 p.codi,
				 d.descripcio_curta,
				 d.descripcio_llarga
		FROM producte p, desc_producte d
		WHERE p.id_producte = d.id_producte AND p.codi = pCodi AND d.id_idioma = idIdioma;
		
		/* Asignem el valor de sortida OK */
		SET resultat = 0;
		
 	END; # p: END;

 	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('consultaProducteCodiIdioma',resultat);
   	
END //

DELIMITER ;


/******************************************************************************
   NOM:      	consultaProductesFamiliaIdioma
   
   PROPSIT:	Retornar una llista dels productes que pertanyen a un familia
   				concreta amb les descripcions en l'idioma demanat.
   
******************************************************************************/
DROP PROCEDURE IF EXISTS consultaProducteFamiliaIdioma;
DELIMITER //
CREATE PROCEDURE consultaProducteFamiliaIdioma (
		IN idFamilia INTEGER,
		IN idIdioma INTEGER,
		OUT resultat INTEGER)

BEGIN
	p:BEGIN
		DECLARE tot INTEGER;
		SET resultat = 99;
	
		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */
		IF idFamilia IS NULL OR idIdioma IS NULL THEN 
			SET resultat = 1;
			leave p;
		END IF;
		
		/* Realitzem cerca */
		SELECT   p.id_producte,
				 p.codi,
				 d.descripcio_curta
		FROM producte p, desc_producte d
		WHERE p.id_producte = d.id_producte AND p.id_familia = idFamilia AND d.id_idioma = idIdioma
		ORDER BY d.descripcio_curta;
		
		/* Asignem el valor de sortida OK */
		SET resultat = 0;
		
 	END; # p: END;

 	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('consultaProducteFamiliaIdioma',resultat);
   	
END //

DELIMITER ;


/******************************************************************************
   NOM:      	consultaProductesIdioma
   
   PROPSIT:	Retornar una llista de tots els productes en l'idioma demanat.
   
******************************************************************************/
DROP PROCEDURE IF EXISTS consultaProductesIdioma;
DELIMITER //
CREATE PROCEDURE consultaProductesIdioma (
		IN idIdioma INTEGER,
		OUT resultat INTEGER)

BEGIN
	p:BEGIN
		DECLARE tot INTEGER;
		SET resultat = 99;
	
		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */
		IF idIdioma IS NULL THEN
			SET resultat = 1;
			leave p;
		END IF;
		
		/* Realitzem cerca */
		SELECT   p.id_producte,
				 p.codi,
				 d.descripcio_curta
		FROM producte p, desc_producte d
		WHERE p.id_producte = d.id_producte AND d.id_idioma = idIdioma
		ORDER BY d.descripcio_curta;
		
		/* Asignem el valor de sortida OK */
		SET resultat = 0;
	
 	END; # p: END;

 	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('consultaProductesIdioma',resultat);
   	
END //

DELIMITER ;


/******************************************************************************
   NOM:      	consultaGarantiaProductePais
   
   PROPSIT:	Retornar les dades de la garantia d'un producte en el pas
   				demanat.
   
******************************************************************************/
DROP PROCEDURE IF EXISTS consultaGarantiaProductePais;
DELIMITER //
CREATE PROCEDURE consultaGarantiaProductePais (
		IN idPais INTEGER,
		IN idProducte INTEGER,
		OUT resultat INTEGER)
BEGIN
	p:BEGIN
		DECLARE tot INTEGER;
		SET resultat = 99;
	
		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */
		IF idPais IS NULL OR idProducte IS NULL THEN 
			SET resultat = 1;
			leave p;
		END IF;
		
		/* Realitzem cerca */
		SELECT   p.id_producte,
				 g.garantia
		FROM producte p, garantia g
		WHERE p.id_producte = g.id_producte AND g.id_pais = idPais AND p.id_producte = idProducte;
		
		/* Asignem el valor de sortida OK */
		SET resultat = 0;
	
	END; # p: END;

	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('consultaGarantiaProductePais',resultat);
	
END //

DELIMITER ;


/******************************************************************************
   NOM:      	consultaGarantiaProductePaisos
   
   PROPSIT:	Retornar una llista amb la gatantia d'un producte a tots els 
   				pasos.
   
******************************************************************************/
DROP PROCEDURE IF EXISTS consultaGarantiaProductePaisos;
DELIMITER //
CREATE PROCEDURE consultaGarantiaProductePaisos (
		IN idProducte INTEGER,
		OUT resultat INTEGER)
BEGIN
	p:BEGIN
		DECLARE tot INTEGER;
		SET resultat = 99;
	
		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */
		IF idProducte IS NULL THEN 
			SET resultat = 1;
			leave p;
		END IF;
		
		/* Realitzem cerca */
		SELECT  p.nom_pais,
				g.garantia
		FROM pais p,garantia g
		WHERE p.id_pais = g.id_pais AND g.id_producte = idProducte
		ORDER BY nom_pais;
		
		/* Asignem el valor de sortida OK */
		SET resultat = 0;
	
	END; # p: END;

	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('consultaGarantiaProductePaisos',resultat);
	
END //

DELIMITER ;


/******************************************************************************
   NOM:      	consultaClient
   
   PROPSIT:	Retornar les dades del client demanat cercant pel id_producte
   				mateix.
   
******************************************************************************/
DROP PROCEDURE IF EXISTS consultaClient;
DELIMITER //
CREATE PROCEDURE consultaClient (
		IN idClient INTEGER,
		OUT resultat INTEGER)
BEGIN
	p:BEGIN
		SET resultat = 99;
	
		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */
		IF idClient IS NULL THEN 
			SET resultat = 1;
			leave p;
		END IF;

		/* Realitzem cerca */
		SELECT  c.id_client,
				c.nif,
				c.nom,
				c.cognoms,
				c.direccio,
				c.cp,
				c.poblacio,
				p.provincia,
				pa.nom_pais,
				c.telefonf,
				c.telefonm,
				c.correue,
				c.observacions
		FROM client c,provincia p, pais pa
		WHERE c.id_provincia = p.id_provincia AND
			  p.id_pais = pa.id_pais AND
			  c.id_client = idClient;

		/* Asignem el valor de sortida OK */
		SET resultat = 0;

	END; # p: END;

	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('consultaClient',resultat);
	
END //

DELIMITER ;


/******************************************************************************
   NOM:      	consultaClientNif
   
   PROPSIT:	Retornar les dades del client demanat cercant pel nif
   				mateix.
   
******************************************************************************/
DROP PROCEDURE IF EXISTS consultaClientNif;
DELIMITER //
CREATE PROCEDURE consultaClientNif (
		IN cNif INTEGER,
		OUT resultat INTEGER)
BEGIN
	p:BEGIN
		SET resultat = 99;
	
		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */
		IF cNif IS NULL THEN 
			SET resultat = 1;
			leave p;
		END IF;
		
		/* Eliminem espais en blanc al inici i fi de les variables */
		SELECT TRIM(cNif) INTO cNif;

		/* Realitzem cerca */
		SELECT  c.id_client,
				c.nif,
				c.nom,
				c.cognoms,
				c.direccio,
				c.cp,
				c.poblacio,
				p.provincia,
				pa.nom_pais,
				c.telefonf,
				c.telefonm,
				c.correue,
				c.observacions
		FROM client c,provincia p, pais pa
		WHERE c.id_provincia = p.id_provincia AND
			  p.id_pais = pa.id_pais AND
			  c.nif = cNif;

		/* Asignem el valor de sortida OK */
		SET resultat = 0;

	END; # p: END;

	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('consultaClientNif',resultat);
	
END //

DELIMITER ;


/******************************************************************************
   NOM:      	consultaClientsProvincia
   
   PROPSIT:	Retornar una llista de tots els client en la provincia demanada.
   
******************************************************************************/
DROP PROCEDURE IF EXISTS consultaClientsProvincia;
DELIMITER //
CREATE PROCEDURE consultaClientsProvincia (
		IN idProvincia INTEGER,
		OUT resultat INTEGER)
BEGIN
	p:BEGIN
		SET resultat = 99;
	
		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */
		IF idProvincia IS NULL THEN 
			SET resultat = 1;
			leave p;
		END IF;

		/* Realitzem cerca */
		SELECT  c.id_client,
				c.nif,
				c.nom,
				c.cognoms,
				c.direccio,
				c.cp,
				c.poblacio,
				p.provincia,
				pa.nom_pais,
				c.telefonf,
				c.telefonm,
				c.correue,
				c.observacions
		FROM client c,provincia p, pais pa
		WHERE c.id_provincia = p.id_provincia AND
			  p.id_pais = pa.id_pais AND
			  c.id_provincia = idProvincia
		ORDER by c.cognoms,c.nom;

		/* Asignem el valor de sortida OK */
		SET resultat = 0;

	END; # p: END;

	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('consultaClientsProvincia',resultat);
	
END //

DELIMITER ;


/******************************************************************************
   NOM:      	consultaClientsPais
   
   PROPSIT:	Retornar una llista de tots els client en el pas demanat.
   
******************************************************************************/
DROP PROCEDURE IF EXISTS consultaClientsPais;
DELIMITER //
CREATE PROCEDURE consultaClientsPais (
		IN idPais INTEGER,
		OUT resultat INTEGER)
BEGIN
	p:BEGIN
		SET resultat = 99;
	
		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */
		IF idPais IS NULL THEN 
			SET resultat = 1;
			leave p;
		END IF;

		/* Realitzem cerca */
		SELECT  c.id_client,
				c.nif,
				c.nom,
				c.cognoms,
				c.direccio,
				c.cp,
				c.poblacio,
				p.provincia,
				pa.nom_pais,
				c.telefonf,
				c.telefonm,
				c.correue,
				c.observacions
		FROM client c,provincia p, pais pa
		WHERE c.id_provincia = p.id_provincia AND
			  p.id_pais = pa.id_pais AND
			  pa.id_pais = idPais
		ORDER by c.cognoms,c.nom;

		/* Asignem el valor de sortida OK */
		SET resultat = 0;

	END; # p: END;

	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('consultaClientsPais',resultat);
	
END //

DELIMITER ;


/******************************************************************************
   NOM:      	consultaClients
   
   PROPSIT:	Retornar una llista de tots els client.
   
******************************************************************************/
DROP PROCEDURE IF EXISTS consultaClients;
DELIMITER //
CREATE PROCEDURE consultaClients (
		OUT resultat INTEGER)
BEGIN
	p:BEGIN
		SET resultat = 99;

		/* Realitzem cerca */
		SELECT  c.id_client,
				c.nif,
				c.nom,
				c.cognoms,
				c.direccio,
				c.cp,
				c.poblacio,
				p.provincia,
				pa.nom_pais,
				c.telefonf,
				c.telefonm,
				c.correue,
				c.observacions
		FROM client c,provincia p, pais pa
		WHERE c.id_provincia = p.id_provincia AND
			  p.id_pais = pa.id_pais
		ORDER by c.cognoms,c.nom;

		/* Asignem el valor de sortida OK */
		SET resultat = 0;

	END; # p: END;

	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('consultaClients',resultat);
	
END //

DELIMITER ;


/******************************************************************************
   NOM:      	consultaSat
   
   PROPSIT:	Retornar les dades del SAT demanat cercant pel id_sat del
   				mateix.
   
******************************************************************************/
DROP PROCEDURE IF EXISTS consultaSat;
DELIMITER //
CREATE PROCEDURE consultaSat (
		IN idSat INTEGER,
		OUT resultat INTEGER)
BEGIN
	p:BEGIN
		DECLARE tot INTEGER;
		SET resultat = 99;
	
		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */
		IF idSat IS NULL THEN 
			SET resultat = 1;
			leave p;
		END IF;

		/* Realitzem cerca */
		SELECT  s.id_sat,
				s.nif,
				s.nom,
				s.direccio,
				s.poblacio,
				s.cp,
				p.provincia,
				pa.nom_pais,
				s.telefon,
				s.fax,
				s.correue,
				s.horari
		FROM sat s,provincia p, pais pa
		WHERE s.id_provincia = p.id_provincia AND
			  p.id_pais = pa.id_pais AND
			  s.id_sat = idSat;
		
		/* Asignem el valor de sortida OK */
		SET resultat = 0;
		
	END; # p: END;

	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('consultaSat',resultat);
	
END //

DELIMITER ;


/******************************************************************************
   NOM:      	consultaSatNif
   
   PROPSIT:	Retornar les dades del SAT demanat cercant pel nif del mateix.
   
******************************************************************************/
DROP PROCEDURE IF EXISTS consultaSatNif;
DELIMITER //
CREATE PROCEDURE consultaSatNif (
		IN sNif VARCHAR(30),
		OUT resultat INTEGER)
BEGIN
	p:BEGIN
		DECLARE tot INTEGER;
		SET resultat = 99;
	
		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */
		IF sNif IS NULL THEN 
			SET resultat = 1;
			leave p;
		END IF;

		/* Eliminem espais en blanc al inici i fi de les variables */
		SELECT TRIM(sNif) INTO sNif;

		/* Realitzem cerca */
		SELECT  s.id_sat,
				s.nif,
				s.nom,
				s.direccio,
				s.poblacio,
				s.cp,
				p.provincia,
				pa.nom_pais,
				s.telefon,
				s.fax,
				s.correue,
				s.horari
		FROM sat s,provincia p, pais pa
		WHERE s.id_provincia = p.id_provincia AND
			  p.id_pais = pa.id_pais AND
			  s.nif = sNif;
		
		/* Asignem el valor de sortida OK */
		SET resultat = 0;
		
	END; # p: END;

	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('consultaSatNif',resultat);
	
END //

DELIMITER ;


/******************************************************************************
   NOM:      	consultaSatProvincia
   
   PROPSIT:	Retornar una llista de tots els SAT en la provincia demanada.
   
******************************************************************************/
DROP PROCEDURE IF EXISTS consultaSatProvincia;
DELIMITER //
CREATE PROCEDURE consultaSatProvincia (
		IN idProvincia INTEGER,
		OUT resultat INTEGER)
BEGIN
	p:BEGIN
		DECLARE tot INTEGER;
		SET resultat = 99;
	
		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */
		IF idProvincia IS NULL THEN 
			SET resultat = 1;
			leave p;
		END IF;

		/* Realitzem cerca */
		SELECT  s.id_sat,
				s.nif,
				s.nom,
				s.direccio,
				s.poblacio,
				s.cp,
				p.provincia,
				pa.nom_pais,
				s.telefon,
				s.fax,
				s.correue,
				s.horari
		FROM sat s,provincia p, pais pa
		WHERE s.id_provincia = p.id_provincia AND
			  p.id_pais = pa.id_pais AND
			  s.id_provincia = idProvincia
		ORDER BY s.nom;
		
		/* Asignem el valor de sortida OK */
		SET resultat = 0;
		
	END; # p: END;

	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('consultaSatProvincia',resultat);
	
END //

DELIMITER ;


/******************************************************************************
   NOM:      	consultaSatPais
   
   PROPSIT:	Retornar una llista de tots els SAT en el pas demanat.
   
******************************************************************************/
DROP PROCEDURE IF EXISTS consultaSatPais;
DELIMITER //
CREATE PROCEDURE consultaSatPais (
		IN idPais INTEGER,
		OUT resultat INTEGER)
BEGIN
	p:BEGIN
		DECLARE tot INTEGER;
		SET resultat = 99;
	
		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */
		IF idPais IS NULL THEN 
			SET resultat = 1;
			leave p;
		END IF;

		/* Realitzem cerca */
		SELECT  s.id_sat,
				s.nif,
				s.nom,
				s.direccio,
				s.poblacio,
				s.cp,
				p.provincia,
				pa.nom_pais,
				s.telefon,
				s.fax,
				s.correue,
				s.horari
		FROM sat s,provincia p, pais pa
		WHERE s.id_provincia = p.id_provincia AND
			  p.id_pais = pa.id_pais AND
			  pa.id_pais = idPais
		ORDER BY s.nom;
		
		/* Asignem el valor de sortida OK */
		SET resultat = 0;
		
	END; # p: END;

	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('consultaSatPais',resultat);
	
END //

DELIMITER ;


/******************************************************************************
   NOM:      	consultaSats
   
   PROPSIT:	Retornar una llista de tots els SAT.
   
******************************************************************************/
DROP PROCEDURE IF EXISTS consultaSats;
DELIMITER //
CREATE PROCEDURE consultaSats (
		OUT resultat INTEGER)
BEGIN
	p:BEGIN
		DECLARE tot INTEGER;
		SET resultat = 99;

		/* Realitzem cerca */
		SELECT  s.id_sat,
				s.nif,
				s.nom,
				s.direccio,
				s.poblacio,
				s.cp,
				p.provincia,
				pa.nom_pais,
				s.telefon,
				s.fax,
				s.correue,
				s.horari
		FROM sat s,provincia p, pais pa
		WHERE s.id_provincia = p.id_provincia AND
			  p.id_pais = pa.id_pais
		ORDER BY s.nom;
		
		/* Asignem el valor de sortida OK */
		SET resultat = 0;
		
	END; # p: END;

	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('consultaSats',resultat);
	
END //

DELIMITER ;


/******************************************************************************
   NOM:      	consultaRecanviIdioma
   
   PROPSIT:	Retornar les dades d'un recanvi en l'idioma demanat cercant pel
   				id_recanvi del mateix.
   
******************************************************************************/
DROP PROCEDURE IF EXISTS consultaRecanviIdioma;
DELIMITER //
CREATE PROCEDURE consultaRecanviIdioma (
		IN idRecanvi INTEGER,
		IN idIdioma INTEGER,
		OUT resultat INTEGER)
BEGIN
	p:BEGIN
		DECLARE tot INTEGER;
		SET resultat = 99;
	
		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */
		IF idRecanvi IS NULL OR idIdioma IS NULL THEN 
			SET resultat = 1;
			leave p;
		END IF;
		
		/* Realitzem cerca */
		SELECT  r.id_recanvi,
				r.codi,
				r.preu,
				d.descripcio_curta,
				d.descripcio_llarga
		FROM recanvi r, desc_recanvi d
		WHERE   r.id_recanvi = d.id_recanvi AND 
				d.id_idioma = idIdioma AND
				d.id_recanvi = idRecanvi;

		/* Asignem el valor de sortida OK */
		SET resultat = 0;

	END; # p: END;

	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('consultaRecanviIdioma',resultat);

END //

DELIMITER ;


/******************************************************************************
   NOM:      	consultaRecanviCodiIdioma
   
   PROPSIT:	Retornar les dades d'un recanvi en l'idioma demanat cercant pel
   				codi del mateix.
   
******************************************************************************/
DROP PROCEDURE IF EXISTS consultaRecanviCodiIdioma;
DELIMITER //
CREATE PROCEDURE consultaRecanviCodiIdioma (
		IN rCodi VARCHAR(50),
		IN idIdioma INTEGER,
		OUT resultat INTEGER)
BEGIN
	p:BEGIN
		DECLARE tot INTEGER;
		SET resultat = 99;
	
		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */
		IF rCodi IS NULL OR idIdioma IS NULL THEN 
			SET resultat = 1;
			leave p;
		END IF;
		
		/* Eliminem espais en blanc al inici i fi de les variables */
		SELECT TRIM(rCodi) INTO rCodi;
		
		/* Realitzem cerca */
		SELECT  r.id_recanvi,
				r.codi,
				r.preu,
				d.descripcio_curta,
				d.descripcio_llarga
		FROM recanvi r, desc_recanvi d
		WHERE   r.id_recanvi = d.id_recanvi AND 
				d.id_idioma = idIdioma AND
				r.codi = rCodi;

		/* Asignem el valor de sortida OK */
		SET resultat = 0;

	END; # p: END;

	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('consultaRecanviCodiIdioma',resultat);

END //

DELIMITER ;


/******************************************************************************
   NOM:      	consultaRecanvisIdioma
   
   PROPSIT:	Retornar la llista de recanvis amb les descripcions amb l'idioma
   				demanat.
   
******************************************************************************/
DROP PROCEDURE IF EXISTS consultaRecanvisIdioma;
DELIMITER //
CREATE PROCEDURE consultaRecanvisIdioma (
		IN idIdioma INTEGER,
		OUT resultat INTEGER)
BEGIN
	p:BEGIN
		DECLARE tot INTEGER;
		SET resultat = 99;
	
		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */
		IF idIdioma IS NULL THEN 
			SET resultat = 1;
			leave p;
		END IF;
		
		/* Realitzem cerca */
		SELECT  r.id_recanvi,
				r.codi,
				r.preu,
				d.descripcio_curta
		FROM recanvi r, desc_recanvi d
		WHERE   r.id_recanvi = d.id_recanvi AND 
				d.id_idioma = idIdioma
		ORDER BY d.descripcio_curta;

		/* Asignem el valor de sortida OK */
		SET resultat = 0;

	END; # p: END;

	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('consultaRecanvisIdioma',resultat);

END //

DELIMITER ;


/******************************************************************************
   NOM:      	consultaRecanviIdiomes
   
   PROPSIT:	Retornar les descripcions en tots els idiomes del recanvi 
   				demanat.
   
******************************************************************************/
DROP PROCEDURE IF EXISTS consultaRecanviIdiomes;
DELIMITER //
CREATE PROCEDURE consultaRecanviIdiomes (
		IN idRecanvi INTEGER,
		OUT resultat INTEGER)
BEGIN
	p:BEGIN
		DECLARE tot INTEGER;
		SET resultat = 99;
	
		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */
		IF idRecanvi IS NULL THEN 
			SET resultat = 1;
			leave p;
		END IF;
		
		/* Realitzem cerca */
		SELECT  d.descripcio_curta,
				i.nom_idioma,
				r.codi
		FROM recanvi r, desc_recanvi d, idioma i
		WHERE   r.id_recanvi = d.id_recanvi AND 
				d.id_idioma = i.id_idioma AND
				d.id_recanvi = idRecanvi
		ORDER BY d.descripcio_curta;

		/* Asignem el valor de sortida OK */
		SET resultat = 0;

	END; # p: END;

	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('consultaRecanviIdiomes',resultat);

END //

DELIMITER ;


/******************************************************************************
   NOM:      	consultaTipusIncidenciesIdioma
   
   PROPSIT:	Retornar una llista amb els tipus d'incidencia en l'idioma
   				demanat.
   
******************************************************************************/
DROP PROCEDURE IF EXISTS consultaTipusIncidenciesIdioma;
DELIMITER //
CREATE PROCEDURE consultaTipusIncidenciesIdioma (
		IN idIdioma INTEGER,
		OUT resultat INTEGER)
BEGIN
	p:BEGIN
		DECLARE tot INTEGER;
		SET resultat = 99;
		
		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */
		IF idIdioma IS NULL THEN 
			SET resultat = 1;
			leave p;
		END IF;
		
		/* Realitzem cerca */
		SELECT  t.id_tipus,
				d.descripcio 
		FROM 	tipus_incidencia t, desc_tipus_incidencia d
		WHERE	t.id_tipus = d.id_tipus AND
				d.id_idioma = idIdioma
		ORDER BY d.descripcio;

		/* Asignem el valor de sortida OK */
		SET resultat = 0;

	END; # p: END;
	
	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('consultaTipusIncidenciesIdioma',resultat);

END //

DELIMITER ;


/******************************************************************************
   NOM:      	consultaTipusIncidenciaIdioma
   
   PROPSIT:	Retornar les dades d'un tipus d'incidencia en l'idioma 
   				demanat.
   
******************************************************************************/
DROP PROCEDURE IF EXISTS consultaTipusIncidenciaIdioma;
DELIMITER //
CREATE PROCEDURE consultaTipusIncidenciaIdioma (
		IN idTipus INTEGER,
		IN idIdioma INTEGER,
		OUT resultat INTEGER)
BEGIN
	p:BEGIN
		DECLARE tot INTEGER;
		SET resultat = 99;
		
		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */
		IF idIdioma IS NULL OR idTipus IS NULL THEN 
			SET resultat = 1;
			leave p;
		END IF;
		
		/* Realitzem cerca */
		SELECT  t.id_tipus,
				d.descripcio 
		FROM 	tipus_incidencia t, desc_tipus_incidencia d
		WHERE	t.id_tipus = d.id_tipus AND
				d.id_idioma = idIdioma AND
				t.id_tipus = idTipus;

		/* Asignem el valor de sortida OK */
		SET resultat = 0;

	END; # p: END;
	
	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('consultaTipusIncidenciaIdioma',resultat);

END //

DELIMITER ;


/******************************************************************************
   NOM:      	consultaEstatsIncidenciesIdioma
   
   PROPSIT:	Retornar una llista amb els estats d'incidencia en l'idioma
   				demanat.
   
******************************************************************************/
DROP PROCEDURE IF EXISTS consultaEstatsIncidenciesIdioma;
DELIMITER //
CREATE PROCEDURE consultaEstatsIncidenciesIdioma (
		IN idIdioma INTEGER,
		OUT resultat INTEGER)
BEGIN
	p:BEGIN
		DECLARE tot INTEGER;
		SET resultat = 99;
		
		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */
		IF idIdioma IS NULL THEN 
			SET resultat = 1;
			leave p;
		END IF;
		
		/* Realitzem cerca */
		SELECT  e.id_estat,
				d.descripcio 
		FROM 	estat_incidencia e, desc_estat_incidencia d
		WHERE	e.id_estat = d.id_estat AND
				d.id_idioma = idIdioma
		ORDER BY d.descripcio;

		/* Asignem el valor de sortida OK */
		SET resultat = 0;

	END; # p: END;
	
	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('consultaEstatsIncidenciesIdioma',resultat);

END //

DELIMITER ;


/******************************************************************************
   NOM:      	consultaEstatIncidenciaIdioma
   
   PROPSIT:	Retornar les dades d'un estat d'incidencia en l'idioma 
   				demanat.
   
******************************************************************************/
DROP PROCEDURE IF EXISTS consultaEstatIncidenciaIdioma;
DELIMITER //
CREATE PROCEDURE consultaEstatIncidenciaIdioma (
		IN idEstat INTEGER,
		IN idIdioma INTEGER,
		OUT resultat INTEGER)
BEGIN
	p:BEGIN
		DECLARE tot INTEGER;
		SET resultat = 99;
		
		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */
		IF idIdioma IS NULL OR idEstat IS NULL THEN 
			SET resultat = 1;
			leave p;
		END IF;
		
		/* Realitzem cerca */
		SELECT  e.id_estat,
				d.descripcio 
		FROM 	estat_incidencia e, desc_estat_incidencia d
		WHERE	e.id_estat = d.id_estat AND
				d.id_idioma = idIdioma AND
				e.id_estat = idEstat;

		/* Asignem el valor de sortida OK */
		SET resultat = 0;

	END; # p: END;
	
	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('consultaEstatIncidenciaIdioma',resultat);

END //

DELIMITER ;


/******************************************************************************
   NOM:      	consultaIncidenciaIdioma
   
   PROPSIT:	Retornar les dades d'una incidncia en l'idioma demanat.
   
******************************************************************************/
DROP PROCEDURE IF EXISTS consultaIncidenciaIdioma;
DELIMITER //
CREATE PROCEDURE consultaIncidenciaIdioma (
		IN idIncidencia INTEGER,
		IN idIdioma INTEGER,
		OUT resultat INTEGER)
BEGIN
	p:BEGIN
		DECLARE tot INTEGER;		
		SET resultat = 99;
	
		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */
		IF idIncidencia IS NULL OR idIdioma IS NULL THEN 
			SET resultat = 1;
			leave p;
		END IF;
		
		/* Realitzem cerca */
		SELECT  i.id_incidencia,
				i.id_client,
				i.id_producte,
				i.id_sat,
				i.data_compra,
				i.data_entrada,
				i.data_sortida,
				i.garantia,
				dt.descripcio AS tipus,
				de.descripcio AS estat,
  				i.descripcio
  		FROM incidencia i,
  			 desc_tipus_incidencia dt,
  			 desc_estat_incidencia de
  		WHERE i.id_tipus = dt.id_tipus AND
  			  i.id_estat = de.id_estat AND
  			  dt.id_idioma = idIdioma AND
  			  de.id_idioma = idIdioma AND
  			  i.id_incidencia = idIncidencia;
  		
		/* Asignem el valor de sortida OK */
		SET resultat = 0;

	END; # p: END;
	
	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('consultaIncidenciaIdioma',resultat);

END //

DELIMITER ;


/******************************************************************************
   NOM:      	consultaIncidenciesClientIdioma
   
   PROPSIT:	Retornar les dades de les incidncies d'un client en l'idioma
   				demanat.
   
******************************************************************************/
DROP PROCEDURE IF EXISTS consultaIncidenciesClientIdioma;
DELIMITER //
CREATE PROCEDURE consultaIncidenciesClientIdioma (
		IN idClient INTEGER,
		IN idIdioma INTEGER,
		OUT resultat INTEGER)
BEGIN
	p:BEGIN
		DECLARE tot INTEGER;		
		SET resultat = 99;
	
		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */
		IF idClient IS NULL OR idIdioma IS NULL THEN 
			SET resultat = 1;
			leave p;
		END IF;
		
		/* Realitzem cerca */
		SELECT  i.id_incidencia,
				i.id_client,
				i.id_producte,
				i.id_sat,
				i.data_compra,
				i.data_entrada,
				i.data_sortida,
				i.garantia,
				dt.descripcio AS tipus,
				de.descripcio AS estat,
  				i.descripcio
  		FROM incidencia i,
  			 desc_tipus_incidencia dt,
  			 desc_estat_incidencia de
  		WHERE i.id_tipus = dt.id_tipus AND
  			  i.id_estat = de.id_estat AND
  			  dt.id_idioma = idIdioma AND
  			  de.id_idioma = idIdioma AND
  			  i.id_client = idClient
  		ORDER BY data_entrada DESC;
  		
		/* Asignem el valor de sortida OK */
		SET resultat = 0;

	END; # p: END;

	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('consultaIncidenciesClientIdioma',resultat);

END //

DELIMITER ;


/******************************************************************************
   NOM:      	consultaIncidenciesSatIdioma
   
   PROPSIT:	Retornar les dades de les incidncies d'un SAT en l'idioma
   				demanat.
   
******************************************************************************/
DROP PROCEDURE IF EXISTS consultaIncidenciesSatIdioma;
DELIMITER //
CREATE PROCEDURE consultaIncidenciesSatIdioma (
		IN idSat INTEGER,
		IN idIdioma INTEGER,
		OUT resultat INTEGER)
BEGIN
	p:BEGIN
		DECLARE tot INTEGER;		
		SET resultat = 99;
	
		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */
		IF idSat IS NULL OR idIdioma IS NULL THEN 
			SET resultat = 1;
			leave p;
		END IF;
		
		/* Realitzem cerca */
		SELECT  i.id_incidencia,
				i.id_client,
				i.id_producte,
				i.id_sat,
				i.data_compra,
				i.data_entrada,
				i.data_sortida,
				i.garantia,
				dt.descripcio AS tipus,
				de.descripcio AS estat,
  				i.descripcio
  		FROM incidencia i,
  			 desc_tipus_incidencia dt,
  			 desc_estat_incidencia de
  		WHERE i.id_tipus = dt.id_tipus AND
  			  i.id_estat = de.id_estat AND
  			  dt.id_idioma = idIdioma AND
  			  de.id_idioma = idIdioma AND
  			  i.id_sat = idSat
  		ORDER BY data_entrada DESC;
  		
		/* Asignem el valor de sortida OK */
		SET resultat = 0;

	END; # p: END;

	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('consultaIncidenciesSatIdioma',resultat);

END //

DELIMITER ;


/******************************************************************************
   NOM:      	consultaIncidenciesProducteIdioma
   
   PROPSIT:	Retornar les dades de les incidncies d'un producte en l'idioma
   				demanat.
   
******************************************************************************/
DROP PROCEDURE IF EXISTS consultaIncidenciesProducteIdioma;
DELIMITER //
CREATE PROCEDURE consultaIncidenciesProducteIdioma (
		IN idProducte INTEGER,
		IN idIdioma INTEGER,
		OUT resultat INTEGER)
BEGIN
	p:BEGIN
		DECLARE tot INTEGER;		
		SET resultat = 99;
	
		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */
		IF idProducte IS NULL OR idIdioma IS NULL THEN 
			SET resultat = 1;
			leave p;
		END IF;
		
		/* Realitzem cerca */
		SELECT  i.id_incidencia,
				i.id_client,
				i.id_producte,
				i.id_sat,
				i.data_compra,
				i.data_entrada,
				i.data_sortida,
				i.garantia,
				dt.descripcio AS tipus,
				de.descripcio AS estat,
  				i.descripcio
  		FROM incidencia i,
  			 desc_tipus_incidencia dt,
  			 desc_estat_incidencia de
  		WHERE i.id_tipus = dt.id_tipus AND
  			  i.id_estat = de.id_estat AND
  			  dt.id_idioma = idIdioma AND
  			  de.id_idioma = idIdioma AND
  			  i.id_producte = idProducte
  		ORDER BY data_entrada DESC;
  		
		/* Asignem el valor de sortida OK */
		SET resultat = 0;

	END; # p: END;

	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('consultaIncidenciesProducteIdioma',resultat);

END //

DELIMITER ;


/******************************************************************************
   NOM:      	consultaIncidenciesTipusIdioma
   
   PROPSIT:	Retornar les dades de les incidncies d'un tipus d'incidncia
   				en l'idioma demanat.
   
******************************************************************************/
DROP PROCEDURE IF EXISTS consultaIncidenciesTipusIdioma;
DELIMITER //
CREATE PROCEDURE consultaIncidenciesTipusIdioma (
		IN idTipus INTEGER,
		IN idIdioma INTEGER,
		OUT resultat INTEGER)
BEGIN
	p:BEGIN
		DECLARE tot INTEGER;		
		SET resultat = 99;
	
		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */
		IF idTipus IS NULL OR idIdioma IS NULL THEN 
			SET resultat = 1;
			leave p;
		END IF;
		
		/* Realitzem cerca */
		SELECT  i.id_incidencia,
				i.id_client,
				i.id_producte,
				i.id_sat,
				i.data_compra,
				i.data_entrada,
				i.data_sortida,
				i.garantia,
				dt.descripcio AS tipus,
				de.descripcio AS estat,
  				i.descripcio
  		FROM incidencia i,
  			 desc_tipus_incidencia dt,
  			 desc_estat_incidencia de
  		WHERE i.id_tipus = dt.id_tipus AND
  			  i.id_estat = de.id_estat AND
  			  dt.id_idioma = idIdioma AND
  			  de.id_idioma = idIdioma AND
  			  i.id_tipus = idTipus
  		ORDER BY data_entrada DESC;
  		
		/* Asignem el valor de sortida OK */
		SET resultat = 0;

	END; # p: END;

	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('consultaIncidenciesTipusIdioma',resultat);

END //

DELIMITER ;


/******************************************************************************
   NOM:      	consultaIncidenciesEstatIdioma
   
   PROPSIT:	Retornar les dades de les incidncies d'un estat d'incidncia
   				en l'idioma demanat.
   
******************************************************************************/
DROP PROCEDURE IF EXISTS consultaIncidenciesEstatIdioma;
DELIMITER //
CREATE PROCEDURE consultaIncidenciesEstatIdioma (
		IN idEstat INTEGER,
		IN idIdioma INTEGER,
		OUT resultat INTEGER)
BEGIN
	p:BEGIN
		DECLARE tot INTEGER;		
		SET resultat = 99;
	
		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */
		IF idEstat IS NULL OR idIdioma IS NULL THEN 
			SET resultat = 1;
			leave p;
		END IF;
		
		/* Realitzem cerca */
		SELECT  i.id_incidencia,
				i.id_client,
				i.id_producte,
				i.id_sat,
				i.data_compra,
				i.data_entrada,
				i.data_sortida,
				i.garantia,
				dt.descripcio AS tipus,
				de.descripcio AS estat,
  				i.descripcio
  		FROM incidencia i,
  			 desc_tipus_incidencia dt,
  			 desc_estat_incidencia de
  		WHERE i.id_tipus = dt.id_tipus AND
  			  i.id_estat = de.id_estat AND
  			  dt.id_idioma = idIdioma AND
  			  de.id_idioma = idIdioma AND
  			  i.id_estat = idEstat
  		ORDER BY data_entrada DESC;
  		
		/* Asignem el valor de sortida OK */
		SET resultat = 0;

	END; # p: END;

	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('consultaIncidenciesEstatIdioma',resultat);

END //

DELIMITER ;


/******************************************************************************
   NOM:      	consultaIncidenciesPaisIdioma
   
   PROPSIT:	Retornar les dades de les incidncies d'un pas en l'idioma
   				demanat.
   
******************************************************************************/
DROP PROCEDURE IF EXISTS consultaIncidenciesPaisIdioma;
DELIMITER //
CREATE PROCEDURE consultaIncidenciesPaisIdioma (
		IN idPais INTEGER,
		IN idIdioma INTEGER,
		OUT resultat INTEGER)
BEGIN
	p:BEGIN
		DECLARE tot INTEGER;		
		SET resultat = 99;
	
		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */
		IF idPais IS NULL OR idIdioma IS NULL THEN 
			SET resultat = 1;
			leave p;
		END IF;
		
		/* Realitzem cerca */
		SELECT  i.id_incidencia,
				i.id_client,
				i.id_producte,
				i.id_sat,
				i.data_compra,
				i.data_entrada,
				i.data_sortida,
				i.garantia,
				dt.descripcio AS tipus,
				de.descripcio AS estat,
  				i.descripcio
  		FROM incidencia i,
  			 sat s,
  			 provincia p,
  			 desc_tipus_incidencia dt,
  			 desc_estat_incidencia de
  		WHERE i.id_sat = s.id_sat AND
  			  s.id_provincia = p.id_provincia AND
              i.id_tipus = dt.id_tipus AND
  			  i.id_estat = de.id_estat AND
  			  dt.id_idioma = idIdioma AND
  			  de.id_idioma = idIdioma AND
  			  p.id_pais = idPais  			  
  		ORDER BY data_entrada DESC;
  		
		/* Asignem el valor de sortida OK */
		SET resultat = 0;

	END; # p: END;

	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('consultaIncidenciesPaisIdioma',resultat);

END //

DELIMITER ;


/******************************************************************************
   NOM:      	consultaIncidenciesProvinciaIdioma
   
   PROPSIT:	Retornar les dades de les incidncies d'una provincia en
   				l'idioma demanat.
   
******************************************************************************/
DROP PROCEDURE IF EXISTS consultaIncidenciesProvinciaIdioma;
DELIMITER //
CREATE PROCEDURE consultaIncidenciesProvinciaIdioma (
		IN idProvincia INTEGER,
		IN idIdioma INTEGER,
		OUT resultat INTEGER)
BEGIN
	p:BEGIN
		DECLARE tot INTEGER;		
		SET resultat = 99;
	
		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */
		IF idProvincia IS NULL OR idIdioma IS NULL THEN 
			SET resultat = 1;
			leave p;
		END IF;
		
		/* Realitzem cerca */
		SELECT  i.id_incidencia,
				i.id_client,
				i.id_producte,
				i.id_sat,
				i.data_compra,
				i.data_entrada,
				i.data_sortida,
				i.garantia,
				dt.descripcio AS tipus,
				de.descripcio AS estat,
  				i.descripcio
  		FROM incidencia i,
  			 sat s,
  			 desc_tipus_incidencia dt,
  			 desc_estat_incidencia de
  		WHERE i.id_sat = s.id_sat AND
              i.id_tipus = dt.id_tipus AND
  			  i.id_estat = de.id_estat AND
  			  dt.id_idioma = idIdioma AND
  			  de.id_idioma = idIdioma AND
  			  s.id_provincia = idProvincia  			  
  		ORDER BY data_entrada DESC;
  		
		/* Asignem el valor de sortida OK */
		SET resultat = 0;

	END; # p: END;

	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('consultaIncidenciesProvinciaIdioma',resultat);

END //

DELIMITER ;


/******************************************************************************
   NOM:      	consultaIncidenciesProductePaisIdioma
   
   PROPSIT:	Retornar les dades de les incidncies d'un producte en un pas
   				en l'idioma demanat.
   
******************************************************************************/
DROP PROCEDURE IF EXISTS consultaIncidenciesProductePaisIdioma;
DELIMITER //
CREATE PROCEDURE consultaIncidenciesProductePaisIdioma (
		IN idProducte INTEGER,
		IN idPais INTEGER,
		IN idIdioma INTEGER,
		OUT resultat INTEGER)
BEGIN
	p:BEGIN
		DECLARE tot INTEGER;		
		SET resultat = 99;
	
		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */
		IF idProducte IS NULL OR idPais IS NULL OR idIdioma IS NULL THEN 
			SET resultat = 1;
			leave p;
		END IF;
		
		/* Realitzem cerca */
		SELECT  i.id_incidencia,
				i.id_client,
				i.id_producte,
				i.id_sat,
				i.data_compra,
				i.data_entrada,
				i.data_sortida,
				i.garantia,
				dt.descripcio AS tipus,
				de.descripcio AS estat,
  				i.descripcio
  		FROM incidencia i,
  			 sat s,
  			 provincia p,
  			 desc_tipus_incidencia dt,
  			 desc_estat_incidencia de
  		WHERE i.id_sat = s.id_sat AND
  			  s.id_provincia = p.id_provincia AND
              i.id_tipus = dt.id_tipus AND
  			  i.id_estat = de.id_estat AND
  			  dt.id_idioma = idIdioma AND
  			  de.id_idioma = idIdioma AND
  			  p.id_pais = idPais AND
  			  i.id_producte = idProducte 			  
  		ORDER BY data_entrada DESC;
  		
		/* Asignem el valor de sortida OK */
		SET resultat = 0;

	END; # p: END;

	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('consultaIncidenciesProductePaisIdioma',resultat);

END //

DELIMITER ;


/******************************************************************************
   NOM:      	consultaIncidenciesProducteProvinciaIdioma
   
   PROPSIT:	Retornar les dades de les incidncies d'un producte en una 
   				provincia en l'idioma demanat.
   
******************************************************************************/
DROP PROCEDURE IF EXISTS consultaIncidenciesProducteProvinciaIdioma;
DELIMITER //
CREATE PROCEDURE consultaIncidenciesProducteProvinciaIdioma (
		IN idProducte INTEGER,
		IN idProvincia INTEGER,
		IN idIdioma INTEGER,
		OUT resultat INTEGER)
BEGIN
	p:BEGIN
		DECLARE tot INTEGER;		
		SET resultat = 99;
	
		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */
		IF idProducte IS NULL OR idProvincia IS NULL OR idIdioma IS NULL THEN 
			SET resultat = 1;
			leave p;
		END IF;
		
		/* Realitzem cerca */
		SELECT  i.id_incidencia,
				i.id_client,
				i.id_producte,
				i.id_sat,
				i.data_compra,
				i.data_entrada,
				i.data_sortida,
				i.garantia,
				dt.descripcio AS tipus,
				de.descripcio AS estat,
  				i.descripcio
  		FROM incidencia i,
  			 sat s,
  			 desc_tipus_incidencia dt,
  			 desc_estat_incidencia de
  		WHERE i.id_sat = s.id_sat AND
              i.id_tipus = dt.id_tipus AND
  			  i.id_estat = de.id_estat AND
  			  dt.id_idioma = idIdioma AND
  			  de.id_idioma = idIdioma AND
  			  s.id_provincia = idProvincia AND
  			  i.id_producte = idProducte
  		ORDER BY data_entrada DESC;
  		
		/* Asignem el valor de sortida OK */
		SET resultat = 0;

	END; # p: END;

	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('consultaIncidenciesProducteProvinciaIdioma',resultat);

END //

DELIMITER ;


/******************************************************************************
   NOM:      	consultaOpinioIncidencia
   
   PROPSIT:	Retornar les dades de la opinio d'una incidncia.
   
******************************************************************************/
DROP PROCEDURE IF EXISTS consultaOpinioIncidencia;
DELIMITER //
CREATE PROCEDURE consultaOpinioIncidencia (
		IN idIncidencia INTEGER,
		OUT resultat INTEGER)
BEGIN
	p:BEGIN
		DECLARE tot INTEGER;
		SET resultat = 99;
	
		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */
		IF idIncidencia IS NULL THEN 
			SET resultat = 1;
			leave p;
		END IF;
		
		/* Modifiquem el registre */
		SELECT * FROM opinio WHERE id_incidencia = idIncidencia;
		
		/* Asignem el valor de sortida OK */
		SET resultat = 0;

	END; # p: END;

	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('consultaOpinioIncidencia',resultat);

END //

DELIMITER ;


/******************************************************************************
   NOM:      	consultaRecanvisIncidencia
   
   PROPSIT:	Retornar el llistat de recanvis que ha requerit una incidncia
   				amb el subtotal de cada lnia.
   
******************************************************************************/
DROP PROCEDURE IF EXISTS consultaRecanvisIncidencia;
DELIMITER //
CREATE PROCEDURE consultaRecanvisIncidencia (
		IN idIncidencia INTEGER,
		OUT resultat INTEGER)
BEGIN
	p:BEGIN
		DECLARE tot INTEGER;
		SET resultat = 99;
	
		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */
		IF idIncidencia IS NULL THEN 
			SET resultat = 1;
			leave p;
		END IF;

	   	/* Realitzem cerca */
	   	SELECT *, (preu_unitari * unitats) AS subtotal FROM recanvis_incidencia WHERE id_incidencia = idIncidencia;

		/* Asignem el valor de sortida OK */
		SET resultat = 0;
		
	END; # p: END;

	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('consultaRecanvisIncidencia',resultat);

END //

DELIMITER ;


/******************************************************************************
   NOM:      	consultaRecanvisIncidencia
   
   PROPSIT:	Retornar les dades d'un recanvi que ha una incidncia amb el
   				subtotal de la lnia.
   
******************************************************************************/
DROP PROCEDURE IF EXISTS consultaRecanviIncidencia;
DELIMITER //
CREATE PROCEDURE consultaRecanviIncidencia (
		IN idIncidencia INTEGER,
		IN idRecanvi INTEGER,
		OUT resultat INTEGER)
BEGIN
	p:BEGIN
		DECLARE tot INTEGER;
		SET resultat = 99;
	
		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */
		IF idIncidencia IS NULL OR idRecanvi IS NULL THEN 
			SET resultat = 1;
			leave p;
		END IF;

	   	/* Realitzem cerca */
	   	SELECT *, (preu_unitari * unitats) AS subtotal FROM recanvis_incidencia WHERE id_incidencia = idIncidencia AND id_recanvi = idRecanvi;

		/* Asignem el valor de sortida OK */
		SET resultat = 0;
		
	END; # p: END;

	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('consultaRecanviIncidencia',resultat);

END //

DELIMITER ;


/******************************************************************************
   NOM:      	consultaTotalIncidencia
   
   PROPSIT:	Retornar el cost total de la incidncia demanada.
   
******************************************************************************/
DROP PROCEDURE IF EXISTS consultaTotalIncidencia;
DELIMITER //
CREATE PROCEDURE consultaTotalIncidencia (
		IN idIncidencia INTEGER,
		OUT resultat INTEGER)
BEGIN
	p:BEGIN
		DECLARE tot INTEGER;
		SET resultat = 99;
	
		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */
		IF idIncidencia IS NULL THEN 
			SET resultat = 1;
			leave p;
		END IF;

	   	/* Realitzem cerca */
	   	SELECT SUM(preu_unitari * unitats) INTO tot FROM recanvis_incidencia WHERE id_incidencia = idIncidencia;

		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */
		IF tot IS NULL THEN 
			SET resultat = 1;
			leave p;
		END IF;
		
		/* Tornem total */
		SELECT tot;
	   	
	   	
		/* Asignem el valor de sortida OK */
		SET resultat = 0;
		
	END; # p: END;

	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('consultaTotalIncidencia',resultat);

END //

DELIMITER ;

/******************************************************************************
******************************************************************************/