/******************************************************************************************************
   NOM:      	altaEstadistiquesClient
   
   PROPSIT:	Dona d'alta o actualitza les estadstiques del client demanat.
   				
******************************************************************************************************/
DROP PROCEDURE IF EXISTS altaEstadistiquesClient;
DELIMITER //
CREATE PROCEDURE altaEstadistiquesClient (
		IN idIncidencia INTEGER,
		OUT resultat INTEGER)
BEGIN
	p:BEGIN
		DECLARE idClient INTEGER;
		DECLARE iGarantia TINYINT;
		DECLARE dataEntrada TIMESTAMP;
		DECLARE total DOUBLE;
		
		DECLARE ani INTEGER;
		DECLARE gar INTEGER;
		DECLARE cto DOUBLE;
		DECLARE cga DOUBLE;
		
		DECLARE vt INTEGER;
		
		SET resultat = 99;

		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */
		IF idIncidencia IS NULL THEN
			SET resultat = 1;
			leave p;
		END IF;

		/* Cerquem dades a l'incidncia */
		SELECT id_client,garantia,data_entrada INTO idClient,iGarantia,dataEntrada
		FROM incidencia WHERE id_incidencia = idIncidencia;
		
		/* Cerquem el cost total de la incidncia */
		SELECT SUM(preu_unitari * unitats) INTO total FROM recanvis_incidencia WHERE id_incidencia = idIncidencia;
				
		/* Cerquem valors NULL a les dades obtingudes */
		IF idClient IS NULL OR iGarantia IS NULL OR dataEntrada IS NULL OR total IS NULL THEN
			SET resultat = 1;
			leave p;
		END IF;
		
		/* Realitzem calculs */
		
		/* Mirem si el producte era en garanta o no i asignem cost si correspon */
		IF iGarantia = 1 THEN
			SET gar = 1;
			SET cga = total;
		ELSE 
			SET gar = 0;
			SET cga = 0;
		END IF;
				
		/* Extreiem l'any de la data d'entrada */
		SET ani = YEAR(dataEntrada);
		
		/* Cerquem si existeix el id cercat a les estadstiques */
		SELECT COUNT(*) INTO vt FROM estadistiques_client WHERE id_client = idClient AND any = ani;
		
		/* Si existeix actualitzem */
		IF vt > 0 THEN
			UPDATE estadistiques_client SET
					nombre = nombre + 1,
					garantia = garantia + gar,
					cost_total = cost_total + total,
					cost_garantia = cost_garantia + cga
			WHERE id_client = idClient AND any = ani;
		/* Si no existeix, donem d'alta */
		ELSE 
			INSERT INTO estadistiques_client(id_client,any,nombre,garantia,cost_total,cost_garantia) VALUES (idClient,ani,1,gar,total,cga);
		END IF;
   		
   		/* Asignem el valor de sortida OK */
   		SET resultat = 0;
   		
   	END; # p: END;
	
   	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('altaEstadistiquesClient',resultat);
   
END //

DELIMITER ;


/******************************************************************************************************
   NOM:      	altaEstadistiquesSat
   
   PROPSIT:	Dona d'alta o actualitza les estadstiques del SAT demanat.
   				
******************************************************************************************************/
DROP PROCEDURE IF EXISTS altaEstadistiquesSat;
DELIMITER //
CREATE PROCEDURE altaEstadistiquesSat (
		IN idIncidencia INTEGER,
		OUT resultat INTEGER)
BEGIN
	p:BEGIN
		DECLARE idSat INTEGER;
		DECLARE iGarantia TINYINT;
		DECLARE dataEntrada TIMESTAMP;
		DECLARE dataSortida TIMESTAMP;
		DECLARE total DOUBLE;
		DECLARE tempsTotal INTEGER;
		
		DECLARE ani INTEGER;
		DECLARE msa INTEGER;
		DECLARE gar INTEGER;
		DECLARE cto DOUBLE;
		DECLARE cga DOUBLE;
		DECLARE val INTEGER;
		DECLARE nval INTEGER;
		
		DECLARE vt INTEGER;
		
		SET resultat = 99;

		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */
		IF idIncidencia IS NULL THEN
			SET resultat = 1;
			leave p;
		END IF;
		
		/* Cerquem dades a l'incidncia */
		SELECT id_sat,garantia,data_entrada,data_sortida INTO idSat,iGarantia,dataEntrada,dataSortida
		FROM incidencia WHERE id_incidencia = idIncidencia;
		
		/* Cerquem el cost total de la incidncia */
		SELECT SUM(preu_unitari * unitats) INTO total FROM recanvis_incidencia WHERE id_incidencia = idIncidencia;
				
		/* Cerquem valors NULL a les dades obtingudes */
		IF idSat IS NULL OR iGarantia IS NULL OR dataEntrada IS NULL OR dataSortida IS NULL OR total IS NULL THEN
			SET resultat = 1;
			leave p;
		END IF;
		
		/* Verifiquem els valors dels camps */
		IF dataSortida < dataEntrada THEN
			SET resultat = 4;
			leave p;
		END IF;
		
		/* Cerquem si tenim valoracio de la incidncia */
		SELECT valoracio_sat INTO val FROM opinio WHERE id_incidencia = idIncidencia;
		
		/* Si obtenim NULL (no existeix valoraci) valorem com a 0 altrament haurem de sumar una valoraci */
		IF val IS NULL THEN
			SET val = 0;
			SET nval = 0;
		ELSE
			SET nval = 1;
		END IF;
				
		/* Realitzem calculs */
		
		/* Mirem si el producte era en garanta o no i asignem cost si correspon */
		IF iGarantia = 1 THEN
			SET gar = 1;
			SET cga = total;
		ELSE 
			SET gar = 0;
			SET cga = 0;
		END IF;
				
		/* Extreiem l'any i el mes de la data d'entrada */
		SET ani = YEAR(dataEntrada);
		SET msa = MONTH(dataEntrada);
		
		/* Calculem el temps total en hores */
		SET tempsTotal = TIMESTAMPDIFF(HOUR,dataEntrada,dataSortida);
				
		/* Cerquem si existeix el id cercat a les estadstiques */
		SELECT COUNT(*) INTO vt FROM estadistiques_sat WHERE id_sat = idSat AND any = ani AND mes = msa;
		
		/* Si existeix actualitzem */
		IF vt > 0 THEN
			UPDATE estadistiques_sat SET
					nombre = nombre + 1,
					garantia = garantia + gar,
					temps_total = temps_total + tempsTotal,
					cost_total = cost_total + total,
					cost_garantia = cost_garantia + cga,
					nombre_valoracions = nombre_valoracions + nval,
					total_valoracions = total_valoracions + val
			WHERE id_sat = idSat AND any = ani AND mes = msa;
		/* Si no existeix, donem d'alta */
		ELSE 
			INSERT INTO estadistiques_sat (id_sat,any,mes,nombre,garantia,temps_total,cost_total,cost_garantia,nombre_valoracions,total_valoracions)
				   VALUES (idSat,ani,msa,1,gar,tempsTotal,total,cga,nval,val);
		END IF;
   		
   		/* Asignem el valor de sortida OK */
   		SET resultat = 0;
   		
   	END; # p: END;
	
   	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('altaEstadistiquesSat',resultat);	
   
END //

DELIMITER ;


/******************************************************************************************************
   NOM:      	altaEstadistiquesProductes
   
   PROPSIT:	Dona d'alta o actualitza les estadstiques del producte demanat.
   				
******************************************************************************************************/
DROP PROCEDURE IF EXISTS altaEstadistiquesProducte;
DELIMITER //
CREATE PROCEDURE altaEstadistiquesProducte (
		IN idIncidencia INTEGER,
		OUT resultat INTEGER)
BEGIN
	p:BEGIN
		DECLARE idProducte INTEGER;
		DECLARE iGarantia TINYINT;
		DECLARE dataEntrada TIMESTAMP;
		DECLARE dataSortida TIMESTAMP;
		DECLARE total DOUBLE;
		DECLARE tempsTotal INTEGER;
		
		DECLARE ani INTEGER;
		DECLARE msa INTEGER;
		DECLARE gar INTEGER;
		DECLARE cto DOUBLE;
		DECLARE cga DOUBLE;
		DECLARE val INTEGER;
		DECLARE nval INTEGER;
		
		DECLARE vt INTEGER;
		
		SET resultat = 99;

		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */
		IF idIncidencia IS NULL THEN
			SET resultat = 1;
			leave p;
		END IF;
		
		/* Cerquem dades a l'incidncia */
		SELECT id_producte,garantia,data_entrada,data_sortida INTO idProducte,iGarantia,dataEntrada,dataSortida
		FROM incidencia WHERE id_incidencia = idIncidencia;
		
		/* Cerquem el cost total de la incidncia */
		SELECT SUM(preu_unitari * unitats) INTO total FROM recanvis_incidencia WHERE id_incidencia = idIncidencia;
				
		/* Cerquem valors NULL a les dades obtingudes */
		IF idProducte IS NULL OR iGarantia IS NULL OR dataEntrada IS NULL OR dataSortida IS NULL OR total IS NULL THEN
			SET resultat = 1;
			leave p;
		END IF;
		
		/* Verifiquem els valors dels camps */
		IF dataSortida < dataEntrada THEN
			SET resultat = 4;
			leave p;
		END IF;
		
		/* Cerquem si tenim valoracio de la incidncia */
		SELECT valoracio_producte INTO val FROM opinio WHERE id_incidencia = idIncidencia;
		
		/* Si obtenim NULL (no existeix valoraci) valorem com a 0 altrament haurem de sumar una valoraci */
		IF val IS NULL THEN
			SET val = 0;
			SET nval = 0;
		ELSE
			SET nval = 1;
		END IF;
				
		/* Realitzem calculs */
		
		/* Mirem si el producte era en garanta o no i asignem cost si correspon */
		IF iGarantia = 1 THEN
			SET gar = 1;
			SET cga = total;
		ELSE 
			SET gar = 0;
			SET cga = 0;
		END IF;
				
		/* Extreiem l'any i el mes de la data d'entrada */
		SET ani = YEAR(dataEntrada);
		SET msa = MONTH(dataEntrada);
		
		/* Calculem el temps total en hores */
		SET tempsTotal = TIMESTAMPDIFF(HOUR,dataEntrada,dataSortida);
				
		/* Cerquem si existeix el id cercat a les estadstiques */
		SELECT COUNT(*) INTO vt FROM estadistiques_producte WHERE id_producte = idProducte AND any = ani AND mes = msa;
		
		/* Si existeix actualitzem */
		IF vt > 0 THEN
			UPDATE estadistiques_producte SET
					nombre = nombre + 1,
					garantia = garantia + gar,
					temps_total = temps_total + tempsTotal,
					cost_total = cost_total + total,
					cost_garantia = cost_garantia + cga,
					nombre_valoracions = nombre_valoracions + nval,
					total_valoracions = total_valoracions + val
			WHERE id_producte = idProducte AND any = ani AND mes = msa;
		/* Si no existeix, donem d'alta */
		ELSE 
			INSERT INTO estadistiques_producte (id_producte,any,mes,nombre,garantia,temps_total,cost_total,cost_garantia,nombre_valoracions,total_valoracions)
				   VALUES (idProducte,ani,msa,1,gar,tempsTotal,total,cga,nval,val);
		END IF;
   		
   		/* Asignem el valor de sortida OK */
   		SET resultat = 0;
   		
   	END; # p: END;
	
   	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('altaEstadistiquesProducte',resultat);	
   
END //

DELIMITER ;


/******************************************************************************************************
   NOM:      	altaEstadistiquesTipus
   
   PROPSIT:	Dona d'alta o actualitza les estadstiques del tipus d'incidncia demanada.
   				
******************************************************************************************************/
DROP PROCEDURE IF EXISTS altaEstadistiquesTipus;
DELIMITER //
CREATE PROCEDURE altaEstadistiquesTipus (
		IN idIncidencia INTEGER,
		OUT resultat INTEGER)
BEGIN
	p:BEGIN
		DECLARE idTipus INTEGER;
		DECLARE iGarantia TINYINT;
		DECLARE dataEntrada TIMESTAMP;
		DECLARE dataSortida TIMESTAMP;
		DECLARE total DOUBLE;
		DECLARE tempsTotal INTEGER;
				
		DECLARE ani INTEGER;
		DECLARE msa INTEGER;
		DECLARE gar INTEGER;
		DECLARE cto DOUBLE;
		DECLARE cga DOUBLE;
		
		DECLARE vt INTEGER;
		
		SET resultat = 99;

		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */
		IF idIncidencia IS NULL THEN
			SET resultat = 1;
			leave p;
		END IF;
		
		/* Cerquem dades a l'incidncia */
		SELECT id_tipus,garantia,data_entrada,data_sortida INTO idTipus,iGarantia,dataEntrada,dataSortida
		FROM incidencia WHERE id_incidencia = idIncidencia;
		
		/* Cerquem el cost total de la incidncia */
		SELECT SUM(preu_unitari * unitats) INTO total FROM recanvis_incidencia WHERE id_incidencia = idIncidencia;
				
		/* Cerquem valors NULL a les dades obtingudes */
		IF idTipus IS NULL OR iGarantia IS NULL OR dataEntrada IS NULL OR dataSortida IS NULL OR total IS NULL THEN
			SET resultat = 1;
			leave p;
		END IF;
		
		/* Verifiquem els valors dels camps */
		IF dataSortida < dataEntrada THEN
			SET resultat = 4;
			leave p;
		END IF;
		
		/* Realitzem calculs */
		
		/* Mirem si el producte era en garanta o no i asignem cost si correspon */
		IF iGarantia = 1 THEN
			SET gar = 1;
			SET cga = total;
		ELSE 
			SET gar = 0;
			SET cga = 0;
		END IF;
				
		/* Extreiem l'any i el mes de la data d'entrada */
		SET ani = YEAR(dataEntrada);
		SET msa = MONTH(dataEntrada);
		
		/* Calculem el temps total en hores */
		SET tempsTotal = TIMESTAMPDIFF(HOUR,dataEntrada,dataSortida);
				
		/* Cerquem si existeix el id cercat a les estadstiques */
		SELECT COUNT(*) INTO vt FROM estadistiques_tipus WHERE id_tipus = idTipus AND any = ani AND mes = msa;
		
		/* Si existeix actualitzem */
		IF vt > 0 THEN
			UPDATE estadistiques_tipus SET
					nombre = nombre + 1,
					garantia = garantia + gar,
					temps_total = temps_total + tempsTotal,
					cost_total = cost_total + total,
					cost_garantia = cost_garantia + cga
			WHERE id_tipus = idTipus AND any = ani AND mes = msa;
		/* Si no existeix, donem d'alta */
		ELSE 
			INSERT INTO estadistiques_tipus (id_tipus,any,mes,nombre,garantia,temps_total,cost_total,cost_garantia)
				   VALUES (idTipus,ani,msa,1,gar,tempsTotal,total,cga);
		END IF;
   		
   		/* Asignem el valor de sortida OK */
   		SET resultat = 0;
   		
   	END; # p: END;
	
   	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('altaEstadistiquesTipus',resultat);	
   
END //

DELIMITER ;


/******************************************************************************************************
   NOM:      	altaEstadistiquesIncidencia
   
   PROPSIT:	Dona d'alta o actualitza les estadstiques de la incidncia demanada.
   				
******************************************************************************************************/
DROP PROCEDURE IF EXISTS altaEstadistiquesIncidencia;
DELIMITER //
CREATE PROCEDURE altaEstadistiquesIncidencia (
		IN idIncidencia INTEGER,
		OUT resultat INTEGER)
BEGIN
	p:BEGIN
		DECLARE iGarantia TINYINT;
		DECLARE dataEntrada TIMESTAMP;
		DECLARE dataSortida TIMESTAMP;
		DECLARE total DOUBLE;
		DECLARE tempsTotal INTEGER;
		
		DECLARE ani INTEGER;
		DECLARE msa INTEGER;
		DECLARE gar INTEGER;
		DECLARE cto DOUBLE;
		DECLARE cga DOUBLE;
		DECLARE val INTEGER;
		DECLARE valp INTEGER;
		DECLARE vals INTEGER;
		DECLARE nval INTEGER;
		
		DECLARE vt INTEGER;
		
		SET resultat = 99;

		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */
		IF idIncidencia IS NULL THEN
			SET resultat = 1;
			leave p;
		END IF;
		
		/* Cerquem dades a l'incidncia */
		SELECT garantia,data_entrada,data_sortida INTO iGarantia,dataEntrada,dataSortida
		FROM incidencia WHERE id_incidencia = idIncidencia;
		
		/* Cerquem el cost total de la incidncia */
		SELECT SUM(preu_unitari * unitats) INTO total FROM recanvis_incidencia WHERE id_incidencia = idIncidencia;
				
		/* Cerquem valors NULL a les dades obtingudes */
		IF iGarantia IS NULL OR dataEntrada IS NULL OR dataSortida IS NULL OR total IS NULL THEN
			SET resultat = 1;
			leave p;
		END IF;
		
		/* Verifiquem els valors dels camps */
		IF dataSortida < dataEntrada THEN
			SET resultat = 4;
			leave p;
		END IF;
		
		/* Cerquem si tenim valoracio de la incidncia */
		SELECT valoracio_producte,valoracio_sat INTO valp,vals FROM opinio WHERE id_incidencia = idIncidencia;
		
		/* Si obtenim NULL (no existeix valoraci) valorem com a 0 altrament haurem de sumar una valoraci */
		IF valp IS NULL OR vals IS NULL THEN
			SET val = 0;
			SET nval = 0;
		ELSE
			SET val = vals + valp;
			SET nval = 2;
		END IF;
		
		/* Realitzem calculs */
		
		/* Mirem si el producte era en garanta o no i asignem cost si correspon */
		IF iGarantia = 1 THEN
			SET gar = 1;
			SET cga = total;
		ELSE 
			SET gar = 0;
			SET cga = 0;
		END IF;
				
		/* Extreiem l'any i el mes de la data d'entrada */
		SET ani = YEAR(dataEntrada);
		SET msa = MONTH(dataEntrada);
		
		/* Calculem el temps total en hores */
		SET tempsTotal = TIMESTAMPDIFF(HOUR,dataEntrada,dataSortida);
				
		/* Cerquem si existeix el id cercat a les estadstiques */
		SELECT COUNT(*) INTO vt FROM estadistiques_incidencia WHERE any = ani AND mes = msa;
		
		/* Si existeix actualitzem */
		IF vt > 0 THEN
			UPDATE estadistiques_incidencia SET
					nombre = nombre + 1,
					garantia = garantia + gar,
					temps_total = temps_total + tempsTotal,
					cost_total = cost_total + total,
					cost_garantia = cost_garantia + cga,
					nombre_valoracions = nombre_valoracions + nval,
					total_valoracions = total_valoracions + val
			WHERE any = ani AND mes = msa;
		/* Si no existeix, donem d'alta */
		ELSE 
			INSERT INTO estadistiques_incidencia (any,mes,nombre,garantia,temps_total,cost_total,cost_garantia,nombre_valoracions,total_valoracions)
				   VALUES (ani,msa,2,gar,tempsTotal,total,cga,nval,val);
		END IF;
   		
   		/* Asignem el valor de sortida OK */
   		SET resultat = 0;
   		
   	END; # p: END;
	
   	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('altaEstadistiquesIncidencia',resultat);	
   
END //

DELIMITER ;


/******************************************************************************************************
   NOM:      	altaEstadistiquesProvincia
   
   PROPSIT:	Dona d'alta o actualitza les estadstiques de la provncia demanada.
   				
******************************************************************************************************/
DROP PROCEDURE IF EXISTS altaEstadistiquesProvincia;
DELIMITER //
CREATE PROCEDURE altaEstadistiquesProvincia (
		IN idIncidencia INTEGER,
		OUT resultat INTEGER)
BEGIN
	p:BEGIN
		DECLARE idProvincia INTEGER;
		DECLARE idSat INTEGER;
		DECLARE iGarantia TINYINT;
		DECLARE dataEntrada TIMESTAMP;
		
		DECLARE ani INTEGER;
		DECLARE msa INTEGER;
		DECLARE gar INTEGER;
		
		DECLARE vt INTEGER;
		
		SET resultat = 99;

		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */
		IF idIncidencia IS NULL THEN
			SET resultat = 1;
			leave p;
		END IF;
		
		/* Cerquem dades a l'incidncia */
		SELECT id_sat,garantia,data_entrada INTO idSat,iGarantia,dataEntrada
		FROM incidencia WHERE id_incidencia = idIncidencia;
		
		/* Cerquem provncia */
		SELECT id_provincia INTO idProvincia FROM sat WHERE id_sat = idSat;
		
		/* Cerquem valors NULL a les dades obtingudes */
		IF idProvincia IS NULL OR idSat IS NULL OR iGarantia IS NULL OR dataEntrada IS NULL THEN
			SET resultat = 1;
			leave p;
		END IF;
		
		/* Realitzem calculs */
		
		/* Mirem si el producte era en garanta o no i asignem cost si correspon */
		IF iGarantia = 1 THEN
			SET gar = 1;			
		ELSE 
			SET gar = 0;
		END IF;
				
		/* Extreiem l'any i el mes de la data d'entrada */
		SET ani = YEAR(dataEntrada);
		SET msa = MONTH(dataEntrada);
		
		/* Cerquem si existeix el id cercat a les estadstiques */
		SELECT COUNT(*) INTO vt FROM estadistiques_provincia WHERE id_provincia = idProvincia AND any = ani AND mes = msa;
		
		/* Si existeix actualitzem */
		IF vt > 0 THEN
			UPDATE estadistiques_provincia SET
					nombre = nombre + 1,
					garantia = garantia + gar
			WHERE id_provincia = idProvincia AND any = ani AND mes = msa;
		/* Si no existeix, donem d'alta */
		ELSE 
			INSERT INTO estadistiques_provincia (id_provincia,any,mes,nombre,garantia)
				   VALUES (idProvincia,ani,msa,1,gar);
		END IF;
   		
   		/* Asignem el valor de sortida OK */
   		SET resultat = 0;
   		
   	END; # p: END;
	
   	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('altaEstadistiquesProvincia',resultat);	
   
END //

DELIMITER ;


/******************************************************************************************************
   NOM:      	altaEstadistiquesFamilia
   
   PROPSIT:	Dona d'alta o actualitza les estadstiques de la famlia de producte demanat.
   				
******************************************************************************************************/
DROP PROCEDURE IF EXISTS altaEstadistiquesFamilia;
DELIMITER //
CREATE PROCEDURE altaEstadistiquesFamilia (
		IN idIncidencia INTEGER,
		OUT resultat INTEGER)
BEGIN
	p:BEGIN
		DECLARE idFamilia INTEGER;
		DECLARE idProducte INTEGER;
		DECLARE iGarantia TINYINT;
		DECLARE dataEntrada TIMESTAMP;
		DECLARE dataSortida TIMESTAMP;
		DECLARE total DOUBLE;
		DECLARE tempsTotal INTEGER;
		
		DECLARE ani INTEGER;
		DECLARE msa INTEGER;
		DECLARE gar INTEGER;
		DECLARE cto DOUBLE;
		DECLARE cga DOUBLE;
		
		DECLARE vt INTEGER;
		
		SET resultat = 99;

		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */
		IF idIncidencia IS NULL THEN
			SET resultat = 1;
			leave p;
		END IF;
		
		/* Cerquem dades a l'incidncia */
		SELECT id_producte,garantia,data_entrada,data_sortida INTO idProducte,iGarantia,dataEntrada,dataSortida
		FROM incidencia WHERE id_incidencia = idIncidencia;
		
		/* Cerquem el cost total de la incidncia */
		SELECT SUM(preu_unitari * unitats) INTO total FROM recanvis_incidencia WHERE id_incidencia = idIncidencia;
		
		/* Cerquem familia */
		SELECT id_familia INTO idFamilia FROM producte WHERE id_producte = idProducte;
		
		/* Cerquem valors NULL a les dades obtingudes */
		IF idProducte IS NULL OR iGarantia IS NULL OR dataEntrada IS NULL OR dataSortida IS NULL OR idFamilia IS NULL OR total IS NULL THEN
			SET resultat = 1;
			leave p;
		END IF;
		
		/* Verifiquem els valors dels camps */
		IF dataSortida < dataEntrada THEN
			SET resultat = 4;
			leave p;
		END IF;
		
		/* Calculem el temps total en hores */
		SET tempsTotal = TIMESTAMPDIFF(HOUR,dataEntrada,dataSortida);
		
		/* Realitzem calculs */
		
		/* Mirem si el producte era en garanta o no i asignem cost si correspon */
		IF iGarantia = 1 THEN
			SET gar = 1;
			SET cga = total;
		ELSE 
			SET gar = 0;
			SET cga = 0;
		END IF;
				
		/* Extreiem l'any i el mes de la data d'entrada */
		SET ani = YEAR(dataEntrada);
		SET msa = MONTH(dataEntrada);
		
		/* Cerquem si existeix el id cercat a les estadstiques */
		SELECT COUNT(*) INTO vt FROM estadistiques_familia WHERE id_familia = idFamilia AND any = ani AND mes = msa;
		
		/* Si existeix actualitzem */
		IF vt > 0 THEN
			UPDATE estadistiques_familia SET
					nombre = nombre + 1,
					garantia = garantia + gar,
					temps_total = temps_total + tempsTotal,
					cost_total = cost_total + total,
					cost_garantia = cost_garantia + cga
			WHERE id_familia = idFamilia AND any = ani AND mes = msa;
		/* Si no existeix, donem d'alta */
		ELSE 
			INSERT INTO estadistiques_familia (id_familia,any,mes,nombre,garantia,temps_total,cost_total,cost_garantia)
				   VALUES (idFamilia,ani,msa,1,gar,tempsTotal,total,cga);
		END IF;
		
   		/* Asignem el valor de sortida OK */
   		SET resultat = 0;
   		
   	END; # p: END;
	
   	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('altaEstadistiquesFamilia',resultat);	
   
END //

DELIMITER ;


/******************************************************************************************************
   NOM:      	altaEstadistiquesPais
   
   PROPSIT:	Dona d'alta o actualitza les estadstiques del pas demanat.
   				
******************************************************************************************************/
DROP PROCEDURE IF EXISTS altaEstadistiquesPais;
DELIMITER //
CREATE PROCEDURE altaEstadistiquesPais (
		IN idIncidencia INTEGER,
		OUT resultat INTEGER)
BEGIN
	p:BEGIN
		DECLARE idPais INTEGER;
		DECLARE idSat INTEGER;
		DECLARE idProvincia INTEGER;
		DECLARE iGarantia TINYINT;
		DECLARE dataEntrada TIMESTAMP;
		DECLARE dataSortida TIMESTAMP;
		DECLARE total DOUBLE;
		DECLARE tempsTotal INTEGER;
		
		DECLARE ani INTEGER;
		DECLARE msa INTEGER;
		DECLARE gar INTEGER;
		DECLARE cto DOUBLE;
		DECLARE cga DOUBLE;
		DECLARE val INTEGER;
		DECLARE valp INTEGER;
		DECLARE vals INTEGER;
		DECLARE nval INTEGER;
		
		DECLARE vt INTEGER;
		
		SET resultat = 99;

		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */
		IF idIncidencia IS NULL THEN
			SET resultat = 1;
			leave p;
		END IF;
		
		/* Cerquem dades a l'incidncia */
		SELECT id_sat,garantia,data_entrada,data_sortida INTO idSat,iGarantia,dataEntrada,dataSortida
		FROM incidencia WHERE id_incidencia = idIncidencia;
		
		/* Cerquem el cost total de la incidncia */
		SELECT SUM(preu_unitari * unitats) INTO total FROM recanvis_incidencia WHERE id_incidencia = idIncidencia;
			
		/* Cerquem provncia */
		SELECT id_provincia INTO idProvincia FROM sat WHERE id_sat = idSat;
		
		/* Cerquem pais */
		SELECT id_pais INTO idPais FROM provincia WHERE id_provincia = idProvincia;
		
		/* Cerquem valors NULL a les dades obtingudes */
		IF idPais IS NULL OR idProvincia IS NULL OR idSat IS NULL OR iGarantia IS NULL OR dataEntrada IS NULL OR dataSortida IS NULL OR total IS NULL THEN
			SET resultat = 1;
			leave p;
		END IF;
		
		/* Verifiquem els valors dels camps */
		IF dataSortida < dataEntrada THEN
			SET resultat = 4;
			leave p;
		END IF;
		
		/* Cerquem si tenim valoracio de la incidncia */
		SELECT valoracio_producte,valoracio_sat INTO valp,vals FROM opinio WHERE id_incidencia = idIncidencia;
		
		/* Si obtenim NULL (no existeix valoraci) valorem com a 0 altrament haurem de sumar una valoraci */
		IF valp IS NULL OR vals IS NULL THEN
			SET val = 0;
			SET nval = 0;
		ELSE
			SET val = vals + valp;
			SET nval = 2;
		END IF;
		
		/* Realitzem calculs */
		
		/* Mirem si el producte era en garanta o no i asignem cost si correspon */
		IF iGarantia = 1 THEN
			SET gar = 1;
			SET cga = total;
		ELSE 
			SET gar = 0;
			SET cga = 0;
		END IF;
				
		/* Extreiem l'any i el mes de la data d'entrada */
		SET ani = YEAR(dataEntrada);
		SET msa = MONTH(dataEntrada);
		
		/* Calculem el temps total en hores */
		SET tempsTotal = TIMESTAMPDIFF(HOUR,dataEntrada,dataSortida);
				
		/* Cerquem si existeix el id cercat a les estadstiques */
		SELECT COUNT(*) INTO vt FROM estadistiques_pais WHERE id_pais = idPais AND any = ani AND mes = msa;
		
		/* Si existeix actualitzem */
		IF vt > 0 THEN
			UPDATE estadistiques_pais SET
					nombre = nombre + 1,
					garantia = garantia + gar,
					temps_total = temps_total + tempsTotal,
					cost_total = cost_total + total,
					cost_garantia = cost_garantia + cga,
					nombre_valoracions = nombre_valoracions + nval,
					total_valoracions = total_valoracions + val
			WHERE id_pais = idPais AND any = ani AND mes = msa;
		/* Si no existeix, donem d'alta */
		ELSE 
			INSERT INTO estadistiques_pais (id_pais,any,mes,nombre,garantia,temps_total,cost_total,cost_garantia,nombre_valoracions,total_valoracions)
				   VALUES (idPais,ani,msa,1,gar,tempsTotal,total,cga,nval,val);
		END IF;
   		
   		/* Asignem el valor de sortida OK */
   		SET resultat = 0;
   		
   	END; # p: END;
	
   	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('altaEstadistiquesPais',resultat);	
   
END //

DELIMITER ;


/******************************************************************************************************
   NOM:      	altaEstadistiquesRecanvi
   
   PROPSIT:	Dona d'alta o actualitza les estadstiques del recanvi demanat.
   				
******************************************************************************************************/
DROP PROCEDURE IF EXISTS altaEstadistiquesRecanvi;
DELIMITER //
CREATE PROCEDURE altaEstadistiquesRecanvi (
		IN idIncidencia INTEGER,
		OUT resultat INTEGER)
BEGIN
	p:BEGIN
		DECLARE done BOOLEAN DEFAULT 0;
		DECLARE idRecanvi INTEGER;
		DECLARE iGarantia TINYINT;
		DECLARE dataEntrada TIMESTAMP;
		DECLARE subtotal DOUBLE;
		
		DECLARE ani INTEGER;
		DECLARE msa INTEGER;
		DECLARE gar INTEGER;
		DECLARE cto DOUBLE;
		DECLARE cga DOUBLE;
		
		DECLARE vt INTEGER;
		
		DECLARE cursor1 CURSOR FOR SELECT id_recanvi,(unitats * preu_unitari) FROM recanvis_incidencia;
   		DECLARE CONTINUE HANDLER FOR SQLSTATE '02000' SET done=1;
		
		SET resultat = 99;

		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */
		IF idIncidencia IS NULL THEN
			SET resultat = 1;
			leave p;
		END IF;
		
		/* Cerquem dades a l'incidncia */
		SELECT garantia,data_entrada INTO iGarantia,dataEntrada
		FROM incidencia WHERE id_incidencia = idIncidencia;
		
		/* Cerquem valors NULL a les dades obtingudes */
		IF iGarantia IS NULL OR dataEntrada IS NULL THEN
			SET resultat = 1;
			leave p;
		END IF;
		
		/* Realitzem calculs globals */
		
		/* Mirem si el producte era en garanta o no i asignem cost si correspon */
		IF iGarantia = 1 THEN
			SET gar = 1;
		ELSE 
			SET gar = 0;
			SET cga = 0;
		END IF;
  		
		/* Extreiem l'any i el mes de la data d'entrada */
		SET ani = YEAR(dataEntrada);
		SET msa = MONTH(dataEntrada);

		/* Realitzem per a cada recanvi un INSERT o UPDATE */
		OPEN cursor1;
		REPEAT
				FETCH cursor1 INTO idRecanvi,subtotal;
  		
				IF NOT done THEN
				
  					/* Cerquem valors NULL a les dades obtingudes */
					IF idRecanvi IS NULL OR subtotal IS NULL THEN
						SET resultat = 11;
						leave p;
					END IF;
  					
  					/* Realitzem calculs per a cada subtotal (noms cal calcular en aquest cas */
					IF iGarantia = 1 THEN
						SET cga = subtotal;
					END IF;
  		  			
  					/* Cerquem si existeix el id cercat a les estadstiques */
					SELECT COUNT(*) INTO vt FROM estadistiques_recanvi WHERE id_recanvi = idRecanvi AND any = ani AND mes = msa;
					
					/* Si existeix actualitzem */
					IF vt > 0 THEN
						UPDATE estadistiques_recanvi SET
								nombre = nombre + 1,
								garantia = garantia + gar,
								cost_total = cost_total + subtotal,
								cost_garantia = cost_garantia + cga
						WHERE id_recanvi = idRecanvi AND any = ani AND mes = msa;
					/* Si no existeix, donem d'alta */
					ELSE 
						INSERT INTO estadistiques_recanvi (id_recanvi,any,mes,nombre,garantia,cost_total,cost_garantia)
							   VALUES (idRecanvi,ani,msa,1,gar,subtotal,cga);
					END IF;
									
					/* Asignem el valor de sortida OK */
   					SET resultat = 0;
   					
					INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('altaEstadistiquesRecanviLoop',resultat);		
					
					/* Tornem a assignar el valor d'error de PE pel seguent loop */
					SET resultat = 99;
				END IF;
		
    	UNTIL done END REPEAT;
   		CLOSE cursor1;
    	
   		/* Asignem el valor de sortida OK */
   		SET resultat = 0;
   		
   	END; # p: END;
	
   	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('altaEstadistiquesRecanvi',resultat);	
   
END //

DELIMITER ;


/******************************************************************************************************
   NOM:      	consultaEstadistiquesClient
   
   PROPSIT:	Retornar les estadstiques dels clients.
   				
   				Amb la combinaci dels parmetres d'entrada obtenim les segents estadstiques
   				(0 s el codi per indicar tots):
   				
   				any  = 0 i id_client  = 0 -> Tots els clients
   				any <> 0 i id_client  = 0 -> Tots els clients per any
   				any  = 0 i id_client <> 0 -> Client
   				any <> 0 i id_client <> 0 -> Client per any
   				
******************************************************************************************************/
DROP PROCEDURE IF EXISTS consultaEstadistiquesClient;
DELIMITER //
CREATE PROCEDURE consultaEstadistiquesClient (
		IN idClient INTEGER,
		IN ani INTEGER,
		OUT resultat INTEGER)
BEGIN
	p:BEGIN
		DECLARE tot INTEGER;
		SET resultat = 99;

		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */	
		IF idClient IS NULL OR ani IS NULL THEN 
			SET resultat = 1;
			leave p;
		END IF;
		
		/* Construim sentencia SQL segons els valors d'entrada */
		IF ani = 0 AND idClient = 0 THEN
			/* Suma de tots els clients */
			SELECT 	 SUM(nombre) AS nombre,
					 SUM(garantia) AS garantia,
					 SUM(cost_total) AS cost_total,
					 SUM(cost_garantia) AS cost_garantia
			FROM estadistiques_client;
			
		ELSEIF ani != 0 AND idClient = 0 THEN	
			/* Suma de tots els clients per any */
			SELECT 	 SUM(nombre) AS nombre,
					 SUM(garantia) AS garantia,
					 SUM(cost_total) AS cost_total,
					 SUM(cost_garantia) AS cost_garantia
			FROM estadistiques_client
			WHERE any = ani;
			
		ELSEIF ani = 0 AND idClient != 0 THEN
			
			/* Suma client */
			SELECT 	 SUM(nombre) AS nombre,
					 SUM(garantia) AS garantia,
					 SUM(cost_total) AS cost_total,
					 SUM(cost_garantia) AS cost_garantia
			FROM estadistiques_client
			WHERE id_client = idClient;
			
		ELSE
			/* Suma client en un any */
			SELECT 	 nombre,
					 garantia,
					 cost_total,
					 cost_garantia
			FROM estadistiques_client
			WHERE id_client = idClient  AND any = ani;
		END IF;
		
		/* Asignem el valor de sortida OK */
		SET resultat = 0;

	END; # p: END;

	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('consultaEstadistiquesClient',resultat);

END //

DELIMITER ;


/******************************************************************************************************
   NOM:      	consultaEstadistiquesFamilia
   
   PROPSIT:	Retornar les estadstiques de les famlies de productes.
   				
   				Amb la combinaci dels parmetres d'entrada obtenim les	segents estadstiques
   				(0 s el codi per indicar tots):
   				
   				any  = 0 i mes  = 0 i id_familia  = 0 -> Totes les famlies.
   				any <> 0 i mes  = 0 i id_familia  = 0 -> Totes les famlies en un any.
   				any  = 0 i mes <> 0 i id_familia  = 0 -> Totes les famlies en un mes de tots els anys.
   				any <> 0 i mes <> 0 i id_familia  = 0 -> Totes les famlies en un ms d'un any.
   				any  = 0 i mes  = 0 i id_familia <> 0 -> Una familia.
   				any <> 0 i mes  = 0 i id_familia <> 0 -> Una familia en un mes.
   				any  = 0 i mes <> 0 i id_familia <> 0 -> Una familia en un mes de tots els anys.
   				any <> 0 i mes <> 0 i id_familia <> 0 -> Una familia en un mes d'un any.
   				
******************************************************************************************************/
DROP PROCEDURE IF EXISTS consultaEstadistiquesFamilia;
DELIMITER //
CREATE PROCEDURE consultaEstadistiquesFamilia (
		IN idFamilia INTEGER,
		IN ani INTEGER,
		IN msa INTEGER,
		OUT resultat INTEGER)
BEGIN
	p:BEGIN
		DECLARE tot INTEGER;
		SET resultat = 99;

		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */	
		IF idFamilia IS NULL OR ani IS NULL OR msa IS NULL THEN 
			SET resultat = 1;
			leave p;
		END IF;
		
		/* Verifiquem que el nmero del mes sigui correcte */
		IF msa < 0 OR msa > 12 THEN
		SET resultat = 4;
			leave p;
		END IF;
		
		/* Construim sentencia SQL segons els valors d'entrada */
		IF idFamilia = 0 AND ani = 0 AND msa = 0 THEN
			/* Suma de totes les famlies */
			SELECT 	 SUM(nombre) AS nombre,
					 SUM(garantia) AS garantia,
					 SUM(temps_total) AS temps_total,
					 SUM(cost_total) AS cost_total,
					 SUM(cost_garantia) AS cost_garantia
			FROM estadistiques_familia;
			
		ELSEIF idFamilia = 0 AND ani != 0 AND msa = 0 THEN	
			/* Suma de totes les famlies en un any */
			SELECT 	 SUM(nombre) AS nombre,
					 SUM(garantia) AS garantia,
					 SUM(temps_total) AS temps_total,
					 SUM(cost_total) AS cost_total,
					 SUM(cost_garantia) AS cost_garantia
			FROM estadistiques_familia
			WHERE any = ani;
			
		ELSEIF idFamilia = 0 AND ani = 0 AND msa != 0 THEN	
			/* Suma de totes les famlies en un mes de tots els anys */
			SELECT 	 SUM(nombre) AS nombre,
					 SUM(garantia) AS garantia,
					 SUM(temps_total) AS temps_total,
					 SUM(cost_total) AS cost_total,
					 SUM(cost_garantia) AS cost_garantia
			FROM estadistiques_familia
			WHERE mes = msa;
		
		ELSEIF idFamilia = 0 AND ani != 0 AND msa != 0 THEN	
			/* Suma de totes les famlies en un mes d'un any */
			SELECT 	 SUM(nombre) AS nombre,
					 SUM(garantia) AS garantia,
					 SUM(temps_total) AS temps_total,
					 SUM(cost_total) AS cost_total,
					 SUM(cost_garantia) AS cost_garantia
			FROM estadistiques_familia
			WHERE any = ani AND mes = msa;
			
		ELSEIF idFamilia != 0 AND ani = 0 AND msa = 0 THEN	
			/* Suma d'una familia */
			SELECT 	 SUM(nombre) AS nombre,
					 SUM(garantia) AS garantia,
					 SUM(temps_total) AS temps_total,
					 SUM(cost_total) AS cost_total,
					 SUM(cost_garantia) AS cost_garantia
			FROM estadistiques_familia
			WHERE id_familia = idFamilia;
			
		ELSEIF idFamilia != 0 AND ani != 0 AND msa = 0 THEN	
			/* Suma d'una familia en un any */
			SELECT 	 SUM(nombre) AS nombre,
					 SUM(garantia) AS garantia,
					 SUM(temps_total) AS temps_total,
					 SUM(cost_total) AS cost_total,
					 SUM(cost_garantia) AS cost_garantia
			FROM estadistiques_familia
			WHERE id_familia = idFamilia AND any = ani;
			
		ELSEIF idFamilia != 0 AND ani = 0 AND msa != 0 THEN	
			/* Suma d'una familia en un mes per a tots els anys */
			SELECT 	 SUM(nombre) AS nombre,
					 SUM(garantia) AS garantia,
					 SUM(temps_total) AS temps_total,
					 SUM(cost_total) AS cost_total,
					 SUM(cost_garantia) AS cost_garantia
			FROM estadistiques_familia
			WHERE id_familia = idFamilia AND mes = msa;
			
		ELSE
			/* Suma d'una familia en el mes d'un any */
			SELECT 	 SUM(nombre) AS nombre,
					 SUM(garantia) AS garantia,
					 SUM(temps_total) AS temps_total,
					 SUM(cost_total) AS cost_total,
					 SUM(cost_garantia) AS cost_garantia
			FROM estadistiques_familia
			WHERE id_familia = idFamilia AND any = ani AND mes = msa;
		END IF;
		
		/* Asignem el valor de sortida OK */
		SET resultat = 0;

	END; # p: END;

	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('consultaEstadistiquesFamilia',resultat);

END //

DELIMITER ;


/******************************************************************************************************
   NOM:      	consultaEstadistiquesTipus
   
   PROPSIT:	Retornar les estadstiques dels tipus d'incidncia.
   				
   				Amb la combinaci dels parmetres d'entrada obtenim les segents estadstiques
   				(0 s el codi per indicar tots):
   				
   				any  = 0 i mes  = 0 i id_tipus  = 0 -> Tots els tipus.
   				any <> 0 i mes  = 0 i id_tipus  = 0 -> Tots els tipus en un any.
   				any  = 0 i mes <> 0 i id_tipus  = 0 -> Tots els tipus en un mes de tots els anys.
   				any <> 0 i mes <> 0 i id_tipus  = 0 -> Tots els tipus en un ms d'un any.
   				any  = 0 i mes  = 0 i id_tipus <> 0 -> Un tipus.
   				any <> 0 i mes  = 0 i id_tipus <> 0 -> Un tipus en un mes.
   				any  = 0 i mes <> 0 i id_tipus <> 0 -> Un tipus en un mes de tots els anys.
   				any <> 0 i mes <> 0 i id_tipus <> 0 -> Un tipus en un mes d'un any.
   			
******************************************************************************************************/
DROP PROCEDURE IF EXISTS consultaEstadistiquesTipus;
DELIMITER //
CREATE PROCEDURE consultaEstadistiquesTipus (
		IN idTipus INTEGER,
		IN ani INTEGER,
		IN msa INTEGER,
		OUT resultat INTEGER)
BEGIN
	p:BEGIN
		DECLARE tot INTEGER;
		SET resultat = 99;

		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */	
		IF idTipus IS NULL OR ani IS NULL OR msa IS NULL THEN 
			SET resultat = 1;
			leave p;
		END IF;
		
		/* Verifiquem que el nmero del mes sigui correcte */
		IF msa < 0 OR msa > 12 THEN
		SET resultat = 4;
			leave p;
		END IF;
		
		/* Construim sentencia SQL segons els valors d'entrada */
		IF idTipus = 0 AND ani = 0 AND msa = 0 THEN
			/* Suma de tots els tipus */
			SELECT 	 SUM(nombre) AS nombre,
					 SUM(garantia) AS garantia,
					 SUM(temps_total) AS temps_total,
					 SUM(cost_total) AS cost_total,
					 SUM(cost_garantia) AS cost_garantia
			FROM estadistiques_tipus;
			
		ELSEIF idTipus = 0 AND ani != 0 AND msa = 0 THEN	
			/* Suma de tots els tipus en un any */
			SELECT 	 SUM(nombre) AS nombre,
					 SUM(garantia) AS garantia,
					 SUM(temps_total) AS temps_total,
					 SUM(cost_total) AS cost_total,
					 SUM(cost_garantia) AS cost_garantia
			FROM estadistiques_tipus
			WHERE any = ani;
			
		ELSEIF idTipus = 0 AND ani = 0 AND msa != 0 THEN	
			/* Suma de tots els tipus en un mes de tots els anys */
			SELECT 	 SUM(nombre) AS nombre,
					 SUM(garantia) AS garantia,
					 SUM(temps_total) AS temps_total,
					 SUM(cost_total) AS cost_total,
					 SUM(cost_garantia) AS cost_garantia
			FROM estadistiques_tipus
			WHERE mes = msa;
		
		ELSEIF idTipus = 0 AND ani != 0 AND msa != 0 THEN	
			/* Suma de tots els tipus en un mes d'un any */
			SELECT 	 SUM(nombre) AS nombre,
					 SUM(garantia) AS garantia,
					 SUM(temps_total) AS temps_total,
					 SUM(cost_total) AS cost_total,
					 SUM(cost_garantia) AS cost_garantia
			FROM estadistiques_tipus
			WHERE any = ani AND mes = msa;
			
		ELSEIF idTipus != 0 AND ani = 0 AND msa = 0 THEN	
			/* Suma d'una tipus */
			SELECT 	 SUM(nombre) AS nombre,
					 SUM(garantia) AS garantia,
					 SUM(temps_total) AS temps_total,
					 SUM(cost_total) AS cost_total,
					 SUM(cost_garantia) AS cost_garantia
			FROM estadistiques_tipus
			WHERE id_tipus = idTipus;
			
		ELSEIF idTipus != 0 AND ani != 0 AND msa = 0 THEN	
			/* Suma d'una tipus en un any */
			SELECT 	 SUM(nombre) AS nombre,
					 SUM(garantia) AS garantia,
					 SUM(temps_total) AS temps_total,
					 SUM(cost_total) AS cost_total,
					 SUM(cost_garantia) AS cost_garantia
			FROM estadistiques_tipus
			WHERE id_tipus = idTipus AND any = ani;
			
		ELSEIF idTipus != 0 AND ani = 0 AND msa != 0 THEN	
			/* Suma d'una tipus en un mes per a tots els anys */
			SELECT 	 SUM(nombre) AS nombre,
					 SUM(garantia) AS garantia,
					 SUM(temps_total) AS temps_total,
					 SUM(cost_total) AS cost_total,
					 SUM(cost_garantia) AS cost_garantia
			FROM estadistiques_tipus
			WHERE id_tipus = idTipus AND mes = msa;
			
		ELSE
			/* Suma d'una tipus en el mes d'un any */
			SELECT 	 SUM(nombre) AS nombre,
					 SUM(garantia) AS garantia,
					 SUM(temps_total) AS temps_total,
					 SUM(cost_total) AS cost_total,
					 SUM(cost_garantia) AS cost_garantia
			FROM estadistiques_tipus
			WHERE id_tipus = idTipus AND any = ani AND mes = msa;
		END IF;
		
		/* Asignem el valor de sortida OK */
		SET resultat = 0;

	END; # p: END;

	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('consultaEstadistiquesTipus',resultat);

END //

DELIMITER ;


/******************************************************************************************************
   NOM:      	consultaEstadistiquesRecanvi
   
   PROPSIT:	Retornar les estadstiques dels recanvis.
   				
   				Amb la combinaci dels parmetres d'entrada obtenim les segents estadstiques
   				(0 s el codi per indicar tots):
   				
   				any  = 0 i mes  = 0 i id_recanvi  = 0 -> Tots els recanvis.
   				any <> 0 i mes  = 0 i id_recanvi  = 0 -> Tots els recanvis en un any.
   				any  = 0 i mes <> 0 i id_recanvi  = 0 -> Tots els recanvis en un mes de tots els anys.
   				any <> 0 i mes <> 0 i id_recanvi  = 0 -> Tots els recanvis en un ms d'un any.
   				any  = 0 i mes  = 0 i id_recanvi <> 0 -> Un recanvi.
   				any <> 0 i mes  = 0 i id_recanvi <> 0 -> Un recanvi en un mes.
   				any  = 0 i mes <> 0 i id_recanvi <> 0 -> Un recanvi en un mes de tots els anys.
   				any <> 0 i mes <> 0 i id_recanvi <> 0 -> Un recanvi en un mes d'un any.
   			
******************************************************************************************************/
DROP PROCEDURE IF EXISTS consultaEstadistiquesRecanvi;
DELIMITER //
CREATE PROCEDURE consultaEstadistiquesRecanvi (
		IN idRecanvi INTEGER,
		IN ani INTEGER,
		IN msa INTEGER,
		OUT resultat INTEGER)
BEGIN
	p:BEGIN
		DECLARE tot INTEGER;
		SET resultat = 99;

		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */	
		IF idRecanvi IS NULL OR ani IS NULL OR msa IS NULL THEN 
			SET resultat = 1;
			leave p;
		END IF;
		
		/* Verifiquem que el nmero del mes sigui correcte */
		IF msa < 0 OR msa > 12 THEN
		SET resultat = 4;
			leave p;
		END IF;
		
		/* Construim sentencia SQL segons els valors d'entrada */
		IF idRecanvi = 0 AND ani = 0 AND msa = 0 THEN
			/* Suma de tots els Recanvis */
			SELECT 	 SUM(nombre) AS nombre,
					 SUM(garantia) AS garantia,
					 SUM(cost_total) AS cost_total,
					 SUM(cost_garantia) AS cost_garantia
			FROM estadistiques_recanvi;
			
		ELSEIF idRecanvi = 0 AND ani != 0 AND msa = 0 THEN	
			/* Suma de tots els Recanvis en un any */
			SELECT 	 SUM(nombre) AS nombre,
					 SUM(garantia) AS garantia,
					 SUM(cost_total) AS cost_total,
					 SUM(cost_garantia) AS cost_garantia
			FROM estadistiques_recanvi
			WHERE any = ani;
			
		ELSEIF idRecanvi = 0 AND ani = 0 AND msa != 0 THEN	
			/* Suma de tots els Recanvis en un mes de tots els anys */
			SELECT 	 SUM(nombre) AS nombre,
					 SUM(garantia) AS garantia,
					 SUM(cost_total) AS cost_total,
					 SUM(cost_garantia) AS cost_garantia
			FROM estadistiques_recanvi
			WHERE mes = msa;
		
		ELSEIF idRecanvi = 0 AND ani != 0 AND msa != 0 THEN	
			/* Suma de tots els Recanvis en un mes d'un any */
			SELECT 	 SUM(nombre) AS nombre,
					 SUM(garantia) AS garantia,
					 SUM(cost_total) AS cost_total,
					 SUM(cost_garantia) AS cost_garantia
			FROM estadistiques_recanvi
			WHERE any = ani AND mes = msa;
			
		ELSEIF idRecanvi != 0 AND ani = 0 AND msa = 0 THEN	
			/* Suma d'un Recanvi */
			SELECT 	 SUM(nombre) AS nombre,
					 SUM(garantia) AS garantia,
					 SUM(cost_total) AS cost_total,
					 SUM(cost_garantia) AS cost_garantia
			FROM estadistiques_recanvi
			WHERE id_recanvi = idRecanvi;
			
		ELSEIF idRecanvi != 0 AND ani != 0 AND msa = 0 THEN	
			/* Suma d'un Recanvi en un any */
			SELECT 	 SUM(nombre) AS nombre,
					 SUM(garantia) AS garantia,
					 SUM(cost_total) AS cost_total,
					 SUM(cost_garantia) AS cost_garantia
			FROM estadistiques_recanvi
			WHERE id_recanvi = idRecanvi AND any = ani;
			
		ELSEIF idRecanvi != 0 AND ani = 0 AND msa != 0 THEN	
			/* Suma d'un Recanvi en un mes per a tots els anys */
			SELECT 	 SUM(nombre) AS nombre,
					 SUM(garantia) AS garantia,
					 SUM(cost_total) AS cost_total,
					 SUM(cost_garantia) AS cost_garantia
			FROM estadistiques_recanvi
			WHERE id_recanvi = idRecanvi AND mes = msa;
			
		ELSE
			/* Suma d'un Recanvi en el mes d'un any */
			SELECT 	 SUM(nombre) AS nombre,
					 SUM(garantia) AS garantia,
					 SUM(cost_total) AS cost_total,
					 SUM(cost_garantia) AS cost_garantia
			FROM estadistiques_recanvi
			WHERE id_recanvi = idRecanvi AND any = ani AND mes = msa;
		END IF;
		
		/* Asignem el valor de sortida OK */
		SET resultat = 0;

	END; # p: END;

	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('consultaEstadistiquesRecanvi',resultat);

END //

DELIMITER ;


/******************************************************************************************************
   NOM:      	consultaEstadistiquesProvincia
   
   PROPSIT:	Retornar les estadstiques de les provncies.
   				
   				Amb la combinaci dels parmetres d'entrada obtenim les segents estadstiques
   				(0 s el codi per indicar tots):
   				
   				any  = 0 i mes  = 0 i id_provincia  = 0 -> Totes les provncies.
   				any <> 0 i mes  = 0 i id_provincia  = 0 -> Totes les provncies en un any.
   				any  = 0 i mes <> 0 i id_provincia  = 0 -> Totes les provncies en un mes de tots les anys.
   				any <> 0 i mes <> 0 i id_provincia  = 0 -> Totes les provncies en un ms d'un any.
   				any  = 0 i mes  = 0 i id_provincia <> 0 -> Una provncia.
   				any <> 0 i mes  = 0 i id_provincia <> 0 -> Una provncia en un mes.
   				any  = 0 i mes <> 0 i id_provincia <> 0 -> Una provncia en un mes de tots els anys.
   				any <> 0 i mes <> 0 i id_provincia <> 0 -> Una provncia en un mes d'un any.
   			
******************************************************************************************************/
DROP PROCEDURE IF EXISTS consultaEstadistiquesProvincia;
DELIMITER //
CREATE PROCEDURE consultaEstadistiquesProvincia (
		IN idProvincia INTEGER,
		IN ani INTEGER,
		IN msa INTEGER,
		OUT resultat INTEGER)
BEGIN
	p:BEGIN
		DECLARE tot INTEGER;
		SET resultat = 99;

		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */	
		IF idProvincia IS NULL OR ani IS NULL OR msa IS NULL THEN 
			SET resultat = 1;
			leave p;
		END IF;
		
		/* Verifiquem que el nmero del mes sigui correcte */
		IF msa < 0 OR msa > 12 THEN
		SET resultat = 4;
			leave p;
		END IF;
		
		/* Construim sentencia SQL segons els valors d'entrada */
		IF idProvincia = 0 AND ani = 0 AND msa = 0 THEN
			/* Suma de tots les provncies */
			SELECT 	 SUM(nombre) AS nombre,
					 SUM(garantia) AS garantia
			FROM estadistiques_provincia;
			
		ELSEIF idProvincia = 0 AND ani != 0 AND msa = 0 THEN	
			/* Suma de tots les provncies en un any */
			SELECT 	 SUM(nombre) AS nombre,
					 SUM(garantia) AS garantia
			FROM estadistiques_provincia
			WHERE any = ani;
			
		ELSEIF idProvincia = 0 AND ani = 0 AND msa != 0 THEN	
			/* Suma de tots les provncies en un mes de tots els anys */
			SELECT 	 SUM(nombre) AS nombre,
					 SUM(garantia) AS garantia
			FROM estadistiques_provincia
			WHERE mes = msa;
		
		ELSEIF idProvincia = 0 AND ani != 0 AND msa != 0 THEN	
			/* Suma de tots les provncies en un mes d'un any */
			SELECT 	 SUM(nombre) AS nombre,
					 SUM(garantia) AS garantia
			FROM estadistiques_provincia
			WHERE any = ani AND mes = msa;
			
		ELSEIF idProvincia != 0 AND ani = 0 AND msa = 0 THEN	
			/* Suma d'una provncia */
			SELECT 	 SUM(nombre) AS nombre,
					 SUM(garantia) AS garantia
			FROM estadistiques_provincia
			WHERE id_provincia = idProvincia;
			
		ELSEIF idProvincia != 0 AND ani != 0 AND msa = 0 THEN	
			/* Suma d'una provncia en un any */
			SELECT 	 SUM(nombre) AS nombre,
					 SUM(garantia) AS garantia
			FROM estadistiques_provincia
			WHERE id_provincia = idProvincia AND any = ani;
			
		ELSEIF idProvincia != 0 AND ani = 0 AND msa != 0 THEN	
			/* Suma d'una provncia en un mes per a tots els anys */
			SELECT 	 SUM(nombre) AS nombre,
					 SUM(garantia) AS garantia
			FROM estadistiques_provincia
			WHERE id_provincia = idProvincia AND mes = msa;
			
		ELSE
			/* Suma d'una provncia en el mes d'un any */
			SELECT 	 SUM(nombre) AS nombre,
					 SUM(garantia) AS garantia
			FROM estadistiques_provincia
			WHERE id_provincia = idProvincia AND any = ani AND mes = msa;
		END IF;
		
		/* Asignem el valor de sortida OK */
		SET resultat = 0;

	END; # p: END;

	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('consultaEstadistiquesProvincia',resultat);

END //

DELIMITER ;


/******************************************************************************************************
   NOM:      	consultaEstadistiquesSat
   
   PROPSIT:	Retornar les estadstiques dels SAT.
   				
   				Amb la combinaci dels parmetres d'entrada obtenim les segents estadstiques
   				(0 s el codi per indicar tots):
   				
   				any  = 0 i mes  = 0 i id_sat  = 0 -> Tots els sats.
   				any <> 0 i mes  = 0 i id_sat  = 0 -> Tots els sats en un any.
   				any  = 0 i mes <> 0 i id_sat  = 0 -> Tots els sats en un mes de tots les anys.
   				any <> 0 i mes <> 0 i id_sat  = 0 -> Tots els sats en un ms d'un any.
   				any  = 0 i mes  = 0 i id_sat <> 0 -> Un sat.
   				any <> 0 i mes  = 0 i id_sat <> 0 -> Un sat en un mes.
   				any  = 0 i mes <> 0 i id_sat <> 0 -> Un sat en un mes de tots els anys.
   				any <> 0 i mes <> 0 i id_sat <> 0 -> Un sat en un mes d'un any.
   			
******************************************************************************************************/
DROP PROCEDURE IF EXISTS consultaEstadistiquesSat;
DELIMITER //
CREATE PROCEDURE consultaEstadistiquesSat (
		IN idSat INTEGER,
		IN ani INTEGER,
		IN msa INTEGER,
		OUT resultat INTEGER)
BEGIN
	p:BEGIN
		DECLARE tot INTEGER;
		SET resultat = 99;

		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */	
		IF idSat IS NULL OR ani IS NULL OR msa IS NULL THEN 
			SET resultat = 1;
			leave p;
		END IF;
		
		/* Verifiquem que el nmero del mes sigui correcte */
		IF msa < 0 OR msa > 12 THEN
		SET resultat = 4;
			leave p;
		END IF;
		
		/* Construim sentencia SQL segons els valors d'entrada */
		IF idSat = 0 AND ani = 0 AND msa = 0 THEN
			/* Suma de tots els Sat */
			SELECT 	 SUM(nombre) AS nombre,
					 SUM(garantia) AS garantia,
					 SUM(temps_total) AS temps_total,
					 SUM(cost_total) AS cost_total,
					 SUM(cost_garantia) AS cost_garantia,
					 SUM(nombre_valoracions) AS nombre_valoracions,
					 SUM(total_valoracions) AS total_valoracions
			FROM estadistiques_sat;
			
		ELSEIF idSat = 0 AND ani != 0 AND msa = 0 THEN	
			/* Suma de tots els Sat en un any */
			SELECT 	 SUM(nombre) AS nombre,
					 SUM(garantia) AS garantia,
					 SUM(temps_total) AS temps_total,
					 SUM(cost_total) AS cost_total,
					 SUM(cost_garantia) AS cost_garantia,
					 SUM(nombre_valoracions) AS nombre_valoracions,
					 SUM(total_valoracions) AS total_valoracions
			FROM estadistiques_sat
			WHERE any = ani;
			
		ELSEIF idSat = 0 AND ani = 0 AND msa != 0 THEN	
			/* Suma de tots els Sat en un mes de tots els anys */
			SELECT 	 SUM(nombre) AS nombre,
					 SUM(garantia) AS garantia,
					 SUM(temps_total) AS temps_total,
					 SUM(cost_total) AS cost_total,
					 SUM(cost_garantia) AS cost_garantia,
					 SUM(nombre_valoracions) AS nombre_valoracions,
					 SUM(total_valoracions) AS total_valoracions
			FROM estadistiques_sat
			WHERE mes = msa;
		
		ELSEIF idSat = 0 AND ani != 0 AND msa != 0 THEN	
			/* Suma de tots els Sat en un mes d'un any */
			SELECT 	 SUM(nombre) AS nombre,
					 SUM(garantia) AS garantia,
					 SUM(temps_total) AS temps_total,
					 SUM(cost_total) AS cost_total,
					 SUM(cost_garantia) AS cost_garantia,
					 SUM(nombre_valoracions) AS nombre_valoracions,
					 SUM(total_valoracions) AS total_valoracions
			FROM estadistiques_sat
			WHERE any = ani AND mes = msa;
			
		ELSEIF idSat != 0 AND ani = 0 AND msa = 0 THEN	
			/* Suma d'una Sat */
			SELECT 	 SUM(nombre) AS nombre,
					 SUM(garantia) AS garantia,
					 SUM(temps_total) AS temps_total,
					 SUM(cost_total) AS cost_total,
					 SUM(cost_garantia) AS cost_garantia,
					 SUM(nombre_valoracions) AS nombre_valoracions,
					 SUM(total_valoracions) AS total_valoracions
			FROM estadistiques_sat
			WHERE id_sat = idSat;
			
		ELSEIF idSat != 0 AND ani != 0 AND msa = 0 THEN	
			/* Suma d'una Sat en un any */
			SELECT 	 SUM(nombre) AS nombre,
					 SUM(garantia) AS garantia,
					 SUM(temps_total) AS temps_total,
					 SUM(cost_total) AS cost_total,
					 SUM(cost_garantia) AS cost_garantia,
					 SUM(nombre_valoracions) AS nombre_valoracions,
					 SUM(total_valoracions) AS total_valoracions
			FROM estadistiques_sat
			WHERE id_sat = idSat AND any = ani;
			
		ELSEIF idSat != 0 AND ani = 0 AND msa != 0 THEN	
			/* Suma d'una Sat en un mes per a tots els anys */
			SELECT 	 SUM(nombre) AS nombre,
					 SUM(garantia) AS garantia,
					 SUM(temps_total) AS temps_total,
					 SUM(cost_total) AS cost_total,
					 SUM(cost_garantia) AS cost_garantia,
					 SUM(nombre_valoracions) AS nombre_valoracions,
					 SUM(total_valoracions) AS total_valoracions
			FROM estadistiques_sat
			WHERE id_sat = idSat AND mes = msa;
			
		ELSE
			/* Suma d'una Sat en el mes d'un any */
			SELECT 	 SUM(nombre) AS nombre,
					 SUM(garantia) AS garantia,
					 SUM(temps_total) AS temps_total,
					 SUM(cost_total) AS cost_total,
					 SUM(cost_garantia) AS cost_garantia,
					 SUM(nombre_valoracions) AS nombre_valoracions,
					 SUM(total_valoracions) AS total_valoracions
			FROM estadistiques_sat
			WHERE id_sat = idSat AND any = ani AND mes = msa;
		END IF;
		
		/* Asignem el valor de sortida OK */
		SET resultat = 0;

	END; # p: END;

	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('consultaEstadistiquesSat',resultat);

END //

DELIMITER ;


/******************************************************************************************************
   NOM:      	consultaEstadistiquesProducte
   
   PROPSIT:	Retornar les estadstiques dels productes.
   				
   				Amb la combinaci dels parmetres d'entrada obtenim les segents estadstiques
   				(0 s el codi per indicar tots):
   				
   				any  = 0 i mes  = 0 i id_producte  = 0 -> Tots els productes.
   				any <> 0 i mes  = 0 i id_producte  = 0 -> Tots els productes en un any.
   				any  = 0 i mes <> 0 i id_producte  = 0 -> Tots els productes en un mes de tots les anys.
   				any <> 0 i mes <> 0 i id_producte  = 0 -> Tots els productes en un ms d'un any.
   				any  = 0 i mes  = 0 i id_producte <> 0 -> Un producte.
   				any <> 0 i mes  = 0 i id_producte <> 0 -> Un producte en un mes.
   				any  = 0 i mes <> 0 i id_producte <> 0 -> Un producte en un mes de tots els anys.
   				any <> 0 i mes <> 0 i id_producte <> 0 -> Un producte en un mes d'un any.
   			
******************************************************************************************************/
DROP PROCEDURE IF EXISTS consultaEstadistiquesProducte;
DELIMITER //
CREATE PROCEDURE consultaEstadistiquesProducte (
		IN idProducte INTEGER,
		IN ani INTEGER,
		IN msa INTEGER,
		OUT resultat INTEGER)
BEGIN
	p:BEGIN
		DECLARE tot INTEGER;
		SET resultat = 99;

		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */	
		IF idProducte IS NULL OR ani IS NULL OR msa IS NULL THEN 
			SET resultat = 1;
			leave p;
		END IF;
		
		/* Verifiquem que el nmero del mes sigui correcte */
		IF msa < 0 OR msa > 12 THEN
		SET resultat = 4;
			leave p;
		END IF;
		
		/* Construim sentencia SQL segons els valors d'entrada */
		IF idProducte = 0 AND ani = 0 AND msa = 0 THEN
			/* Suma de tots els Productes */
			SELECT 	 SUM(nombre) AS nombre,
					 SUM(garantia) AS garantia,
					 SUM(temps_total) AS temps_total,
					 SUM(cost_total) AS cost_total,
					 SUM(cost_garantia) AS cost_garantia,
					 SUM(nombre_valoracions) AS nombre_valoracions,
					 SUM(total_valoracions) AS total_valoracions
			FROM estadistiques_producte;
			
		ELSEIF idProducte = 0 AND ani != 0 AND msa = 0 THEN	
			/* Suma de tots els Productes en un any */
			SELECT 	 SUM(nombre) AS nombre,
					 SUM(garantia) AS garantia,
					 SUM(temps_total) AS temps_total,
					 SUM(cost_total) AS cost_total,
					 SUM(cost_garantia) AS cost_garantia,
					 SUM(nombre_valoracions) AS nombre_valoracions,
					 SUM(total_valoracions) AS total_valoracions
			FROM estadistiques_producte
			WHERE any = ani;
			
		ELSEIF idProducte = 0 AND ani = 0 AND msa != 0 THEN	
			/* Suma de tots els Productes en un mes de tots els anys */
			SELECT 	 SUM(nombre) AS nombre,
					 SUM(garantia) AS garantia,
					 SUM(temps_total) AS temps_total,
					 SUM(cost_total) AS cost_total,
					 SUM(cost_garantia) AS cost_garantia,
					 SUM(nombre_valoracions) AS nombre_valoracions,
					 SUM(total_valoracions) AS total_valoracions
			FROM estadistiques_producte
			WHERE mes = msa;
		
		ELSEIF idProducte = 0 AND ani != 0 AND msa != 0 THEN	
			/* Suma de tots els Productes en un mes d'un any */
			SELECT 	 SUM(nombre) AS nombre,
					 SUM(garantia) AS garantia,
					 SUM(temps_total) AS temps_total,
					 SUM(cost_total) AS cost_total,
					 SUM(cost_garantia) AS cost_garantia,
					 SUM(nombre_valoracions) AS nombre_valoracions,
					 SUM(total_valoracions) AS total_valoracions
			FROM estadistiques_producte
			WHERE any = ani AND mes = msa;
			
		ELSEIF idProducte != 0 AND ani = 0 AND msa = 0 THEN	
			/* Suma d'una Productes */
			SELECT 	 SUM(nombre) AS nombre,
					 SUM(garantia) AS garantia,
					 SUM(temps_total) AS temps_total,
					 SUM(cost_total) AS cost_total,
					 SUM(cost_garantia) AS cost_garantia,
					 SUM(nombre_valoracions) AS nombre_valoracions,
					 SUM(total_valoracions) AS total_valoracions
			FROM estadistiques_producte
			WHERE id_producte = idProducte;
			
		ELSEIF idProducte != 0 AND ani != 0 AND msa = 0 THEN	
			/* Suma d'una Productes en un any */
			SELECT 	 SUM(nombre) AS nombre,
					 SUM(garantia) AS garantia,
					 SUM(temps_total) AS temps_total,
					 SUM(cost_total) AS cost_total,
					 SUM(cost_garantia) AS cost_garantia,
					 SUM(nombre_valoracions) AS nombre_valoracions,
					 SUM(total_valoracions) AS total_valoracions
			FROM estadistiques_producte
			WHERE id_producte = idProducte AND any = ani;
			
		ELSEIF idProducte != 0 AND ani = 0 AND msa != 0 THEN	
			/* Suma d'una Productes en un mes per a tots els anys */
			SELECT 	 SUM(nombre) AS nombre,
					 SUM(garantia) AS garantia,
					 SUM(temps_total) AS temps_total,
					 SUM(cost_total) AS cost_total,
					 SUM(cost_garantia) AS cost_garantia,
					 SUM(nombre_valoracions) AS nombre_valoracions,
					 SUM(total_valoracions) AS total_valoracions
			FROM estadistiques_producte
			WHERE id_producte = idProducte AND mes = msa;
			
		ELSE
			/* Suma d'una Producte en el mes d'un any */
			SELECT 	 SUM(nombre) AS nombre,
					 SUM(garantia) AS garantia,
					 SUM(temps_total) AS temps_total,
					 SUM(cost_total) AS cost_total,
					 SUM(cost_garantia) AS cost_garantia,
					 SUM(nombre_valoracions) AS nombre_valoracions,
					 SUM(total_valoracions) AS total_valoracions
			FROM estadistiques_producte
			WHERE id_producte = idProducte AND any = ani AND mes = msa;
		END IF;
		
		/* Asignem el valor de sortida OK */
		SET resultat = 0;

	END; # p: END;

	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('consultaEstadistiquesProducte',resultat);

END //

DELIMITER ;


/******************************************************************************************************
   NOM:      	consultaEstadistiquesPais
   
   PROPSIT:	Retornar les estadstiques dels pasos.
   				
   				Amb la combinaci dels parmetres d'entrada obtenim les segents estadstiques
   				(0 s el codi per indicar tots):
   				
   				any  = 0 i mes  = 0 i id_pais  = 0 -> Tots els pasos.
   				any <> 0 i mes  = 0 i id_pais  = 0 -> Tots els pasos en un any.
   				any  = 0 i mes <> 0 i id_pais  = 0 -> Tots els pasos en un mes de tots les anys.
   				any <> 0 i mes <> 0 i id_pais  = 0 -> Tots els pasos en un ms d'un any.
   				any  = 0 i mes  = 0 i id_pais <> 0 -> Un pas.
   				any <> 0 i mes  = 0 i id_pais <> 0 -> Un pas en un mes.
   				any  = 0 i mes <> 0 i id_pais <> 0 -> Un pas en un mes de tots els anys.
   				any <> 0 i mes <> 0 i id_pais <> 0 -> Un pas en un mes d'un any.
   			
******************************************************************************************************/
DROP PROCEDURE IF EXISTS consultaEstadistiquesPais;
DELIMITER //
CREATE PROCEDURE consultaEstadistiquesPais (
		IN idPais INTEGER,
		IN ani INTEGER,
		IN msa INTEGER,
		OUT resultat INTEGER)
BEGIN
	p:BEGIN
		DECLARE tot INTEGER;
		SET resultat = 99;

		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */	
		IF idPais IS NULL OR ani IS NULL OR msa IS NULL THEN 
			SET resultat = 1;
			leave p;
		END IF;
		
		/* Verifiquem que el nmero del mes sigui correcte */
		IF msa < 0 OR msa > 12 THEN
		SET resultat = 4;
			leave p;
		END IF;
		
		/* Construim sentencia SQL segons els valors d'entrada */
		IF idPais = 0 AND ani = 0 AND msa = 0 THEN
			/* Suma de tots els Pasos */
			SELECT 	 SUM(nombre) AS nombre,
					 SUM(garantia) AS garantia,
					 SUM(temps_total) AS temps_total,
					 SUM(cost_total) AS cost_total,
					 SUM(cost_garantia) AS cost_garantia,
					 SUM(nombre_valoracions) AS nombre_valoracions,
					 SUM(total_valoracions) AS total_valoracions
			FROM estadistiques_pais;
			
		ELSEIF idPais = 0 AND ani != 0 AND msa = 0 THEN	
			/* Suma de tots els Pasos en un any */
			SELECT 	 SUM(nombre) AS nombre,
					 SUM(garantia) AS garantia,
					 SUM(temps_total) AS temps_total,
					 SUM(cost_total) AS cost_total,
					 SUM(cost_garantia) AS cost_garantia,
					 SUM(nombre_valoracions) AS nombre_valoracions,
					 SUM(total_valoracions) AS total_valoracions
			FROM estadistiques_pais
			WHERE any = ani;
			
		ELSEIF idPais = 0 AND ani = 0 AND msa != 0 THEN	
			/* Suma de tots els Pasos en un mes de tots els anys */
			SELECT 	 SUM(nombre) AS nombre,
					 SUM(garantia) AS garantia,
					 SUM(temps_total) AS temps_total,
					 SUM(cost_total) AS cost_total,
					 SUM(cost_garantia) AS cost_garantia,
					 SUM(nombre_valoracions) AS nombre_valoracions,
					 SUM(total_valoracions) AS total_valoracions
			FROM estadistiques_pais
			WHERE mes = msa;
		
		ELSEIF idPais = 0 AND ani != 0 AND msa != 0 THEN	
			/* Suma de tots els Pasos en un mes d'un any */
			SELECT 	 SUM(nombre) AS nombre,
					 SUM(garantia) AS garantia,
					 SUM(temps_total) AS temps_total,
					 SUM(cost_total) AS cost_total,
					 SUM(cost_garantia) AS cost_garantia,
					 SUM(nombre_valoracions) AS nombre_valoracions,
					 SUM(total_valoracions) AS total_valoracions
			FROM estadistiques_pais
			WHERE any = ani AND mes = msa;
			
		ELSEIF idPais != 0 AND ani = 0 AND msa = 0 THEN	
			/* Suma d'un Pasos */
			SELECT 	 SUM(nombre) AS nombre,
					 SUM(garantia) AS garantia,
					 SUM(temps_total) AS temps_total,
					 SUM(cost_total) AS cost_total,
					 SUM(cost_garantia) AS cost_garantia,
					 SUM(nombre_valoracions) AS nombre_valoracions,
					 SUM(total_valoracions) AS total_valoracions
			FROM estadistiques_pais
			WHERE id_pais = idPais;
			
		ELSEIF idPais != 0 AND ani != 0 AND msa = 0 THEN	
			/* Suma d'un Pasos en un any */
			SELECT 	 SUM(nombre) AS nombre,
					 SUM(garantia) AS garantia,
					 SUM(temps_total) AS temps_total,
					 SUM(cost_total) AS cost_total,
					 SUM(cost_garantia) AS cost_garantia,
					 SUM(nombre_valoracions) AS nombre_valoracions,
					 SUM(total_valoracions) AS total_valoracions
			FROM estadistiques_pais
			WHERE id_pais = idPais AND any = ani;
			
		ELSEIF idPais != 0 AND ani = 0 AND msa != 0 THEN	
			/* Suma d'un Pasos en un mes per a tots els anys */
			SELECT 	 SUM(nombre) AS nombre,
					 SUM(garantia) AS garantia,
					 SUM(temps_total) AS temps_total,
					 SUM(cost_total) AS cost_total,
					 SUM(cost_garantia) AS cost_garantia,
					 SUM(nombre_valoracions) AS nombre_valoracions,
					 SUM(total_valoracions) AS total_valoracions
			FROM estadistiques_pais
			WHERE id_pais = idPais AND mes = msa;
			
		ELSE
			/* Suma d'un Pais en el mes d'un any */
			SELECT 	 SUM(nombre) AS nombre,
					 SUM(garantia) AS garantia,
					 SUM(temps_total) AS temps_total,
					 SUM(cost_total) AS cost_total,
					 SUM(cost_garantia) AS cost_garantia,
					 SUM(nombre_valoracions) AS nombre_valoracions,
					 SUM(total_valoracions) AS total_valoracions
			FROM estadistiques_pais
			WHERE id_pais = idPais AND any = ani AND mes = msa;
		END IF;
		
		/* Asignem el valor de sortida OK */
		SET resultat = 0;

	END; # p: END;

	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('consultaEstadistiquesPais',resultat);

END //

DELIMITER ;


/******************************************************************************************************
   NOM:      	consultaEstadistiquesIncidencia
   
   PROPSIT:	Retornar les estadstiques de les incidncies.
   				
   				Amb la combinaci dels parmetres d'entrada obtenim les
   				segents estadstiques (0 s el codi per indicar tots):
   				
   				any  = 0 i mes  = 0 -> Totes les incidncies
   				any <> 0 i mes  = 0 -> Totes les incidncies en un any
   				any  = 0 i mes <> 0 -> Totes les incidncies en un mes de tots
   									   els anys
   				any <> 0 i mes <> 0 -> Totes les incidncies en un mes i un
   									   any
   				
******************************************************************************************************/
DROP PROCEDURE IF EXISTS consultaEstadistiquesIncidencia;
DELIMITER //
CREATE PROCEDURE consultaEstadistiquesIncidencia (
		IN idIncidencia INTEGER,
		IN ani INTEGER,
		IN msa INTEGER,
		OUT resultat INTEGER)
BEGIN
	p:BEGIN
		DECLARE tot INTEGER;
		SET resultat = 99;

		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */	
		IF idIncidencia IS NULL OR ani IS NULL OR msa IS NULL THEN 
			SET resultat = 1;
			leave p;
		END IF;
		
		/* Verifiquem que el nmero del mes sigui correcte */
		IF msa < 0 OR msa > 12 THEN
		SET resultat = 4;
			leave p;
		END IF;
		
		/* Construim sentencia SQL segons els valors d'entrada */
		IF ani = 0 AND msa = 0 THEN
			/* Suma de totes les Incidencies */
			SELECT 	 SUM(nombre) AS nombre,
					 SUM(garantia) AS garantia,
					 SUM(temps_total) AS temps_total,
					 SUM(cost_total) AS cost_total,
					 SUM(cost_garantia) AS cost_garantia,
					 SUM(nombre_valoracions) AS nombre_valoracions,
					 SUM(total_valoracions) AS total_valoracions
			FROM estadistiques_incidencia;
			
		ELSEIF ani != 0 AND msa = 0 THEN	
			/* Suma de totes les indicencies en un any */
			SELECT 	 SUM(nombre) AS nombre,
					 SUM(garantia) AS garantia,
					 SUM(temps_total) AS temps_total,
					 SUM(cost_total) AS cost_total,
					 SUM(cost_garantia) AS cost_garantia,
					 SUM(nombre_valoracions) AS nombre_valoracions,
					 SUM(total_valoracions) AS total_valoracions
			FROM estadistiques_incidencia
			WHERE any = ani;
			
		ELSEIF ani = 0 AND msa != 0 THEN	
			/* Suma de totes les Incidencies en un mes de tots els anys */
			SELECT 	 SUM(nombre) AS nombre,
					 SUM(garantia) AS garantia,
					 SUM(temps_total) AS temps_total,
					 SUM(cost_total) AS cost_total,
					 SUM(cost_garantia) AS cost_garantia,
					 SUM(nombre_valoracions) AS nombre_valoracions,
					 SUM(total_valoracions) AS total_valoracions
			FROM estadistiques_incidencia
			WHERE mes = msa;
		
		ELSE	
			/* Suma de les incidencies en un any i un mes */
			SELECT 	 SUM(nombre) AS nombre,
					 SUM(garantia) AS garantia,
					 SUM(temps_total) AS temps_total,
					 SUM(cost_total) AS cost_total,
					 SUM(cost_garantia) AS cost_garantia,
					 SUM(nombre_valoracions) AS nombre_valoracions,
					 SUM(total_valoracions) AS total_valoracions
			FROM estadistiques_incidencia
			WHERE any = ani AND mes = msa;
		END IF;
		
		/* Asignem el valor de sortida OK */
		SET resultat = 0;

	END; # p: END;

	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('consultaEstadistiquesIncidencia',resultat);

END //

DELIMITER ;


/******************************************************************************************************
   NOM:      	llistaEstadistiquesClient
   
   PROPSIT:	Retornar la llista d'estadstiques dels clients.
   				
   				Amb la combinaci dels parmetres d'entrada obtenim els 
   				segents llistats d'estadstiques (0 s el codi per indicar 
   				tots):
   				
   				any  = 0 i id_client  = 0 -> Tots els clients
   				any <> 0 i id_client  = 0 -> Tots els clients per any
   				any  = 0 i id_client <> 0 -> Client
   				any <> 0 i id_client <> 0 -> Client per any
   				
******************************************************************************************************/
DROP PROCEDURE IF EXISTS llistaEstadistiquesClient;
DELIMITER //
CREATE PROCEDURE llistaEstadistiquesClient (
		IN idClient INTEGER,
		IN ani INTEGER,
		OUT resultat INTEGER)
BEGIN
	p:BEGIN
		DECLARE tot INTEGER;
		SET resultat = 99;

		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */	
		IF idClient IS NULL OR ani IS NULL THEN 
			SET resultat = 1;
			leave p;
		END IF;
		
		/* Construim sentencia SQL segons els valors d'entrada */
		IF ani = 0 AND idClient = 0 THEN
			/* Llista de tots els clients */
			SELECT * FROM estadistiques_client;
			
		ELSEIF ani != 0 AND idClient = 0 THEN	
			/* Llista de tots els clients per any */
			SELECT * FROM estadistiques_client WHERE any = ani;
			
		ELSEIF ani = 0 AND idClient != 0 THEN
			/* Llista client */
			SELECT * FROM estadistiques_client WHERE id_client = idClient;
		ELSE
			/* Llista client en un any */
			SELECT * FROM estadistiques_client WHERE id_client = idClient  AND any = ani;
		END IF;
		
		/* Asignem el valor de sortida OK */
		SET resultat = 0;

	END; # p: END;

	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('llistaEstadistiquesClient',resultat);

END //

DELIMITER ;


/******************************************************************************************************
   NOM:      	llistaEstadistiquesFamilia
   
   PROPSIT:	Retornar la llista de les estadstiques de les familia.
   				
   				Amb la combinaci dels parmetres d'entrada obtenim els segents llistats
   				d'estadstiques (0 s el codi per indicar tots):
   				
   				any  = 0 i mes  = 0 i id_familia  = 0 -> Totes els famlies.
   				any <> 0 i mes  = 0 i id_familia  = 0 -> Totes les famlies en un any.
   				any  = 0 i mes <> 0 i id_familia  = 0 -> Totes les famlies en un mes de tots les anys.
   				any <> 0 i mes <> 0 i id_familia  = 0 -> Totes les famlies en un ms d'un any.
   				any  = 0 i mes  = 0 i id_familia <> 0 -> Una familia.
   				any <> 0 i mes  = 0 i id_familia <> 0 -> Una familia en un mes.
   				any  = 0 i mes <> 0 i id_familia <> 0 -> Una familia en un mes de Totes les anys.
   				any <> 0 i mes <> 0 i id_familia <> 0 -> Una familia en un mes d'un any.
   			
******************************************************************************************************/
DROP PROCEDURE IF EXISTS llistaEstadistiquesFamilia;
DELIMITER //
CREATE PROCEDURE llistaEstadistiquesFamilia (
		IN idFamilia INTEGER,
		IN ani INTEGER,
		IN msa INTEGER,
		OUT resultat INTEGER)
BEGIN
	p:BEGIN
		DECLARE tot INTEGER;
		SET resultat = 99;

		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */	
		IF idFamilia IS NULL OR ani IS NULL OR msa IS NULL THEN 
			SET resultat = 1;
			leave p;
		END IF;
		
		/* Verifiquem que el nmero del mes sigui correcte */
		IF msa < 0 OR msa > 12 THEN
		SET resultat = 4;
			leave p;
		END IF;
		
		/* Construim sentencia SQL segons els valors d'entrada */
		IF idFamilia = 0 AND ani = 0 AND msa = 0 THEN
			/* Llista de totes les famlies */
			SELECT * FROM estadistiques_familia;
			
		ELSEIF idFamilia = 0 AND ani != 0 AND msa = 0 THEN	
			/* Llista de totes les famlies en un any */
			SELECT * FROM estadistiques_familia WHERE any = ani;
			
		ELSEIF idFamilia = 0 AND ani = 0 AND msa != 0 THEN	
			/* Llista de totes les famlies en un mes de tots els anys */
			SELECT * FROM estadistiques_familia WHERE mes = msa;
		
		ELSEIF idFamilia = 0 AND ani != 0 AND msa != 0 THEN	
			/* Llista de totes les famlies en un mes d'un any */
			SELECT * FROM estadistiques_familia WHERE any = ani AND mes = msa;
			
		ELSEIF idFamilia != 0 AND ani = 0 AND msa = 0 THEN	
			/* Llista d'una familia */
			SELECT * FROM estadistiques_familia WHERE id_familia = idFamilia;
			
		ELSEIF idFamilia != 0 AND ani != 0 AND msa = 0 THEN	
			/* Llista d'una familia en un any */
			SELECT * FROM estadistiques_familia WHERE id_familia = idFamilia AND any = ani;
			
		ELSEIF idFamilia != 0 AND ani = 0 AND msa != 0 THEN	
			/* Llista d'una familia en un mes per a tots els anys */
			SELECT * FROM estadistiques_familia WHERE id_familia = idFamilia AND mes = msa;
			
		ELSE
			/* Llista d'una familia en el mes d'un any */
			SELECT * FROM estadistiques_familia WHERE id_familia = idFamilia AND any = ani AND mes = msa;
		END IF;
		
		/* Asignem el valor de sortida OK */
		SET resultat = 0;

	END; # p: END;

	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('llistaEstadistiquesFamilia',resultat);

END //

DELIMITER ;


/******************************************************************************************************
   NOM:      	llistaEstadistiquesTipus
   
   PROPSIT:	Retornar la llista de les estadstiques dels tipus.
   				
   				Amb la combinaci dels parmetres d'entrada obtenim els segents llistats
   				d'estadstiques (0 s el codi per indicar tots):
   				
   				any  = 0 i mes  = 0 i id_tipus  = 0 -> Tots els tipus.
   				any <> 0 i mes  = 0 i id_tipus  = 0 -> Tots els tipus en un any.
   				any  = 0 i mes <> 0 i id_tipus  = 0 -> Tots els tipus en un mes de tots les anys.
   				any <> 0 i mes <> 0 i id_tipus  = 0 -> Tots els tipus en un ms d'un any.
   				any  = 0 i mes  = 0 i id_tipus <> 0 -> Un tipus.
   				any <> 0 i mes  = 0 i id_tipus <> 0 -> Un tipus en un mes.
   				any  = 0 i mes <> 0 i id_tipus <> 0 -> Un tipus en un mes de Totes les anys.
   				any <> 0 i mes <> 0 i id_tipus <> 0 -> Un tipus en un mes d'un any.
   			
******************************************************************************************************/
DROP PROCEDURE IF EXISTS llistaEstadistiquesTipus;
DELIMITER //
CREATE PROCEDURE llistaEstadistiquesTipus (
		IN idTipus INTEGER,
		IN ani INTEGER,
		IN msa INTEGER,
		OUT resultat INTEGER)
BEGIN
	p:BEGIN
		DECLARE tot INTEGER;
		SET resultat = 99;

		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */	
		IF idTipus IS NULL OR ani IS NULL OR msa IS NULL THEN 
			SET resultat = 1;
			leave p;
		END IF;
		
		/* Verifiquem que el nmero del mes sigui correcte */
		IF msa < 0 OR msa > 12 THEN
		SET resultat = 4;
			leave p;
		END IF;
		
		/* Construim sentencia SQL segons els valors d'entrada */
		IF idTipus = 0 AND ani = 0 AND msa = 0 THEN
			/* Llista de tots els tipus */
			SELECT * FROM estadistiques_tipus;
			
		ELSEIF idTipus = 0 AND ani != 0 AND msa = 0 THEN	
			/* Llista de tots els tipus en un any */
			SELECT * FROM estadistiques_tipus WHERE any = ani;
			
		ELSEIF idTipus = 0 AND ani = 0 AND msa != 0 THEN	
			/* Llista de tots els tipus en un mes de tots els anys */
			SELECT * FROM estadistiques_tipus WHERE mes = msa;
		
		ELSEIF idTipus = 0 AND ani != 0 AND msa != 0 THEN	
			/* Llista de tots els tipus en un mes d'un any */
			SELECT * FROM estadistiques_tipus WHERE any = ani AND mes = msa;
			
		ELSEIF idTipus != 0 AND ani = 0 AND msa = 0 THEN	
			/* Llista d'una tipus */
			SELECT * FROM estadistiques_tipus WHERE id_tipus = idTipus;
			
		ELSEIF idTipus != 0 AND ani != 0 AND msa = 0 THEN	
			/* Llista d'una tipus en un any */
			SELECT * FROM estadistiques_tipus WHERE id_tipus = idTipus AND any = ani;
			
		ELSEIF idTipus != 0 AND ani = 0 AND msa != 0 THEN	
			/* Llista d'una tipus en un mes per a tots els anys */
			SELECT * FROM estadistiques_tipus WHERE id_tipus = idTipus AND mes = msa;
			
		ELSE
			/* Llista d'una tipus en el mes d'un any */
			SELECT * FROM estadistiques_tipus WHERE id_tipus = idTipus AND any = ani AND mes = msa;
		END IF;
		
		/* Asignem el valor de sortida OK */
		SET resultat = 0;

	END; # p: END;

	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('llistaEstadistiquesTipus',resultat);

END //

DELIMITER ;


/******************************************************************************************************
   NOM:      	llistaEstadistiquesrecanvi
   
   PROPSIT:	Retornar la llista de les estadstiques dels recanvis.
   				
   				Amb la combinaci dels parmetres d'entrada obtenim els segents llistats
   				d'estadstiques (0 s el codi per indicar tots):
   				
   				any  = 0 i mes  = 0 i id_recanvi  = 0 -> Tots els recanvis.
   				any <> 0 i mes  = 0 i id_recanvi  = 0 -> Tots els recanvis en un any.
   				any  = 0 i mes <> 0 i id_recanvi  = 0 -> Tots els recanvis en un mes de tots les anys.
   				any <> 0 i mes <> 0 i id_recanvi  = 0 -> Tots els recanvis en un ms d'un any.
   				any  = 0 i mes  = 0 i id_recanvi <> 0 -> Un recanvi.
   				any <> 0 i mes  = 0 i id_recanvi <> 0 -> Un recanvi en un mes.
   				any  = 0 i mes <> 0 i id_recanvi <> 0 -> Un recanvi en un mes de Totes les anys.
   				any <> 0 i mes <> 0 i id_recanvi <> 0 -> Un recanvi en un mes d'un any.
   			
******************************************************************************************************/
DROP PROCEDURE IF EXISTS llistaEstadistiquesRecanvi;
DELIMITER //
CREATE PROCEDURE llistaEstadistiquesRecanvi (
		IN idRecanvi INTEGER,
		IN ani INTEGER,
		IN msa INTEGER,
		OUT resultat INTEGER)
BEGIN
	p:BEGIN
		DECLARE tot INTEGER;
		SET resultat = 99;

		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */	
		IF idRecanvi IS NULL OR ani IS NULL OR msa IS NULL THEN 
			SET resultat = 1;
			leave p;
		END IF;
		
		/* Verifiquem que el nmero del mes sigui correcte */
		IF msa < 0 OR msa > 12 THEN
		SET resultat = 4;
			leave p;
		END IF;
		
		/* Construim sentencia SQL segons els valors d'entrada */
		IF idRecanvi = 0 AND ani = 0 AND msa = 0 THEN
			/* Llista de tots els Recanvis */
			SELECT * FROM estadistiques_recanvi;
			
		ELSEIF idRecanvi = 0 AND ani != 0 AND msa = 0 THEN	
			/* Llista de tots els Recanvis en un any */
			SELECT * FROM estadistiques_recanvi WHERE any = ani;
			
		ELSEIF idRecanvi = 0 AND ani = 0 AND msa != 0 THEN	
			/* Llista de tots els Recanvis en un mes de tots els anys */
			SELECT * FROM estadistiques_recanvi WHERE mes = msa;
		
		ELSEIF idRecanvi = 0 AND ani != 0 AND msa != 0 THEN	
			/* Llista de tots els Recanvis en un mes d'un any */
			SELECT * FROM estadistiques_recanvi WHERE any = ani AND mes = msa;
			
		ELSEIF idRecanvi != 0 AND ani = 0 AND msa = 0 THEN	
			/* Llista d'un Recanvi */
			SELECT * FROM estadistiques_recanvi WHERE id_recanvi = idRecanvi;
			
		ELSEIF idRecanvi != 0 AND ani != 0 AND msa = 0 THEN	
			/* Llista d'un Recanvi en un any */
			SELECT * FROM estadistiques_recanvi WHERE id_recanvi = idRecanvi AND any = ani;
			
		ELSEIF idRecanvi != 0 AND ani = 0 AND msa != 0 THEN	
			/* Llista d'un Recanvi en un mes per a tots els anys */
			SELECT * FROM estadistiques_recanvi WHERE id_recanvi = idRecanvi AND mes = msa;
			
		ELSE
			/* Llista d'un Recanvi en el mes d'un any */
			SELECT * FROM estadistiques_recanvi WHERE id_recanvi = idRecanvi AND any = ani AND mes = msa;
		END IF;
		
		/* Asignem el valor de sortida OK */
		SET resultat = 0;

	END; # p: END;

	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('llistaEstadistiquesRecanvi',resultat);

END //

DELIMITER ;


/******************************************************************************************************
   NOM:      	llistaEstadistiquesProvincia
   
   PROPSIT:	Retornar la llista de les estadstiques de les provncies.
   				
   				Amb la combinaci dels parmetres d'entrada obtenim els segents llistats
   				d'estadstiques (0 s el codi per indicar tots):
   				
   				any  = 0 i mes  = 0 i id_provincia  = 0 -> Totes les provncies.
   				any <> 0 i mes  = 0 i id_provincia  = 0 -> Totes les provncies en un any.
   				any  = 0 i mes <> 0 i id_provincia  = 0 -> Totes les provncies en un mes de tots les anys.
   				any <> 0 i mes <> 0 i id_provincia  = 0 -> Totes les provncies en un ms d'un any.
   				any  = 0 i mes  = 0 i id_provincia <> 0 -> Una provncia.
   				any <> 0 i mes  = 0 i id_provincia <> 0 -> Una provncia en un mes.
   				any  = 0 i mes <> 0 i id_provincia <> 0 -> Una provncia en un mes de Totes les anys.
   				any <> 0 i mes <> 0 i id_provincia <> 0 -> Una provncia en un mes d'un any.
   			
******************************************************************************************************/
DROP PROCEDURE IF EXISTS llistaEstadistiquesProvincia;
DELIMITER //
CREATE PROCEDURE llistaEstadistiquesProvincia (
		IN idProvincia INTEGER,
		IN ani INTEGER,
		IN msa INTEGER,
		OUT resultat INTEGER)
BEGIN
	p:BEGIN
		DECLARE tot INTEGER;
		SET resultat = 99;

		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */	
		IF idProvincia IS NULL OR ani IS NULL OR msa IS NULL THEN 
			SET resultat = 1;
			leave p;
		END IF;
		
		/* Verifiquem que el nmero del mes sigui correcte */
		IF msa < 0 OR msa > 12 THEN
		SET resultat = 4;
			leave p;
		END IF;
		
		/* Construim sentencia SQL segons els valors d'entrada */
		IF idProvincia = 0 AND ani = 0 AND msa = 0 THEN
			/* Llista de tots les provncies */
			SELECT * FROM estadistiques_provincia;
			
		ELSEIF idProvincia = 0 AND ani != 0 AND msa = 0 THEN	
			/* Llista de tots les provncies en un any */
			SELECT * FROM estadistiques_provincia WHERE any = ani;
			
		ELSEIF idProvincia = 0 AND ani = 0 AND msa != 0 THEN	
			/* Llista de tots les provncies en un mes de tots els anys */
			SELECT * FROM estadistiques_provincia WHERE mes = msa;
		
		ELSEIF idProvincia = 0 AND ani != 0 AND msa != 0 THEN	
			/* Llista de tots les provncies en un mes d'un any */
			SELECT * FROM estadistiques_provincia WHERE any = ani AND mes = msa;
			
		ELSEIF idProvincia != 0 AND ani = 0 AND msa = 0 THEN	
			/* Llista d'una provncia */
			SELECT * FROM estadistiques_provincia WHERE id_provincia = idProvincia;
			
		ELSEIF idProvincia != 0 AND ani != 0 AND msa = 0 THEN	
			/* Llista d'una provncia en un any */
			SELECT * FROM estadistiques_provincia WHERE id_provincia = idProvincia AND any = ani;
			
		ELSEIF idProvincia != 0 AND ani = 0 AND msa != 0 THEN	
			/* Llista d'una provncia en un mes per a tots els anys */
			SELECT * FROM estadistiques_provincia WHERE id_provincia = idProvincia AND mes = msa;
			
		ELSE
			/* Llista d'una provncia en el mes d'un any */
			SELECT * FROM estadistiques_provincia WHERE id_provincia = idProvincia AND any = ani AND mes = msa;
		END IF;
		
		/* Asignem el valor de sortida OK */
		SET resultat = 0;

	END; # p: END;

	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('llistaEstadistiquesProvincia',resultat);

END //

DELIMITER ;


/******************************************************************************************************
   NOM:      	llistaEstadistiquesSat
   
   PROPSIT:	Retornar la llista de les estadstiques dels SATs.
   				
   				Amb la combinaci dels parmetres d'entrada obtenim les segents estadstiques
   				(0 s el codi per indicar tots):
   				
   				any  = 0 i mes  = 0 i id_sat  = 0 -> Tots els sats.
   				any <> 0 i mes  = 0 i id_sat  = 0 -> Tots els sats en un any.
   				any  = 0 i mes <> 0 i id_sat  = 0 -> Tots els sats en un mes de tots les anys.
   				any <> 0 i mes <> 0 i id_sat  = 0 -> Tots els sats en un ms d'un any.
   				any  = 0 i mes  = 0 i id_sat <> 0 -> Un sat.
   				any <> 0 i mes  = 0 i id_sat <> 0 -> Un sat en un mes.
   				any  = 0 i mes <> 0 i id_sat <> 0 -> Un sat en un mes de tots els anys.
   				any <> 0 i mes <> 0 i id_sat <> 0 -> Un sat en un mes d'un any.
   			
******************************************************************************************************/
DROP PROCEDURE IF EXISTS llistaEstadistiquesSat;
DELIMITER //
CREATE PROCEDURE llistaEstadistiquesSat (
		IN idSat INTEGER,
		IN ani INTEGER,
		IN msa INTEGER,
		OUT resultat INTEGER)
BEGIN
	p:BEGIN
		DECLARE tot INTEGER;
		SET resultat = 99;

		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */	
		IF idSat IS NULL OR ani IS NULL OR msa IS NULL THEN 
			SET resultat = 1;
			leave p;
		END IF;
		
		/* Verifiquem que el nmero del mes sigui correcte */
		IF msa < 0 OR msa > 12 THEN
		SET resultat = 4;
			leave p;
		END IF;
		
		/* Construim sentencia SQL segons els valors d'entrada */
		IF idSat = 0 AND ani = 0 AND msa = 0 THEN
			/* Llista de tots els Sat */
			SELECT * FROM estadistiques_sat;
			
		ELSEIF idSat = 0 AND ani != 0 AND msa = 0 THEN	
			/* Llista de tots els Sat en un any */
			SELECT * FROM estadistiques_sat WHERE any = ani;
			
		ELSEIF idSat = 0 AND ani = 0 AND msa != 0 THEN	
			/* Llista de tots els Sat en un mes de tots els anys */
			SELECT * FROM estadistiques_sat WHERE mes = msa;
		
		ELSEIF idSat = 0 AND ani != 0 AND msa != 0 THEN	
			/* Llista de tots els Sat en un mes d'un any */
			SELECT * FROM estadistiques_sat WHERE any = ani AND mes = msa;
			
		ELSEIF idSat != 0 AND ani = 0 AND msa = 0 THEN	
			/* Llista d'una Sat */
			SELECT * FROM estadistiques_sat WHERE id_sat = idSat;
			
		ELSEIF idSat != 0 AND ani != 0 AND msa = 0 THEN	
			/* Llista d'una Sat en un any */
			SELECT * FROM estadistiques_sat WHERE id_sat = idSat AND any = ani;
			
		ELSEIF idSat != 0 AND ani = 0 AND msa != 0 THEN	
			/* Llista d'una Sat en un mes per a tots els anys */
			SELECT * FROM estadistiques_sat WHERE id_sat = idSat AND mes = msa;
			
		ELSE
			/* Llista d'una Sat en el mes d'un any */
			SELECT * FROM estadistiques_sat WHERE id_sat = idSat AND any = ani AND mes = msa;
		END IF;
		
		/* Asignem el valor de sortida OK */
		SET resultat = 0;

	END; # p: END;

	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('llistaEstadistiquesSat',resultat);

END //

DELIMITER ;


/******************************************************************************************************
   NOM:      	llistaEstadistiquesProducte
   
   PROPSIT:	Retornar la llista de les estadstiques dels productes.
   				
   				Amb la combinaci dels parmetres d'entrada obtenim els segents llistats
   				d'estadstiques (0 s el codi per indicar tots):
   				
   				any  = 0 i mes  = 0 i id_producte  = 0 -> Tots els productes.
   				any <> 0 i mes  = 0 i id_producte  = 0 -> Tots els productes en un any.
   				any  = 0 i mes <> 0 i id_producte  = 0 -> Tots els productes en un mes de tots les anys.
   				any <> 0 i mes <> 0 i id_producte  = 0 -> Tots els productes en un ms d'un any.
   				any  = 0 i mes  = 0 i id_producte <> 0 -> Un producte.
   				any <> 0 i mes  = 0 i id_producte <> 0 -> Un producte en un mes.
   				any  = 0 i mes <> 0 i id_producte <> 0 -> Un producte en un mes de tots els anys.
   				any <> 0 i mes <> 0 i id_producte <> 0 -> Un producte en un mes d'un any.
   			
******************************************************************************************************/
DROP PROCEDURE IF EXISTS llistaEstadistiquesProducte;
DELIMITER //
CREATE PROCEDURE llistaEstadistiquesProducte (
		IN idProducte INTEGER,
		IN ani INTEGER,
		IN msa INTEGER,
		OUT resultat INTEGER)
BEGIN
	p:BEGIN
		DECLARE tot INTEGER;
		SET resultat = 99;

		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */	
		IF idProducte IS NULL OR ani IS NULL OR msa IS NULL THEN 
			SET resultat = 1;
			leave p;
		END IF;
		
		/* Verifiquem que el nmero del mes sigui correcte */
		IF msa < 0 OR msa > 12 THEN
		SET resultat = 4;
			leave p;
		END IF;
		
		/* Construim sentencia SQL segons els valors d'entrada */
		IF idProducte = 0 AND ani = 0 AND msa = 0 THEN
			/* Llista de tots els Productes */
			SELECT * FROM estadistiques_producte;
			
		ELSEIF idProducte = 0 AND ani != 0 AND msa = 0 THEN	
			/* Llista de tots els Productes en un any */
			SELECT * FROM estadistiques_producte WHERE any = ani;
			
		ELSEIF idProducte = 0 AND ani = 0 AND msa != 0 THEN	
			/* Llista de tots els Productes en un mes de tots els anys */
			SELECT * FROM estadistiques_producte WHERE mes = msa;
		
		ELSEIF idProducte = 0 AND ani != 0 AND msa != 0 THEN	
			/* Llista de tots els Productes en un mes d'un any */
			SELECT * FROM estadistiques_producte WHERE any = ani AND mes = msa;
			
		ELSEIF idProducte != 0 AND ani = 0 AND msa = 0 THEN	
			/* Llista d'una Productes */
			SELECT * FROM estadistiques_producte WHERE id_producte = idProducte;
			
		ELSEIF idProducte != 0 AND ani != 0 AND msa = 0 THEN	
			/* Llista d'una Productes en un any */
			SELECT * FROM estadistiques_producte WHERE id_producte = idProducte AND any = ani;
			
		ELSEIF idProducte != 0 AND ani = 0 AND msa != 0 THEN	
			/* Llista d'una Productes en un mes per a tots els anys */
			SELECT * FROM estadistiques_producte WHERE id_producte = idProducte AND mes = msa;
			
		ELSE
			/* Llista d'una Producte en el mes d'un any */
			SELECT * FROM estadistiques_producte WHERE id_producte = idProducte AND any = ani AND mes = msa;
		END IF;
		
		/* Asignem el valor de sortida OK */
		SET resultat = 0;

	END; # p: END;

	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('llistaEstadistiquesProducte',resultat);

END //

DELIMITER ;


/******************************************************************************************************
   NOM:      	llistaEstadistiquesPais
   
   PROPSIT:	Retornar la llista de les estadstiques dels pasos.
   				
   				Amb la combinaci dels parmetres d'entrada obtenim els segents llistats
   				d'estadstiques (0 s el codi per indicar tots):
   				
   				any  = 0 i mes  = 0 i id_pais  = 0 -> Tots els pasos.
   				any <> 0 i mes  = 0 i id_pais  = 0 -> Tots els pasos en un any.
   				any  = 0 i mes <> 0 i id_pais  = 0 -> Tots els pasos en un mes de tots les anys.
   				any <> 0 i mes <> 0 i id_pais  = 0 -> Tots els pasos en un ms d'un any.
   				any  = 0 i mes  = 0 i id_pais <> 0 -> Un pas.
   				any <> 0 i mes  = 0 i id_pais <> 0 -> Un pas en un mes.
   				any  = 0 i mes <> 0 i id_pais <> 0 -> Un pas en un mes de tots els anys.
   				any <> 0 i mes <> 0 i id_pais <> 0 -> Un pas en un mes d'un any.
   			
******************************************************************************************************/
DROP PROCEDURE IF EXISTS llistaEstadistiquesPais;
DELIMITER //
CREATE PROCEDURE llistaEstadistiquesPais (
		IN idPais INTEGER,
		IN ani INTEGER,
		IN msa INTEGER,
		OUT resultat INTEGER)
BEGIN
	p:BEGIN
		DECLARE tot INTEGER;
		SET resultat = 99;

		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */	
		IF idPais IS NULL OR ani IS NULL OR msa IS NULL THEN 
			SET resultat = 1;
			leave p;
		END IF;
		
		/* Verifiquem que el nmero del mes sigui correcte */
		IF msa < 0 OR msa > 12 THEN
		SET resultat = 4;
			leave p;
		END IF;
		
		/* Construim sentencia SQL segons els valors d'entrada */
		IF idPais = 0 AND ani = 0 AND msa = 0 THEN
			/* Llista de tots els Pasos */
			SELECT * FROM estadistiques_pais;
			
		ELSEIF idPais = 0 AND ani != 0 AND msa = 0 THEN	
			/* Llista de tots els Pasos en un any */
			SELECT * FROM estadistiques_pais WHERE any = ani;
			
		ELSEIF idPais = 0 AND ani = 0 AND msa != 0 THEN	
			/* Llista de tots els Pasos en un mes de tots els anys */
			SELECT * FROM estadistiques_pais WHERE mes = msa;
		
		ELSEIF idPais = 0 AND ani != 0 AND msa != 0 THEN	
			/* Llista de tots els Pasos en un mes d'un any */
			SELECT * FROM estadistiques_pais WHERE any = ani AND mes = msa;
			
		ELSEIF idPais != 0 AND ani = 0 AND msa = 0 THEN	
			/* Llista d'un Pasos */
			SELECT * FROM estadistiques_pais WHERE id_pais = idPais;
			
		ELSEIF idPais != 0 AND ani != 0 AND msa = 0 THEN	
			/* Llista d'un Pasos en un any */
			SELECT * FROM estadistiques_pais WHERE id_pais = idPais AND any = ani;
			
		ELSEIF idPais != 0 AND ani = 0 AND msa != 0 THEN	
			/* Llista d'un Pasos en un mes per a tots els anys */
			SELECT * FROM estadistiques_pais WHERE id_pais = idPais AND mes = msa;
			
		ELSE
			/* Llista d'un Pais en el mes d'un any */
			SELECT * FROM estadistiques_pais WHERE id_pais = idPais AND any = ani AND mes = msa;
		END IF;
		
		/* Asignem el valor de sortida OK */
		SET resultat = 0;

	END; # p: END;

	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('llistaEstadistiquesPais',resultat);

END //

DELIMITER ;


/******************************************************************************************************
   NOM:      	llistaEstadistiquesIncidencia
   
   PROPSIT:	Retornar la llista d'estadstiques de les incidncies.
   				
   				Amb la combinaci dels parmetres d'entrada obtenim els 
   				segents llistats d'estadstiques (0 s el codi per indicar 
   				tots):
   				
   				any  = 0 i mes  = 0 -> Totes les incidncies
   				any <> 0 i mes  = 0 -> Totes les incidncies en un any
   				any  = 0 i mes <> 0 -> Totes les incidncies en un mes de tots
   									   els anys
   				any <> 0 i mes <> 0 -> Totes les incidncies en un mes i un
   									   any
   				
******************************************************************************************************/
DROP PROCEDURE IF EXISTS llistaEstadistiquesIncidencia;
DELIMITER //
CREATE PROCEDURE llistaEstadistiquesIncidencia (
		IN ani INTEGER,
		IN msa INTEGER,
		OUT resultat INTEGER)
BEGIN
	p:BEGIN
		DECLARE tot INTEGER;
		SET resultat = 99;

		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */	
		IF ani IS NULL OR msa IS NULL THEN 
			SET resultat = 1;
			leave p;
		END IF;
		
		/* Verifiquem que el nmero del mes sigui correcte */
		IF msa < 0 OR msa > 12 THEN
		SET resultat = 4;
			leave p;
		END IF;
		
		/* Construim sentencia SQL segons els valors d'entrada */
		IF ani = 0 AND msa = 0 THEN
			/* Llista de totes les Incidencies */
			SELECT * FROM estadistiques_incidencia;
			
		ELSEIF ani != 0 AND msa = 0 THEN	
			/* Llista de totes les indicencies en un any */
			SELECT * FROM estadistiques_incidencia WHERE any = ani;
			
		ELSEIF ani = 0 AND msa != 0 THEN	
			/* Llista de totes les Incidencies en un mes de tots els anys */
			SELECT * FROM estadistiques_incidencia WHERE mes = msa;
		
		ELSE
			/* Llista de les incidencies en un any i un mes */
			SELECT * FROM estadistiques_incidencia WHERE any = ani AND mes = msa;
		END IF;
		
		/* Asignem el valor de sortida OK */
		SET resultat = 0;

	END; # p: END;

	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('llistaEstadistiquesIncidencia',resultat);

END //

DELIMITER ;