/******************************************************************************
   NOM:      	modificaPais
   
   PROPSIT:	Modifica un pas a la base de dades.
   
******************************************************************************/
DROP PROCEDURE IF EXISTS modificaPais;
DELIMITER //
CREATE PROCEDURE modificaPais (
		IN idPais INTEGER,
		IN nomPais VARCHAR(200),
		OUT resultat INTEGER)
BEGIN
	p:BEGIN
		DECLARE tot INTEGER;
		SET resultat = 99;

		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */
		IF idPais IS NULL OR nomPais IS NULL THEN
			SET resultat = 1;
			leave p;
		END IF;
		
		/* Cerquem si existeix el registre a modificar */
   		SELECT COUNT(*) INTO tot FROM pais WHERE id_pais = idPais;
   		
   		/* Si no existeix el registre gravem error i sortim */	
   		IF tot = 0 THEN
   			SET resultat = 5;
   			leave p;
   		END IF;
   		
   		/* Eliminem espais a l'inici i fi de la variable */
		SELECT TRIM(nomPais) INTO nomPais;
   		
   		/* Cerquem si ja existeix un registre igual */
   		SELECT COUNT(*) INTO tot FROM pais WHERE nom_pais = nomPais AND id_pais!=idPais;
   		
   		/* Si existeix el registre gravem error i sortim */	
   		IF tot > 0 THEN
   			SET resultat = 6;
   			leave p;
   		END IF;   		
   		
   		/* Modifiquem el registre */
   		UPDATE pais SET nom_pais = nomPais WHERE id_pais = idPais;

   		/* Asignem el valor de sortida OK */
		SET resultat = 0;
   		
   	END; # p: END;
	
   	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('modificaPais',resultat);	
   
END //

DELIMITER ;


/******************************************************************************
   NOM:      	modificaIdioma
   
   PROPSIT:	Modifica un idioma a la base de dades.
   
******************************************************************************/
DROP PROCEDURE IF EXISTS modificaIdioma;
DELIMITER //
CREATE PROCEDURE modificaIdioma (
		IN idIdioma INTEGER,
		IN nomIdioma VARCHAR(50),
		OUT resultat INTEGER)
BEGIN
	p:BEGIN
		DECLARE tot INTEGER;
		SET resultat = 99;
		
		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */
		IF idIdioma IS NULL OR nomIdioma IS NULL THEN
			SET resultat = 1;
			leave p;
		END IF;
		
		/* Cerquem si existeix el registre a modificar */
   		SELECT COUNT(*) INTO tot FROM idioma WHERE id_idioma = idIdioma;
   		
   		/* Si no existeix el registre gravem error i sortim */	
   		IF tot = 0 THEN
   			SET resultat = 5;
   			leave p;
   		END IF;
		
   		/* Eliminem espais a l'inici i fi de la variable */
   		SELECT TRIM(nomIdioma) INTO nomIdioma;
   		
   		/* Cerquem si ja existeix un registre igual */
   		SELECT COUNT(*) INTO tot FROM idioma WHERE nom_idioma = nomIdioma AND id_idioma != idIdioma;
   		
   		/* Si existeix el registre gravem error i sortim */	
   		IF tot > 0 THEN
   			SET resultat = 6;
   			leave p;
   		END IF;
   		
   		/* Modifiquem el registre */
   		UPDATE idioma SET nom_idioma = nomIdioma WHERE id_idioma = idIdioma;

   		/* Asignem el valor de sortida OK */
		SET resultat = 0;
 		
 	END; # p: END;

 	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('modificaIdioma',resultat);
   
END //

DELIMITER ;
   

/******************************************************************************
   NOM:      	modificaProvincia
   
   PROPSIT:	Modifica una provincia a la base de dades.
   
******************************************************************************/
DROP PROCEDURE IF EXISTS modificaProvincia;
DELIMITER //
CREATE PROCEDURE modificaProvincia (
		IN idProvincia INTEGER,
		IN idPais INTEGER,
		IN nomProvincia VARCHAR(60),
		OUT resultat INTEGER)

BEGIN
	p:BEGIN
		DECLARE tot INTEGER;
		SET resultat = 99;

		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */	
		IF idProvincia IS NULL OR idPais IS NULL OR nomProvincia IS NULL THEN 
			SET resultat = 1;
			leave p;
		END IF;

		/* Cerquem si existeix el registre a modificar */
   		SELECT COUNT(*) INTO tot FROM provincia WHERE id_provincia = idProvincia;
   		
   		/* Si no existeix el registre gravem error i sortim */	
   		IF tot = 0 THEN
   			SET resultat = 5;
   			leave p;
   		END IF;
		
		/* Cerquem la clau externa */
   		SELECT COUNT(*) INTO tot FROM pais WHERE id_pais = idPais;
   		
   		/* Si no existeix la clau externa gravem error i sortim */
	   	IF tot = 0 THEN
   			SET resultat = 3;
   			leave p;
		END IF;

		/* Eliminem espais a l'inici i fi de la variable */
		SELECT TRIM(nomProvincia) INTO nomProvincia;
		
		/* Cerquem si ja existeix un registre igual */
		SELECT COUNT(*) INTO tot FROM provincia WHERE provincia = nomProvincia AND id_pais = idPais AND id_provincia != idProvincia;
   		
		/* Si existeix el registre gravem error i sortim */	
	   	IF tot > 0 THEN
   			SET resultat = 6;
   			leave p;
		END IF;
		
		/* Modifiquem el registre */
		UPDATE provincia SET id_pais = idPais, provincia = nomProvincia WHERE id_provincia = idProvincia;
	
		/* Asignem el valor de sortida OK */
		SET resultat = 0;
		
 	END; # p: END;

 	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('modificaProvincia',resultat);
   	
END //

DELIMITER ;


/******************************************************************************
   NOM:      	modificaDescripcioFamiliaProducte
   
   PROPSIT:	Modifica la descripci d'una familia de productes en un
   				idioma a la base de dades.
   				
******************************************************************************/
DROP PROCEDURE IF EXISTS modificaDescripcioFamiliaProducte;
DELIMITER //
CREATE PROCEDURE modificaDescripcioFamiliaProducte (
		IN idFamilia INTEGER,
		IN idIdioma INTEGER,
		IN fNom VARCHAR(60),
		IN fDescripcio TEXT,
		OUT resultat INTEGER)

BEGIN
	p:BEGIN
		DECLARE tot INTEGER;
		SET resultat = 99;
	
		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */
		IF idFamilia IS NULL OR idIdioma IS NULL OR fNom IS NULL THEN 
			SET resultat = 1;
			leave p;
		END IF;
		
		/* Cerquem si existeix el registre a modificar */
   		SELECT COUNT(*) INTO tot FROM desc_familia_producte WHERE id_familia = idFamilia AND id_idioma = idIdioma;
   		
   		/* Si no existeix el registre gravem error i sortim */	
   		IF tot = 0 THEN
   			SET resultat = 5;
   			leave p;
   		END IF;
		
		/* Cerquem la clau externa */
   		SELECT COUNT(*) INTO tot FROM familia_producte WHERE id_familia = idFamilia;
   		
   		/* Si no existeix la clau externa gravem error i sortim */
	   	IF tot = 0 THEN
   			SET resultat = 3;
   			leave p;
		END IF;

		/* Cerquem la clau externa */
   		SELECT COUNT(*) INTO tot FROM idioma WHERE id_idioma = idIdioma;
   		
   		/* Si no existeix la clau externa gravem error i sortim */
	   	IF tot = 0 THEN
   			SET resultat = 3;
   			leave p;
		END IF;
		
		/* Eliminem espais a l'inici i fi de la variable */
		SELECT TRIM(fNom) INTO fNom;
		
		/* Cerquem si ja existeix un registre igual */
		SELECT COUNT(*) INTO tot FROM desc_familia_producte WHERE id_familia != idFamilia AND id_idioma = idIdioma AND nom = fNom;
   		
		/* Si existeix el registre gravem error i sortim */	
	   	IF tot > 0 THEN
   			SET resultat = 6;
   			leave p;
		END IF;
		
		/* Modifiquem el registre */
		UPDATE desc_familia_producte SET nom = fNom, descripcio = fDescripcio WHERE id_familia = idFamilia AND id_idioma = idIdioma;

		/* Asignem el valor de sortida OK */
		SET resultat = 0;
		
 	END; # p: END;

 	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('modificaDescripcioFamiliaProducte',resultat);
   	
END //

DELIMITER ;


/******************************************************************************
   NOM:      	modificaProducte
   
   PROPSIT:	Modifica un producte a la base de dades.
   				
******************************************************************************/
DROP PROCEDURE IF EXISTS modificaProducte;
DELIMITER //
CREATE PROCEDURE modificaProducte (
		IN idProducte INTEGER,
		IN pCodi VARCHAR(30),
		IN idFamilia INTEGER,
		OUT resultat INTEGER)

BEGIN
	p:BEGIN
		DECLARE tot INTEGER;
		SET resultat = 99;
	
		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */
		IF idProducte IS NULL OR pCodi IS NULL OR idFamilia IS NULL THEN 
			SET resultat = 1;
			leave p;
		END IF;

		/* Cerquem si existeix el registre a modificar */
   		SELECT COUNT(*) INTO tot FROM producte WHERE id_producte = idProducte;
   		
   		/* Si no existeix el registre gravem error i sortim */	
   		IF tot = 0 THEN
   			SET resultat = 5;
   			leave p;
   		END IF;
				
		/* Cerquem la clau externa */
   		SELECT COUNT(*) INTO tot FROM familia_producte WHERE id_familia = idFamilia;
   		
   		/* Si no existeix la clau externa gravem error i sortim */
	   	IF tot = 0 THEN
   			SET resultat = 3;
   			leave p;
		END IF;

		/* Eliminem espais a l'inici i fi de la variable */
		SELECT TRIM(pCodi) INTO pCodi;
		
		/* Cerquem si ja existeix un registre igual */
   		SELECT COUNT(*) INTO tot FROM producte WHERE codi = pCodi AND id_producte != idProducte;
   		
   		/* Si existeix el registre gravem error i sortim */	
	   	IF tot > 0 THEN
   			SET resultat = 6;
   			leave p;
		END IF;
		
		/* Modifiquem el registre */
		UPDATE producte SET codi = pCodi, id_familia = idFamilia WHERE id_producte = idProducte;

		/* Asignem el valor de sortida OK */
		SET resultat = 0;
		
 	END; # p: END;

 	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('modificaProducte',resultat);
   	
END //

DELIMITER ;


/******************************************************************************
   NOM:      	modificaDescripcioProducte
   
   PROPSIT:	Modifica la descripci d'un producte en un idioma a la 
   				base de dades.
   				
******************************************************************************/
DROP PROCEDURE IF EXISTS modificaDescripcioProducte;
DELIMITER //
CREATE PROCEDURE modificaDescripcioProducte (
		IN idProducte INTEGER,
		IN idIdioma INTEGER,
		IN dCurta VARCHAR(200),
		IN dLlarga TEXT,
		OUT resultat INTEGER)

BEGIN
	p:BEGIN
		DECLARE tot INTEGER;
		SET resultat = 99;
	
		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */
		IF idProducte IS NULL OR idIdioma IS NULL OR dCurta IS NULL OR dLlarga IS NULL THEN 
			SET resultat = 1;
			leave p;
		END IF;
		
		/* Cerquem si existeix el registre a modificar */
		SELECT COUNT(*) INTO tot FROM desc_producte WHERE id_producte = idProducte AND id_idioma = idIdioma;
   		
   		/* Si no existeix el registre gravem error i sortim */	
   		IF tot = 0 THEN
   			SET resultat = 5;
   			leave p;
   		END IF;
		
		/* Cerquem la clau externa */
   		SELECT COUNT(*) INTO tot FROM producte WHERE id_producte = idProducte;
   		
   		/* Si no existeix la clau externa gravem error i sortim */
	   	IF tot = 0 THEN
   			SET resultat = 3;
   			leave p;
		END IF;

		/* Cerquem la clau externa */
   		SELECT COUNT(*) INTO tot FROM idioma WHERE id_idioma = idIdioma;
   		
   		/* Si no existeix la clau externa gravem error i sortim */
	   	IF tot = 0 THEN
   			SET resultat = 3;
   			leave p;
		END IF;
		
		/* Eliminem espais a l'inici i fi de la variable */
		SELECT TRIM(dCurta) INTO dCurta;
		
		/* Cerquem si ja existeix el registre */
   		SELECT COUNT(*) INTO tot FROM desc_producte WHERE id_idioma = idIdioma AND descripcio_curta = dCurta AND id_producte != idProducte;
		
		/* Si existeix el registre gravem error i sortim */	
	   	IF tot > 0 THEN
   			SET resultat = 6;
   			leave p;
		END IF;
		
		/* Modifiquem el registre */
		UPDATE desc_producte SET descripcio_curta = dCurta, descripcio_llarga = dLlarga WHERE id_producte = idProducte AND id_idioma = idIdioma;

		/* Asignem el valor de sortida OK */
		SET resultat = 0;
		
 	END; # p: END;

 	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('modificaDescripcioProducte',resultat);
   	
END //

DELIMITER ;


/******************************************************************************
   NOM:      	modificaGarantia
   
   PROPSIT:	Modifica la garantia d'un producte en un pas a la base
   				de dades.
   				
******************************************************************************/
DROP PROCEDURE IF EXISTS modificaGarantia;
DELIMITER //
CREATE PROCEDURE modificaGarantia (
		IN idPais INTEGER,
		IN idProducte INTEGER,
		IN tGarantia INTEGER,
		OUT resultat INTEGER)
BEGIN
	p:BEGIN
		DECLARE tot INTEGER;
		SET resultat = 99;
	
		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */
		IF idPais IS NULL OR idProducte IS NULL OR tGarantia IS NULL THEN 
			SET resultat = 1;
			leave p;
		END IF;
	
		/* Verifiquem que els valors estiguin dintre del rang, del contrari gravem error i sortim */
		IF tGarantia < 0 THEN
			SET resultat = 4;
			leave p;
		END IF;
		
		/* Cerquem si existeix el registre a modificar */
		SELECT COUNT(*) INTO tot FROM garantia WHERE id_producte = idProducte AND id_pais = idPais;
   		
   		/* Si no existeix el registre gravem error i sortim */	
   		IF tot = 0 THEN
   			SET resultat = 5;
   			leave p;
   		END IF;
		
		/* Cerquem la clau externa */
	   	SELECT COUNT(*) INTO tot FROM pais WHERE id_pais = idPais;
   		
	   	/* Si no existeix la clau externa gravem error i sortim */
   		IF tot = 0 THEN
   			SET resultat = 3;
	   		leave p;
		END IF;
		
		/* Cerquem la clau externa */
		SELECT COUNT(*) INTO tot FROM producte WHERE id_producte = idProducte;
   		
		/* Si no existeix la clau externa gravem error i sortim */
	   	IF tot = 0 THEN
   			SET resultat = 3;
   			leave p;
		END IF;
		
		/* Modifiquem el registre */
		UPDATE garantia SET garantia = tGarantia WHERE id_producte = idProducte AND id_pais = idPais;

		/* Asignem el valor de sortida OK */
		SET resultat = 0;
		
	END; # p: END;

	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('modificaGarantia',resultat);
	
END //

DELIMITER ;


/******************************************************************************
   NOM:      	modificaClient
   
   PROPSIT:	Modifica un client a la base de dades.
   				
******************************************************************************/
DROP PROCEDURE IF EXISTS modificaClient;
DELIMITER //
CREATE PROCEDURE modificaClient (
		IN idClient INTEGER,
		IN cNif VARCHAR(12),
		IN cNom VARCHAR(50),
		IN cCognoms VARCHAR(200),
		IN cDireccio VARCHAR(200),
		IN cCp VARCHAR(15),
		IN cPoblacio VARCHAR(120),
		IN idProvincia INTEGER,
		IN cTelefonf VARCHAR(15),
		IN cTelefonm VARCHAR(15),
		IN cCorreue VARCHAR(120),
		IN cObservacions TEXT,
		OUT resultat INTEGER)
BEGIN
	p:BEGIN
		DECLARE tot INTEGER;
		SET resultat = 99;
	
		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */
		IF idClient IS NULL OR cNIF IS NULL OR cNom IS NULL OR cCognoms IS NULL OR cDireccio IS NULL OR cCp IS NULL OR cPoblacio IS NULL OR idProvincia IS NULL OR cTelefonf IS NULL OR cCorreue IS NULL OR cObservacions IS NULL THEN 
			SET resultat = 1;
			leave p;
		END IF;
	
		/* Cerquem si existeix el registre a modificar */
		SELECT COUNT(*) INTO tot FROM client WHERE id_client = idClient;
   		
   		/* Si no existeix el registre gravem error i sortim */	
   		IF tot = 0 THEN
   			SET resultat = 5;
   			leave p;
   		END IF;
		
		/* Eliminem espais en blanc al inici i fi de les variables */
		SELECT TRIM(cNif) INTO cNif;
		SELECT TRIM(cNom) INTO cNom;
		SELECT TRIM(cCognoms) INTO cCognoms;
		SELECT TRIM(cCp) INTO cCp;
		SELECT TRIM(cPoblacio) INTO cPoblacio;
		SELECT TRIM(cTelefonf) INTO cTelefonf;
		SELECT TRIM(cTelefonm) INTO cTelefonm;
		SELECT TRIM(cCorreue) INTO cCorreue;
		
		/* Cerquem la clau externa */
	   	SELECT COUNT(*) INTO tot FROM provincia WHERE id_provincia = idProvincia;
   		
	   	/* Si no existeix la clau externa gravem error i sortim */
   		IF tot = 0 THEN
   			SET resultat = 3;
	   		leave p;
		END IF;
		
		/* Cerquem si ja existeix el registre */
   		SELECT COUNT(*) INTO tot FROM client WHERE id_client != idClient AND nif = cNif;
		
		/* Si existeix el registre gravem error i sortim */	
	   	IF tot > 0 THEN
   			SET resultat = 6;
   			leave p;
		END IF;
		
		/* Modifiquem el registre */
		UPDATE client SET
			nif = cNif, nom = cNom, cognoms = cCognoms, direccio = cDireccio, cp = cCp, poblacio = cPoblacio,
			id_provincia = idProvincia, telefonf = cTelefonf, telefonm = cTelefonm, correue = cCorreue, observacions = cObservacions
		WHERE id_client = idClient; 

		/* Asignem el valor de sortida OK */
		SET resultat = 0;

	END; # p: END;

	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('modificaClient',resultat);
	
END //

DELIMITER ;


/******************************************************************************
   NOM:      	modificaSat
   
   PROPSIT:	Modifica un SAT (servei atencici tcnica) a la base de
   				dades.
   				
******************************************************************************/
DROP PROCEDURE IF EXISTS modificaSat;
DELIMITER //
CREATE PROCEDURE modificaSat (
		IN idSat INTEGER,
		IN sNif VARCHAR(12),
		IN sNom VARCHAR(120),
		IN sDireccio VARCHAR(200),
		IN sCp VARCHAR(15),
		IN sPoblacio VARCHAR(120),
		IN idProvincia INTEGER,
		IN sTelefon VARCHAR(15),
		IN sFax VARCHAR(15),
		IN sCorreue VARCHAR(120),
		IN sHorari VARCHAR(120),
		OUT resultat INTEGER)
BEGIN
	p:BEGIN
		DECLARE tot INTEGER;
		SET resultat = 99;
	
		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */
		IF idSat IS NULL OR sNIF IS NULL OR sNom IS NULL OR sDireccio IS NULL OR sCp IS NULL OR sPoblacio IS NULL OR idProvincia IS NULL OR sTelefon IS NULL OR sFax IS NULL OR sCorreue IS NULL OR sHorari IS NULL THEN 
			SET resultat = 1;
			leave p;
		END IF;
	
		/* Eliminem espais en blanc al inici i fi de les variables */
		SELECT TRIM(sNif) INTO sNif;
		SELECT TRIM(sNom) INTO sNom;
		SELECT TRIM(sCp) INTO sCp;
		SELECT TRIM(sPoblacio) INTO sPoblacio;
		SELECT TRIM(sTelefon) INTO sTelefon;
		SELECT TRIM(sFax) INTO sFax;
		SELECT TRIM(sCorreue) INTO sCorreue;
		SELECT TRIM(sHorari) INTO sHorari;
		
		/* Cerquem si existeix el registre a modificar */
		SELECT COUNT(*) INTO tot FROM sat WHERE id_sat = idSat;
   		
   		/* Si no existeix el registre gravem error i sortim */	
   		IF tot = 0 THEN
   			SET resultat = 5;
   			leave p;
   		END IF;
		
		/* Cerquem la clau externa */
	   	SELECT COUNT(*) INTO tot FROM provincia WHERE id_provincia = idProvincia;
   		
	   	/* Si no existeix la clau externa gravem error i sortim */
   		IF tot = 0 THEN
   			SET resultat = 3;
	   		leave p;
		END IF;
		
		/* Cerquem si ja existeix un registre igual */
		SELECT COUNT(*) INTO tot FROM sat WHERE nif = sNif AND id_sat != idSat;
   		
		/* Si existeix el registre gravem error i sortim */	
	   	IF tot > 0 THEN
   			SET resultat = 6;
   			leave p;
		END IF;
		
		/* Modifiquem el registre */
		UPDATE sat SET
			nif = sNif, nom = sNom, direccio = sDireccio, cp = sCp, poblacio = sPoblacio,
			id_provincia = idProvincia, telefon = sTelefon, fax = sFax, correue = sCorreue, horari = sHorari
		WHERE id_sat = idSat; 

		/* Asignem el valor de sortida OK */
		SET resultat = 0;
		
	END; # p: END;

	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('modificaSat',resultat);
	
END //

DELIMITER ;


/******************************************************************************
   NOM:      	modificaRecanvi
   
   PROPSIT:	Modifica un recanvi a la base de dades.
   				
******************************************************************************/
DROP PROCEDURE IF EXISTS modificaRecanvi;
DELIMITER //
CREATE PROCEDURE modificaRecanvi (
		IN idRecanvi INTEGER,
		IN rCodi VARCHAR(50),
		IN rPreu DOUBLE,
		OUT resultat INTEGER)
BEGIN
	p:BEGIN
		DECLARE tot INTEGER;
		SET resultat = 99;
	
		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */
		IF idRecanvi IS NULL OR rCodi IS NULL OR rPreu IS NULL THEN 
			SET resultat = 1;
			leave p;
		END IF;

		/* Verifiquem que els valors estiguin dintre del rang, del contrari gravem error i sortim */
		IF rPreu < 0 THEN
			SET resultat = 4;
			leave p;
		END IF;
		
		/* Cerquem si existeix el registre a modificar */
		SELECT COUNT(*) INTO tot FROM recanvi WHERE id_recanvi = idRecanvi;
   		
   		/* Si no existeix el registre gravem error i sortim */	
   		IF tot = 0 THEN
   			SET resultat = 5;
   			leave p;
   		END IF;
		
		/* Eliminem espais a l'inici i fi de la variable */
		SELECT TRIM(rCodi) INTO rCodi;
		
		/* Cerquem si ja existeix un registre igual */
		SELECT COUNT(*) INTO tot FROM recanvi WHERE codi = rCodi AND id_recanvi != idRecanvi;
   		
		/* Si existeix el registre gravem error i sortim */	
	   	IF tot > 0 THEN
   			SET resultat = 6;
   			leave p;
		END IF;
		
		/* Modifiquem el registre */
		UPDATE recanvi SET codi = rCodi, preu = rPreu WHERE id_recanvi = idRecanvi;

		/* Asignem el valor de sortida OK */
		SET resultat = 0;

	END; # p: END;

	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('modificaRecanvi',resultat);

END //

DELIMITER ;


/******************************************************************************
   NOM:      	modificaDescripcioRecanvi
   
   PROPSIT:	Modifica la descripci d'un recanvi en un idioma a la
   				base de dades.
   				
******************************************************************************/
DROP PROCEDURE IF EXISTS modificaDescripcioRecanvi;
DELIMITER //
CREATE PROCEDURE modificaDescripcioRecanvi (
		IN idRecanvi INTEGER,
		IN idIdioma INTEGER,
		IN dCurta VARCHAR(200),
		IN dLlarga TEXT,
		OUT resultat INTEGER)
BEGIN
	p:BEGIN
		DECLARE tot INTEGER;
		SET resultat = 99;
	
		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */
		IF idRecanvi IS NULL OR idIdioma IS NULL OR dCurta IS NULL OR dLlarga IS NULL THEN 
			SET resultat = 1;
			leave p;
		END IF;
		
		/* Cerquem si existeix el registre a modificar */
		SELECT COUNT(*) INTO tot FROM desc_recanvi WHERE id_recanvi = idRecanvi AND id_idioma = idIdioma;
   		
   		/* Si no existeix el registre gravem error i sortim */	
   		IF tot = 0 THEN
   			SET resultat = 5;
   			leave p;
   		END IF;
		
		/* Cerquem la clau externa */
	   	SELECT COUNT(*) INTO tot FROM recanvi WHERE id_recanvi = idRecanvi;
   		
	   	/* Si no existeix la clau externa gravem error i sortim */
   		IF tot = 0 THEN
   			SET resultat = 3;
	   		leave p;
		END IF;
	
		/* Cerquem la clau externa */
		SELECT COUNT(*) INTO tot FROM idioma WHERE id_idioma = idIdioma;
   		
		/* Si no existeix la clau externa gravem error i sortim */
   		IF tot = 0 THEN
   			SET resultat = 3;
	   		leave p;
		END IF;
		
		/* Eliminem espais a l'inici i fi de la variable */
		SELECT TRIM(dCurta) INTO dCurta;
		
		/* Cerquem si ja existeix el registre */
   		SELECT COUNT(*) INTO tot FROM desc_recanvi WHERE id_idioma = idIdioma AND descripcio_curta = dCurta AND id_recanvi != idRecanvi;
		
		/* Si existeix el registre gravem error i sortim */	
	   	IF tot > 0 THEN
   			SET resultat = 6;
   			leave p;
		END IF;
		
		/* Modifiquem el registre */
		UPDATE desc_recanvi SET descripcio_curta = dCurta, descripcio_llarga = dLlarga WHERE id_recanvi = idRecanvi AND id_idioma = idIdioma;

		/* Asignem el valor de sortida OK */
		SET resultat = 0;
		
	END; # p: END;

	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('modificaDescripcioRecanvi',resultat);
	
END //

DELIMITER ;


/******************************************************************************
   NOM:      	modificaDescripcioTipusIncidencia
   
   PROPSIT:	Modifica la descripci d'un tipus d'incidncia en un
   				idioma a la base de dades.
   				
******************************************************************************/
DROP PROCEDURE IF EXISTS modificaDescripcioTipusIncidencia;
DELIMITER //
CREATE PROCEDURE modificaDescripcioTipusIncidencia (
		IN idTipus INTEGER,
		IN idIdioma INTEGER,		
		IN tDescripcio VARCHAR(60),
		OUT resultat INTEGER)

BEGIN
	p:BEGIN
		DECLARE tot INTEGER;
		SET resultat = 99;
	
		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */
		IF idTipus IS NULL OR idIdioma IS NULL OR tDescripcio IS NULL THEN 
			SET resultat = 1;
			leave p;
		END IF;
		
		/* Cerquem si existeix el registre a modificar */
		SELECT COUNT(*) INTO tot FROM desc_tipus_incidencia WHERE id_tipus = idTipus AND id_idioma = idIdioma;
   		
   		/* Si no existeix el registre gravem error i sortim */	
   		IF tot = 0 THEN
   			SET resultat = 5;
   			leave p;
   		END IF;

		/* Cerquem la clau externa */
   		SELECT COUNT(*) INTO tot FROM tipus_incidencia WHERE id_tipus = idTipus;
   		
   		/* Si no existeix la clau externa gravem error i sortim */
	   	IF tot = 0 THEN
   			SET resultat = 3;
   			leave p;
		END IF;

		/* Cerquem la clau externa */
   		SELECT COUNT(*) INTO tot FROM idioma WHERE id_idioma = idIdioma;
   		
   		/* Si no existeix la clau externa gravem error i sortim */
	   	IF tot = 0 THEN
   			SET resultat = 3;
   			leave p;
		END IF;
		
		/* Eliminem espais a l'inici i fi de la variable */
		SELECT TRIM(tDescripcio) INTO tDescripcio;
		
		/* Cerquem si ja existeix un registre igual */
		SELECT COUNT(*) INTO tot FROM desc_tipus_incidencia WHERE id_tipus != idTipus AND id_idioma = idIdioma AND descipcio = tDescripcio;
   		
		/* Si existeix el registre gravem error i sortim */	
	   	IF tot > 0 THEN
   			SET resultat = 6;
   			leave p;
		END IF;
				
		/* Modifiquem el registre */
		UPDATE desc_tipus_incidencia SET descripcio = tDescripcio WHERE id_tipus = idTipus AND id_idioma = idIdioma;

		/* Asignem el valor de sortida OK */
		SET resultat = 0;
		
 	END; # p: END;

 	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('modificaDescripcioTipusIncidencia',resultat);
   	
END //

DELIMITER ;


/******************************************************************************
   NOM:      	modificaDescripcioEstatIncidencia
   
   PROPSIT:	Modifica la descripci d'un estat d'una incidncia en un
   				idioma a la base de dades.
   				
******************************************************************************/  
DROP PROCEDURE IF EXISTS modificaDescripcioEstatIncidencia;
DELIMITER //
CREATE PROCEDURE modificaDescripcioEstatIncidencia (
		IN idEstat INTEGER,
		IN idIdioma INTEGER,		
		IN eDescripcio VARCHAR(60),
		OUT resultat INTEGER)

BEGIN
	p:BEGIN
		DECLARE tot INTEGER;
		SET resultat = 99;
	
		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */
		IF idEstat IS NULL OR idIdioma IS NULL OR eDescripcio IS NULL THEN 
			SET resultat = 1;
			leave p;
		END IF;
		
		/* Cerquem si existeix el registre a modificar */
		SELECT COUNT(*) INTO tot FROM desc_estat_incidencia WHERE id_estat = idEstat AND id_idioma = idIdioma;
		   		
   		/* Si no existeix el registre gravem error i sortim */	
   		IF tot = 0 THEN
   			SET resultat = 5;
   			leave p;
   		END IF;

		/* Cerquem la clau externa */
   		SELECT COUNT(*) INTO tot FROM estat_incidencia WHERE id_estat = idEstat;
   		
   		/* Si no existeix la clau externa gravem error i sortim */
	   	IF tot = 0 THEN
   			SET resultat = 3;
   			leave p;
		END IF;

		/* Cerquem la clau externa */
   		SELECT COUNT(*) INTO tot FROM idioma WHERE id_idioma = idIdioma;
   		
   		/* Si no existeix la clau externa gravem error i sortim */
	   	IF tot = 0 THEN
   			SET resultat = 3;
   			leave p;
		END IF;

		/* Eliminem espais a l'inici i fi de la variable */
		SELECT TRIM(eDescripcio) INTO eDescripcio;
		
		/* Cerquem si ja existeix un registre igual */
		SELECT COUNT(*) INTO tot FROM desc_estat_incidencia WHERE id_estat != idEstat AND id_idioma = idIdioma AND descripcio = eDescripcio;
   		
		/* Si existeix el registre gravem error i sortim */	
	   	IF tot > 0 THEN
   			SET resultat = 6;
   			leave p;
		END IF;
		
		/* Modifiquem el registre */
		UPDATE desc_estat_incidencia SET descripcio = eDescripcio WHERE id_estat = idEstat AND id_idioma = idIdioma;

		/* Asignem el valor de sortida OK */
		SET resultat = 0;
		
 	END; # p: END;

 	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('modificaDescripcioEstatIncidencia',resultat);
   	
END //

DELIMITER ;


/******************************************************************************
   NOM:      	modificaIncidencia
   
   PROPSIT:	Modifica una incidncia a la base de dades.
   				
******************************************************************************/
DROP PROCEDURE IF EXISTS modificaIncidencia;
DELIMITER //
CREATE PROCEDURE modificaIncidencia (
		IN idIncidencia INTEGER,
		IN idClient INTEGER,
		IN idProducte INTEGER,
		IN idSat INTEGER,
		IN dCompra DATE,
		IN pGarantia TINYINT,
		IN idTipus INTEGER,
		IN idEstat INTEGER,
		IN iDescripcio TEXT,
		OUT resultat INTEGER)
BEGIN
	p:BEGIN
		DECLARE tot INTEGER;
		SET resultat = 99;
	
		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */
		IF idIncidencia IS NULL OR idClient IS NULL OR idProducte IS NULL OR idSat IS NULL OR dCompra IS NULL OR pGarantia IS NULL OR idTipus IS NULL OR idEstat IS NULL OR iDescripcio IS NULL THEN 
			SET resultat = 1;
			leave p;
		END IF;
		
		/* Verifiquem que els valors estiguin dintre del rang, del contrari gravem error i sortim */
		IF pGarantia > 1 OR pGarantia < 0 THEN
			SET resultat = 4;
			leave p;
		END IF;

		/* Cerquem si existeix el registre a modificar i l'estat del mateix */
		SELECT COUNT(*),id_estat INTO tot FROM incidencia WHERE id_incidencia = idIncidencia;
   		
   		/* Si no existeix el registre gravem error i sortim */	
   		IF tot = 0 THEN
   			SET resultat = 5;
   			leave p;
   		END IF;
   		
   		/* Si l'estat s = 1 -> incidncia tancada, no es pot modificar */	
   		IF id_estat = 1 THEN
   			SET resultat = 8;
   			leave p;
   		END IF;
		
		
		/* Cerquem la clau externa */
		SELECT COUNT(*) INTO tot FROM client WHERE id_client = idClient;
		
		/* Si no existeix la clau externa gravem error i sortim */
		IF tot = 0 THEN
   			SET resultat = 3;
   			leave p;
		END IF;
		
		/* Cerquem la clau externa */
		SELECT COUNT(*) INTO tot FROM producte WHERE id_producte = idProducte;
   		
		/* Si no existeix la clau externa gravem error i sortim */
	   	IF tot = 0 THEN
   			SET resultat = 3;
   			leave p;
		END IF;
		
		/* Cerquem la clau externa */
		SELECT COUNT(*) INTO tot FROM sat WHERE id_sat = idSat;
		
		/* Si no existeix la clau externa gravem error i sortim */
		IF tot = 0 THEN
   			SET resultat = 3;
   			leave p;
		END IF;
		
		/* Cerquem la clau externa */
		SELECT COUNT(*) INTO tot FROM tipus_incidencia WHERE id_tipus = idTipus;
		
		/* Si no existeix la clau externa gravem error i sortim */
		IF tot = 0 THEN
   			SET resultat = 3;
   			leave p;
		END IF;
		
		/* Cerquem la clau externa */
		SELECT COUNT(*) INTO tot FROM estat_incidencia WHERE id_estat = idEstat;
		
		/* Si no existeix la clau externa gravem error i sortim */
		IF tot = 0 THEN
   			SET resultat = 3;
   			leave p;
		END IF;

		/* Modifiquem el registre */
		UPDATE incidencia SET id_client = idClient, id_producte = idProducte, id_sat = idSat,
			data_compra = dCompra, garantia = pGarantia, id_tipus = idTipus, id_estat = idEstat, descripcio = iDescripcio
		WHERE id_incidencia = idIncidencia;

		/* Asignem el valor de sortida OK */
		SET resultat = 0;
		
	END; # p: END;

	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('modificaIncidencia',resultat);

END //

DELIMITER ;


/******************************************************************************
   NOM:      	modificaOpinio
   
   PROPSIT:	Modifica l'opini d'una incidncia a la base de dades.
   				
******************************************************************************/
DROP PROCEDURE IF EXISTS modificaOpinio;
DELIMITER //
CREATE PROCEDURE modificaOpinio (
		IN idIncidencia INTEGER,
		IN vSat INTEGER(1),
		IN vProducte INTEGER(1),
		IN oOpinio TEXT,
		OUT resultat INTEGER)
BEGIN
	p:BEGIN
		DECLARE tot INTEGER;
		SET resultat = 99;
	
		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */
		IF idIncidencia IS NULL OR vSat IS NULL OR vProducte IS NULL OR oOpinio IS NULL THEN 
			SET resultat = 1;
			leave p;
		END IF;
		
		/* Verifiquem que els valors estiguin dintre del rang, del contrari gravem error i sortim */
		IF vSat > 9 OR vSat < 0 OR vProducte > 9 OR vProducte < 0 THEN
   			SET resultat = 4;
   			leave p;
		END IF;
		
		/* Cerquem si existeix el registre a modificar */
		SELECT COUNT(*) INTO tot FROM opinio WHERE id_incidencia = idIncidencia;
   		
   		/* Si no existeix el registre gravem error i sortim */	
   		IF tot = 0 THEN
   			SET resultat = 5;
   			leave p;
   		END IF;

		/* Modifiquem el registre */
		UPDATE opinio SET valoracio_sat = vSat, valoracio_producte = vProducte, opinio = oOpinio
		WHERE id_incidencia = idIncidencia;

		/* Asignem el valor de sortida OK */
		SET resultat = 0;

	END; # p: END;

	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('modificaOpinio',resultat);

END //

DELIMITER ;


/******************************************************************************
   NOM:      	modificaRecanviIncidencia
   
   PROPSIT:	Modifica un recanvi d'una incidncia a la base de dades.
   				
******************************************************************************/
DROP PROCEDURE IF EXISTS modificaRecanviIncidencia;
DELIMITER //
CREATE PROCEDURE modificaRecanviIncidencia (
		IN idIncidencia INTEGER,
		IN idRecanvi INTEGER,
		IN rUnitats INTEGER,
		IN preu INTEGER,
		OUT resultat INTEGER)
BEGIN
	p:BEGIN
		DECLARE tot INTEGER;
		SET resultat = 99;
	
		/* Cerquem valors NULL d'entrada, si existeixen gravem error i sortim */
		IF idIncidencia IS NULL OR idRecanvi IS NULL OR rUnitats IS NULL OR preu IS NULL THEN 
			SET resultat = 1;
			leave p;
		END IF;
		
		/* Verifiquem que els valors estiguin dintre del rang, del contrari gravem error i sortim */
		IF rUnitats < 0 OR preu < 0 THEN
   			SET resultat = 4;
   			leave p;
		END IF;
		
		/* Cerquem si existeix el registre a modificar */
		SELECT COUNT(*) INTO tot FROM recanvis_incidencia WHERE id_incidencia = idIncidencia AND id_recanvi = idRecanvi;
   		
   		/* Si no existeix el registre gravem error i sortim */	
   		IF tot = 0 THEN
   			SET resultat = 5;
   			leave p;
   		END IF;
		
		/* Cerquem la clau externa */
		SELECT COUNT(*) INTO tot FROM incidencia WHERE id_incidencia = idIncidencia;
		
		/* Si no existeix la clau externa gravem error i sortim */
		IF tot = 0 THEN
   			SET resultat = 3;
   			leave p;
		END IF;
		
		/* Cerquem la clau externa */
		SELECT COUNT(*) INTO tot FROM recanvi WHERE id_recanvi = idRecanvi;
		
		/* Si no existeix la clau externa gravem error i sortim */
		IF tot = 0 THEN
   			SET resultat = 3;
   			leave p;
		END IF;
				
	   	/* Modifiquem el registre */
	   	UPDATE recanvis_incidencia SET unitats = rUnitats, preu_unitari = preu
	   	WHERE id_incidencia = idIncidencia AND id_recanvi = idRecanvi;

	   	/* Asignem el valor de sortida OK */
		SET resultat = 0;
		
	END; # p: END;

	/* Insertem acci i resultat a la taula log */
	INSERT INTO log (procediment_emmagatzemat,resultat_operacio) VALUES ('modificaRecanviIncidencia',resultat);

END //

DELIMITER ;

/******************************************************************************
******************************************************************************/